;+
;NAME:
;agcazencdifplot - plot azimuth encoder difference averaged to 1 deg bins.
;SYNTAX: agcazencdifplot,dIAr,tit0=tit0,stddif=stddif,verD=verD
;ARGS:
; dIAr[ndays]: {}     averaged az enc dif data (see agcazencdifinpavg) 
;KEYWORDS:
;  tit0  : string  add to title of top frame
; stddif[360]: float input the standard difference (in degs). This is used to plot limit lines
;                  around the averaged data. The limit lines are +/- .01 degrees about this line
;                  When an encoder jumps 1 tooth, the encDif jumps about .02 degrees.
; verD[2]: float   vertical range for the degree plot, def: [-.06,.06]
;azLoc[360]: float azimuth  values for each averaged bin. The def is .5,1.5,2.5...359.5
;
;DESCRIPION:
; Plot the azimuth encoder difference for each day in dIAr[ndays]. 
; The data is input and averaged by agcazencdifinpavg;
;The plot has two frames:
;  top Frame: az encoder dif in degrees
;  bottom frame: az encoder dif in encoder counts
;
;Limit lines are plotted around the averaged data. They are taken from  stddif[360] (or the oct19 avg 14-31 day).
;The lines are +/- .01 degrees about stddif. When the encoder jumps by 1 tooth, this is about .02 degrees.
; The keyword verD[2] can be used to set the vertical scale for the degree avg (the default is [-.06,.06] degrees 
;(with the encoder plot scaled to these values).
;
;Examples:
; plot the data for oct19
;   yymmdd=191001
;	ndays=agcazencdifinpavg(yymmdd,dIAr,ndays=31,azloc=azloc)
;   agcazencdifplot,dIAr,tit0='191001 - 191031',verD=[-.1,.06],azLoc=azLoc
;-
;
pro  agcazencdifplot,diAr,tit0=tit0,stddif=stddif,verD=verD,azLoc=azLoc
	common colph,decomposedph,colph
;
	usePs=!d.flags and 1
	encToDeg=1.441775344488189e-4
	dtoE=1./encToDeg
	if n_elements(verD) ne 2 then verD=[-.06,.06]
	verE=verD*dToE
	stdfile='/share/megs/phil/x101/191016/encDifStd_191016.sav'
	stdDifStep=.01
	ndays=n_elements(dIAr)
	if n_elements(stddif) ne 360 then begin
		restore,stdfile
		stdDifL=oct19avg
	endif else begin
		stddifL=stddif
	endelse
	if n_elements(tit0) eq 0 then tit0=''
	if n_elements(azLoc) ne 360 then azLoc=findgen(360) + .5
;
; 	now plot encoder diff.. deg and counts
;	
	ver,verD[0],verD[1]
	cs=1.4
	font=1
	!p.multi=[0,1,2]
	xtit='az [deg]'
	ytit='azEncDif [deg]'
	tit='. Azimuth encoder difference daily avgerages. (deg). '
	sym=1
	x=azLoc
	if usePs then begin
	  stripsxy,x,diAr.azDAvg,0,0,/step,psym=sym,$
    	chars=cs,font=font,$
    	xtit=xtit,ytit=ytit,$
    	tit=tit0 + tit 
	endif else begin
	  stripsxy,x,diAr.azDAvg,0,0,/step,psym=sym,$
    	chars=cs,$
    	xtit=xtit,ytit=ytit,$
    	tit=tit0 + tit 
	endelse
	oplot,azStd,stdDifL-.01,col=colph[2]
	oplot,azStd,stdDifL+.01,col=colph[2]
	oplot,[0,360],[0,0],col=colph[3]
ln=2.5
xp=.04
csn=1.5
scl=.7
	if usePs then begin
      note,ln,'+/- .01 deg about std monthly average',chars=csn,font=font,col=colph[2],xp=xp 
      note,ln+1*scl,'0 values--> no data that azimuth value',chars=csn,font=font,col=colph[3],xp=xp
	endif else begin
		note,ln,'+/- .01 deg about std monthly average',chars=csn,col=colph[2],xp=xp
		note,ln+1*scl,'0 values--> no data that azimuth value',chars=csn,col=colph[3],xp=xp
	endelse
;
; now in encoder units
;
	ver,verE[0],verE[1]
	ytit='Encoder Cnts'
	tit='Azimuth encoder difference daily avgerages. (EncoderCnts). '
	if usePs then begin
	  stripsxy,x,diar.azDavg*dToE,0,0,/step,psym=sym,$
        chars=cs,font=font,$
        xtit=xtit,ytit=ytit,$
        tit=tit 
	endif else begin
	  stripsxy,x,diar.azDavg*dToE,0,0,/step,psym=sym,$
        chars=cs,$
        xtit=xtit,ytit=ytit,$
        tit=tit 
	endelse
    oplot,azStd,(stdDifL-.01)*dToE,col=colph[2]
    oplot,azStd,(stdDifL+.01)*dToE,col=colph[2]
    oplot,[0,360],[0,0],col=colph[3]
	return
end
