;-
;NAME:
;shsclpimg: make image of decoded clp file
;SYNTAX:istat=shsclpimg,file,imgNum,img=img,hdr=hdr,mimgInfo=imgInfo,$
;			bpcind=bpcind,medlen=medlen,cfr=cfr,bw=bw,useimg=useimg,
;			nsig=nsig,zx=zx,zy=zy,title=title,nhghts=nhghts,$
;           wintouse=wintouse,freqToUse=freqToUse,rangeToUse=rangeToUse,fast=fast,$
;			flipdata=flipdata,freqsmo=freqsmo
;ARGS:
;file: string	    filename holding decoded info (xxx.dcd)
;imgNum:  int        which img to display 1 img1 , 2 img2, 0 no image
;                    12 - both images merged
;
;KEYWORDS:
;bpcInd[2]:long     first last height indices to use for bpc
;                   default last 100 hghts
;medlen:   long     length median filter each spc. default=71 channels
;cfr : float        cfr in Mhz for band. If imgNum=12 then cfr
;                   must be cfr[2] holding the cfr for each img
;bw  : float        bandwidth in Mhz for band
;useimg:            if set then user is passing in img. useit
;nsig[2]: float		for scaling the image. default=[-nsig[0],nsig[1]]*sig
;                   def. 6 sigma.         
;flipdata[2]:       if echotek loses an i or q sample, the image can
;                   come out flipped in freq. flipdata will put an extra
;                   freq flip in the data.
;                   1,2 band: flipdata[0]=1 --> flip
;                   12 band: flipdata[0]=1 --> flip1 flipdata[1]-->flip 2
;freqsmo      :int   number of freq chan to smooth,decimate before output.
;                    the medlen length above will still be relative to the original
;zx  : int   	    scaling for x axis (neg is smaller)
;zy  : int   	    scaling for y axis (neg is smaller)
;nhghts:int         limit to this number of heights (def all)
;title: string      title
;wintouse: int      window number to use for display. Default=1
;freqToUse[2] :float freq range to use (in Mhz). 
;rangeToUse[2]:float ranges to use (in km). overrides nghts
;                    [0.,x] will start with first range
;                    [x,999] will end with last range
;fast         :int   if supplied then compute median bandpass to subtract
;                    every fast rows
;
;RETURNS:
;
;istat:  0 ok, -1 error
;img[*,*]:  float selected channel image
;hdr: {}    struct from .hdr file
;MimgInfo:{} if imgNum=+/-12 the this has the freq info for the
;           merged image.. see shsimgmerge()
;
;DESCRIPTION:
;	Make a dynamic spectra image of decoded shs file (.dcd).
;Take info from the .hdr file (it should be in the same directory
;as the .dcd file).
; You select which image you want with imgNum=1,2,12
;12 --> merge the 2 images. If imgNum is -1,-2,-12
;then the image is created, but not displayed
;-
;
function shsclpimg,dcdfile,imgNum,img=img,hdr=hdr,mimgInfo=imgInfo,$
            cfr=cfrAr,bw=bw,useimg=useimg,flipdata=flipdata,$
			bpcind=bpcind,medLen=medlen,$
			nsig=nsig,zx=zx,zy=zy,title=title,border=border,$
			nhghts=nhghts,wintouse=wintouse, freqToUse=freqToUse,rangeToUse=rangeToUse,$
			fast=fast,freqsmo=freqsmo
;
	forward_function shsimgmerge
	largVal=1e31 ; larger than this, replace with median.
	if n_elements(fast) eq 0 then fast=1
	usecToKm=.15
	chkinf=1	; check for infinities
	double=1	; use double for meanrob in imgdisp
	if n_elements(wintouse) eq 0 then wintouse=1
	csn=1.5
	if n_elements(nsig) eq 0 then nsig=6
	if n_elements(title) eq 0 then title='' 
	if n_elements(cfrAr) eq 0 then cfrAr=430.
	if n_elements(bw) eq 0 then bw=5.
	if n_elements(border) eq 0 then border=75

	if n_elements(medlen) eq 0 then medlen=71L
	if n_elements(useimg) eq 0 then useimg=0
	flipDataL=intarr(2)
	if n_elements(flipData) ge 1 then flipDataL[0]=flipData[0]
	if n_elements(flipData) gt 1 then flipDataL[1]=flipData[1]
	useSmo=(n_elements(freqsmo) gt 0)
    if useSmo then useSmo=(freqSmo[0] gt 1)

    basenm=basename(dcdfile)
	len=strlen(dcdfile)
	hdrfile=strmid(dcdfile,0,len-3) + "hdr"
	if (shsclprdhdr(hdrfile,hdr) ne 0) then return,-1
	nchan=hdr.nchan
	fftlen=hdr.fftlen
	if 0 then begin
;   no longer needed, chop at end
    if (useSmo) then begin
        if (fftlen mod long(freqSmo)) ne 0 then begin
          print,"Err: freqsmo length must divide into fftlen:",fftlen
          return,-1
        endif
    endif
	endif

	nhghtsTot=hdr.nhghts
	if n_elements(nhghts) eq 0 then nhghts=nhghtsTot
	if nhghts le 0 then nhghts=nhghtsTot
	hghtsToUseL=long([1,nhghts] + .5)
	ih0=hghtsToUseL[0]-1
    ih1=hghtsToUseL[1]-1

;   they specified the freq range to use
    if0=0
    if1=fftlen-1
    selectFreq=n_elements(freqToUse) eq 2
    if selectFreq then begin
        if (useSmo) then begin
           print,"Error: smoothing currently not supported when selecting freq range"
           return,-1
        endif
	endif


;
	if n_elements(rangeToUse) gt 0 then begin
		rangeTot=([0L,nhghts-1]*hdr.hghtresusec  + hdr.hghtdelayusec)$
				 *usecToKm
		rangeToUseL=rangeTot
		if n_elements(rangeToUse) eq 1 then $
			rangeToUseL=[rangeToUse,rangeTot[1]]
		if n_elements(rangeToUse) eq 2 then rangeToUseL=rangeToUse
;       compute indices relative to first height
		aa=(rangeToUseL/usecToKm - hdr.hghtdelayusec)/$
				hdr.hghtresusec
		ih0=long((aa[0] > 0L) + .5)
		ih1=long((aa[1] > 0L) + .5) < (nhghtsTot-1)
		hghtsToUseL=[ih0,ih1]+1L
	endif
		
	nhghts=hghtsToUseL[1]-hghtsToUseL[0] + 1L
	if (nhghts lt 0) or (nhghts gt hdr.nhghts) or $
		(hghtsToUseL[0] lt 1) or (hghtsToUseL[1] gt hdr.nhghts)$
		then begin
		if n_elements(rangeToUse) gt 0 then begin
			print,"rangeToUse illegal. Valid vales are:",rangeTot
		endif else begin
			print,"illegal number heights requested. maxval:",$
		        hdr.nhghts
	    endelse
		return,-1
	endif
	if (not useimg) then begin
;
;	bpc should always come from end of array? 
;
		if n_elements(bpcind)  ne 2 then begin
            ; be careful with signal pulse typically 175-185 hghts
            if hdr.nhghts gt 1000 then begin
                bpcInd=[-100,-1] + hdr.nhghts
            endif else begin
                ; normally 100./3960 = .025

                aa=long(hdr.nhghts * .025) > 10
                bpcInd=[-aa,-1] + hdr.nhghts
            endelse
        endif

		img=fltarr(fftlen,nhghtsTot)
		err=0
		openr,lun,dcdfile,error=err,/get_lun
		if err ne 0 then begin	
			printf,-2,!ERROR_STATE.MSG
			return,-1
		endif
;
;	see which img they want
;   if img2,position before read
;
		if imgNum eq 0 then imgNum=-1
		iimg=abs(imgNum)
		nimg=(iimg eq 12)?2:1
		posFile=0L
; -----------------------------------------------------------------
;		loop inputing, the images..
;
		useImg=intarr(nimg)+1
		for im=0,nimg-1 do begin
			if (iimg eq 2) then begin
				posFile=4L*fftlen*hdr.nhghts
	   	    	point_lun,lun,posFile
			endif
			readu,lun,img
			img=shift(img,fftlen/2,0)
			if (flipDataL[im] ne 1) then img=reverse(img,1)
;
;	check for infinities.. warn,.
;
			inftst=finite(img)
		    jj=where(inftst eq 0,cntInf)
			if cntInf gt 0 then begin
		    	print,"Warning: found ",cntInf," nonFinite numbers in input img"
                ; replace with median value
                jj1=where(inftst eq 1)
				medVal=median(img[jj])
				img[jj]=medval
                ; check for any really lard values
				kk=where(abs(img[jj1]) gt largval,cntlarge) 
				
				if cntLarge gt 0 then begin
				    print,"Warning found:",cntLarge," values > ",largval
					img[jj1[kk]]=medval
			    endif
			endif 

			bpcScl=1./(total(img[*,bpcind[0]:bpcind[1]],2)/(bpcind[1]-bpcind[0] +1.))
			bpcScl=reform(bpcScl,fftlen)
;
;	now extract the heights that actually want to display
;
			ih0=hghtsToUseL[0]-1
			ih1=hghtsToUseL[1]-1
; -> don't shrink it till both images input..
;			if nhghts ne nhghtsTot then begin
;				img=img[*,ih0:ih1]
;			endif
			if (fast gt 1 )then begin
				midval=fast/2
				if (medlen gt 1) then begin
                    medbp= median(img[*,midval],medlen)
                endif else begin
                    medbp= img[*,midval]
                endelse

				for ih=0,nhghts-1 do begin
					img[*,ih]*=bpcScl[*]
					if (ih mod fast) eq midval then begin
					 	print,midval
                        medbp=(medlen gt 1)? median(img[*,ih],medlen):img[*,ih]
					endif
					img[*,ih]-= medbp
				endfor
			endif else begin
;				print,"medlen:",medlen
				; try to speed up median if subset of freq
				if selectFreq then begin
					freqAr=(findgen(fftlen)/fftlen - .5)*bw + cfrar[im]
					ii=where((freqAr ge freqToUse[0]) and (freqAr le freqToUse[1]),nchan)
					; if we don't need this band, don't bother to process it..
					if nchan gt 0 then begin
				    ; limit to medlen/2 beyond freq they wanted..
                   		ij0=(if0 - medlen/2) > 0l
                        ij1=(if1 + medlen/2) < (fftlen-1)
						; make sure we have at least medlen points..
						if (ij1 -ij0 + 1) lt medlen then begin
							if (ij0 gt fftlen/2) then begin
								ij0-=medlen
							endif else begin
								ij1+=medlen
							endelse
						endif
                   	    for ih=ih0,ih1 do begin
                       		img[ij0:ij1,ih]*=bpcScl[ij0:ij1]
                       		if medlen gt 1 then $
                            	img[ij0:ij1,ih]-= median(img[ij0:ij1,ih],medlen)
                    	endfor
					endif
				endif else begin
					for ih=ih0,ih1 do begin
						img[*,ih]*=bpcScl[*]
				        if medlen gt 1 then $
                        	img[*,ih]-= median(img[*,ih],medlen)
					endfor
				endelse
			endelse
			if (nimg eq 2) and (im eq 0)  then img1=img	; save it
		endfor
; -----------------------------------------------------------------
		if nhghts ne hdr.nhghts then begin
			img=img[*,ih0:ih1]
			if nimg eq 2 then img1=img1[*,ih0:ih1]
		endif
		if nimg eq 2 then begin
;        merge images
;        kind of a waste if selectfreq doesn't use the band.. but we'll
;        get rid of it later..
		 	istat=shsmergeimg(img1,img,cfrAr,bw,imgM,imgInfo)
			img=imgM
			imgM=''
			img1=''
		endif 
		free_lun,lun
	endif
    if medlen lt 1 then img-=1.
	;
	; if select freq, take the subset..
	; 	
	if selectFreq then begin
		if nimg eq 2 then begin
			freqAr=findgen(imgInfo.nchan)*imgInfo.df + imgInfo.f0
		endif else begin
			freqAr=(findgen(fftlen)/fftlen - .5)*bw + cfrar[0]
		endelse
		ii=where((freqAr ge freqToUse[0]) and (freqAr le freqToUse[1]),nchan)
		if0=ii[0]
		if1=ii[nchan-1]
		xr=[freqAr[if0],freqAr[if1]]
		if nimg eq 2 then begin ; .. fix imginfo
			imgInfo.f0=freqAr[if0]
			imgInfo.f1=freqAr[if1]
			imgInfo.nchan=nchan
		endif
		img=img[if0:if1,*]
	endif

	if (imgNum lt 0) then return,0
	yr=([ih0,ih1]*hdr.hghtresusec  + hdr.hghtdelayusec)*.15
	if not selectFreq then begin
		if nimg eq 2 then begin
			xr=[-.5,.5]*imgInfo.df*imgInfo.nchan + (imgInfo.f0 + imgInfo.f1)*.5
		endif else begin
			xr=[-.5,.5]*bw + cfrAr
		endelse
	endif
	tit0=(nimg eq 2)?" file:"+basenm+ " chn:" + string(format='(i2)',imgNum):$
	                 " file:"+basenm+ " chn:" + string(format='(i1)',imgNum) 
	if useSmo then begin
		; if length not a multiple of freq smo, chop end, fix x axis..
		ifreqsmo=long(freqsmo+.5)
		nx=n_elements(img[*,0])
		chopx=nx - (nx/ifreqsmo) * ifreqsmo
		jj=nx
		if chopx ne 0 then begin
			xr[1]-=((1.*chopx)/nx)*(xr[1]-xr[0])
			jj=nx - chopx
		endif
		imgsmo=reform(total(reform(img[0:jj-1,*],freqsmo,jj/freqsmo,nhghts),1)/freqsmo)
		imgdisp,imgsmo,nsigclip=nsig,zx=zx,zy=zy,xr=xr,yr=yr,win=wintouse,$
			border=border,xstyle=9,xtitle='Freq Mhz',ytitle='Range Km',$
			chkinf=chkinf,double=double
	endif else begin
;		print,"flipdataL:",flipdataL,' xr=:',xr
   	 	imgdisp,img[*,*],nsigclip=nsig,zx=zx,zy=zy,xr=xr,yr=yr,win=wintouse,$
			border=border,xstyle=9,xtitle='Freq Mhz',ytitle='Range Km',$
			chkinf=chkinf,double=double
	endelse
	note,1.5,title + tit0,chars=csn
	return,0
end
