;+
;NAME:	
;shsclpparsetming - parse timing info from clp hdr files
;SYNTAX:n=shsclpparsetming(dirName,tmIAr)
;ARGS:
;dirName: string	name of directory holding .hdr files
;RETURNS:
;	n: long   number of entries found
;tmIAr[n]: {}   holds timing info:
;DESCRIPTION:
;	The clp processing generates a .dcd and a .hdr file for each
;integration (usually 10 seconds). This routine will search
;all of the .hdr files in a directory and return the timing
;info. This info tells how long it took to complete different
;parts of the processing.
;The tmIAr struct has:
; ;tmI={        wstS:  0.    , $; secs waited before start
;               fftU:  0.    , $; usecs for 1 fft
;              accumU: 0.    , $; usecs for power and accum 1 height,1 ipp
;                ippS: 0.    , $; secs for 1 ipp
;                inpS: 0.    , $; secs for input
;                outS: 0.    , $; write out time secs
;                tmTot:0.}   ; tot tm secs this block
;-
;-
function shsclpparsetming,dirname,tmIAr


	tmI={      wstS:  0.    , $; secs waited before start
               fftU:  0.    , $; usecs for 1 fft
              accumU: 0.    , $; usecs for power and accum 1 height
                ippS: 0.    , $; secs for 1 ipp
                inpS: 0.    , $; secs for input
                outS: 0.    , $; write out time secs
                tmTot:0.}   ; tot tm secs this block

	dirL=dirName
	if strmid(dirName,0,1,/reverse) ne "/"  then dirL+="/"
	 cmd='grep AvgTMING ' + dirL + '*.hdr'
	spawn,cmd,inplines,errResult,count=nlines
	if nlines eq 0 then begin
		print,"clpparsehdrs:" + errResult
		return,0
	endif
	a=stregex(inplines,"^[^ ]* wSt *([^ ]*) fftU *([^ ]*) accumU *([^ ]*) ipp *([^ ]*) inp *([^ ]*) out *([^ ]*) tot *([^ ]*)",/extr,/sub)
	ii=where(a[1,*] ne '',cnt)
	if cnt ne nlines then begin
		a=a[*,ii]
		nlines=cnt
	endif
	tmIAr=replicate(tmI,nlines)
	tmIAr.wstS  =reform(float(a[1,*]))
	tmIAr.fftU  =reform(float(a[2,*]))
	tmIAr.accumU=reform(float(a[3,*]))
	tmIAr.ippS  =reform(float(a[4,*]))
	tmIAr.inpS  =reform(float(a[5,*]))
	tmIAr.outS  =reform(float(a[6,*]))
	tmIAr.tmTot =reform(float(a[7,*]))
	return,nlines
end
