;+
;NAME:
;shsgetspc - input decoded spectra
;SYNTAX: nspc=shsgetspc(dir,fbase,spcar,freq,hdr)
;ARGS:
;dir    :string    directory holding file
;fbase  :string    file basename (see below)
;RETURNS:
; nspc  : long     < 0 error.. 
;                  > 0  number of spectra in array
;spcar[nchn,nspc]:float  spectra
;freq[nchn]: float   freq for spectra
;hdr       : {}     header info
;
;DESCRIPTION:
;   Read a shs decoded averaged spectra file (typically avged for 10 secs).
;This has been processed by clp1shs.c program.
;	The user inputs the directory and base filename (see below).
;The spectra, freq array, and header struct will be returned.
;	This routine is normally used for debugging...
;EXAMPLE:
;  Suppose the integrated files you want are:
;/net/rserv2/data/atm/clp/test_20170101_001.hdr
;/net/rserv2/data/atm/clp/test_20170101_001.dcd
;The call would be:
; dir  ='/net/rserv2/data/atm/clp/'
; fbase='test_20170101_001'    ; note no trailing .
;nspc=shsgetspc(dir,fbase,spcar,freq,hdr)
;
;-
;
; input r decoded shs file
;
function shsgetspc,dir,fbase,spcar,freq,hdr
;	dir='/net/rserv2/data/atm/clp/hf_20160602shs/'
;	fbase='1464935470.1'
	hname=dir+fbase + ".hdr"
	dname=dir+fbase + ".dcd"
	if (shsclprdhdr(hname,hdr) ne 0) then begin &$
   		print,"can't open hdrfile:",hname &$
		return,-1
	endif
;
	openr,lun,dname,error=err,/get_lun
    if err ne 0 then begin &$
        printf,-2,"err opening dcdfile:",!ERROR_STATE.MSG &$
        return,-1
     endif
	fftlen=hdr.fftlen
	nhghtsTot=hdr.nhghts
	nchan=hdr.nchan
	spcAr=fltarr(fftlen,nhghtsTot,nchan)
	readu,lun,spcAr 
	free_lun,lun
	for i=0,nchan-1 do begin
		spcAr[*,*,i]=reverse(shift(spcAr[*,*,i],fftlen/2l,0),1)
	endfor
    cenChan=fftlen/2l - 1  ; sincde we flipped it..
	bw=1./(hdr.smpTmUsec)
	chnWd=bw/fftlen
	cfr=430.
	freq=((findgen(fftlen) - cenChan)*chnWd ) + cfr
	return,nhghtsTot
end     
