;+
;NAME:
;bdwf_getscaninfo - get scan info for a set of fnmI files
;SYNTAX: nscans=bdwf_getscaninfo(fnmi,rcvNum,scanIAr,maxDfileScan=maxDfileScan,useposonoff=useposonoff)
;ARGS:
;fnmI[]:{}  array of fnmI structs to search. This is returned from 
;           masgetfilelist()
;rcvNum: int  receiver number to use
;KEYWORDS:
;maxDfileScan: long Limit the maximum data files per scan. If not 
;                   supplied, then the program searches for the maximum.
;useposonoff    : if set the look for position on,off on scans and use the on..
;RETURNS:
; scanIAr[nscans]: {} array holding info on all the scans found 
;-
function bdwf_getscaninfo,fnmi,rcvNum,scaniar,maxDfileScan=maxDFileScan,useposonoff=useposonoff
;
;
; figure out order for beam 0 . others will follow
;
	useAlfa=rcvnum eq 17
	iband=(usealfa)?0:1
	ii=where((fnmi.bm eq 0) and (fnmi.band eq iband),cnt)
	fnmiT=fnmi[ii]
;
; file summary for these 
;
	nsum=masfilesum(flist,sumI,fnmi=fnmiT)
	ii=where(sumI.h.rfNum eq rcvNum,cnt)
	if cnt eq 0 then begin
		print,"No scans found for rcvNum:",rcvNum
		return,-1
	endif
	sumI=sumI[ii]
; 
; sort by time
;
	ii=sort(sumi.h.mjdxxobs)
	sumi=sumi[ii]
	if keyword_set(useposonoff) then begin
		ii=where(sumi.h.obsmode eq 'ONOFF' and (sumI.h.scantype eq 'ON'),cnt)
	endif else begin
		ii=where(sumi.h.obsmode eq 'ON',cnt)
	endelse
	if cnt eq 0 then begin
		print,"did not find and on scans (or posonoff on scans)"
		return,0
	endif
	ii=ii[0]
	; make sure we start on a data scan
	sumI=sumI[ii:*]
	scanAr=sumi.h.scan_id
	uscanAr=scanAr[uniq(scanar,sort(scanar))]
	if not (keyword_set(maxDFileScan)) then begin
		maxDFileScan=0L
		for i=0,n_elements(uscanar)-1 do begin &$
			ii=where(scanAr eq uscanar[i],cnt) &$
			maxDfileScan=(maxDFileScan > cnt) &$
		endfor
	endif
	ii=where((fnmi.date eq sumI[0].date) and $
	         (fnmi.band eq sumI[0].band) and $
	         (fnmi.grp  eq sumI[0].grp)  and $
	         (fnmi.num  eq sumI[0].num),nbeams)
	if useAlfa then nbeams*=2   ; each band counted as separate beam
	ubeams=fnmi[ii].bm
;
; loop getting the data and cals
;
	if (keyword_set(useposonoff)) then begin
		iid1=where((sumi.h.obsmode eq 'ONOFF')  and (sumI.h.scantype eq 'ON') and  $
		       (sumi.num mod 100L eq 0),ndatst)
		ok=intarr(ndatst) +1
		iion=iid1+2
		iioff=iion+1
		for i=0,ndatst-1 do begin
			if (sumI[iion[i]].h.obsmode ne 'CAL') || $ 
			   (sumI[iion[i]].h.scantype ne 'ON') || $
			   (sumI[iioff[i]].h.obsmode ne 'CAL') || $
			   (sumI[iioff[i]].h.scantype ne 'OFF') then ok[i]=0
		endfor
		ii=where(ok eq 1,cnt)
		if (cnt eq 0 ) then begin
			print,"No onoff position switching with cals found"
			return,0
		endif
		if cnt ne ndatst then begin
			iid1=iid1[ii]
			iion=iion[ii]
			iioff=iion[ii]
		endif
	endif else begin
		; check that cals are really cals
;   indices for calon,caloff, start of data beam 0
	 	iion=where((sumi.h.obsmode eq 'CAL') and $
               (sumi.h.scantype eq 'ON'),non)
     	iioff=where((sumi.h.obsmode eq 'CAL') and $
                 (sumi.h.scantype eq 'OFF'),noff)

; following  assumes data takes less than 100 files...
		iid1=where((sumi.h.obsmode eq 'ON')  and $
		       (sumi.num mod 100L eq 0),ndatst)
	endelse
	nscans=min([n_elements(iion),n_elements(iioff),n_elements(iid1)])
;	ii=where((sumi.h.obsmode eq 'CAL')  and $
;             (sumi.h.scantype eq 'OFF'),nscans)
	; alfa has both bands.. count as separate beams
	scanI={$
		nfilesD   : 0L,$
		nrowsD    : 0L,$
		ndumpD    : 0L,$
		nrowsC    : 0L,$
		ndumpC    : 0L,$
		sumI_D0   : sumi[0],$ ;  bm 0 dat 0 sumI file
		fnmIDat   :replicate(fnmi[0],nbeams,maxDFileScan),$
		fnmICalOn :replicate(fnmi[0],nbeams),$
		fnmICalOff:replicate(fnmi[0],nbeams)$
	}
	scanIAr=replicate(scanI,nscans)
;
	for iscan=0,nscans -1 do begin
		iid   =iid1[iscan]
		iiCon =iion[iscan]
		iiCoff=iioff[iscan]
		scanD=sumI[iid].h.scan_id
		nfilesD=0
		nrowsD=0L       		; all datafiles
		for i=0,maxDfileScan-1 do begin
			if sumi[iid+i].h.scan_id ne scanD then break
			nfilesD++
			nrowsD+=sumi[iid+i].nrows
		endfor
		scanIAr[iscan].nrowsD=nrowsD
		scanIAr[iscan].ndumpD=sumI[iid].dumprow; spc per row (except maybe last?)
		scanIAr[iscan].nfilesD=nfilesD
; 		assumes calon=caloff and only 1 file for each
		scanIAr[iscan].nrowsC=sumi[iiCon].nrows
		scanIAr[iscan].ndumpC=sumi[iiCon].dumprow
        scanIar[iscan].sumI_d0  =sumi[iid]
		for ibm=0,nbeams-1 do begin
;
;		here's the data
;           alfa will hav ibm going 0..15 (band0,band1 count as separate beams)
;
			iibm=ibm
			iiband=1
			if useAlfa then begin
			    iibm=ibm/2l
			    iiband=ibm mod 2 ; do band 0 then band 1
			endif
 			for i=0,nfilesD - 1 do begin
				ii=where((fnmi.date eq sumi[iid+i].date) and $
		                 (fnmi.num  eq sumi[iid+i].num) and $
				         (fnmi.bm eq iibm) and (fnmI.band eq iiband),cnt)
				if cnt ne 1 then begin
					print,"could not find data scan for bm,band:",iibm,iiband
					help,sumi[iid+i],/st
					return,-1
				endif
				scanIAr[iscan].fnmiDat[ibm,i]=fnmi[ii]
			endfor
;       cals
			ii=where((fnmi.date eq sumi[iicOn].date) and $
		         	 (fnmi.num  eq sumi[iicOn].num) and $
				 	 (fnmi.bm eq iibm) and (fnmi.band eq iiband),cnt)
			if cnt ne 1 then begin
				print,"could not find calOn scan for bm,band:",iibm,iiband
					help,sumi[iicon],/st
					return,-1
			endif
			scanIAr[iscan].fnmICalOn[ibm]=fnmi[ii]
;      cal off
			ii=where((fnmi.date eq sumi[iicOff].date) and $
		          	 (fnmi.num  eq sumi[iicOff].num) and $
				 	 (fnmi.bm eq iibm) and (fnmi.band eq iiband),cnt)
			if cnt ne 1 then begin
				print,"could not find calOff scan for bm,band:",iibm,iiband
	 			help,sumi[iicoff],/st
				return,-1
			endif
			scanIAr[iscan].fnmiCalOff[ibm]=fnmi[ii]
		endfor
	endfor
	return,nscans
end
