;
; input cadi  file, unpack, return data (in a reasonable datatype format) 
; 
; pos    
; 0    timestamp
; 25   hdr data block
;
;
;RETURNS:
;     stat: int   1  ok
;                 -1 open error
;                 -2 gainflag mismatch
;                 -3 ioerror
;                 -4 file no data..
function cadi_inpfile,fname,hdr,fAr,eAr
;
; get length of file
;
	dhstepI=3l	; height resolution
	maxHghtFlag=170 ; 510km/3  if a height entry, gain flag must be less than this
	iE=0l
	retstat=0
	lun=-1
	err=0
	openr,lun,fname,err=err,/get_lun
	if err ne 0 then begin
		print,"open error:"+!error_state.msg + " for " + fname
		return,-1
	endif
	on_ioerror,ioerr
	fs=fstat(lun)
	bytesTot=fs.size
	if bytesTot eq 0 then begin
		retstat=-4
		goto,done
	endif
			
	inpbuf=bytarr(bytesTot)
	
;  raw header
	a={stationNm:bytarr(4),$ ; 0
   		   fileTm   :bytarr(24),$; 3
		   fileType :bytarr(4) ,$; 28
   	       nfreq    :0l        ,$; 32
   		   dopLen   :0b,$        ; 36
           fill1    :bytarr(3),$ ; 37  "cad"
           minH     :0L,$        ; 40
           maxH     :0L,$        ; 44
              pps   :0b,$        ; 48 
           npulseAvg:0b,$        ; 49
   		   fill2    :bytarr(2),$ ;50  .. ".d" or 46,100 or
             bthr100:0l,$        ; 52 .. base threshold *100
             nthr100:0l,$        ; 56 .. noise threshold * 100
             minDop :0b,$        ; 60 .. min dop before saving
             secBsmp: bytarr(7),$    ; 61
  			 gainCtl: 0b,$         ; 68
             sigProc: 0b,$         ; 69
             nrcv   : 0b,$         ; 70
             fill3  : bytarr(13)}  ; 71
;
; get header
;
	readu,lun,a
;
;	make header we return
;
	 nfreq=a.nfreq
;
;	read the frequencies
;	
	freqAr=fltarr(nfreq)
	a1={tmMin: 0b,$         ; 1284
    tmSec: 0b}         ; 1285
	 
	readu,lun,freqAr,a1
	
	 gainCtl=(string(a.gainctl) eq 'n')?0l:long(a.gainctl-byte('0')); N-->0 (actually should be 2..)
	 gainctl=gainctl[0]
	 hdr={stationNm:string(a.stationNm),$ ; SILL
           fileTm    :strtrim(string(a.fileTm)),$
           fileType  :string(a.fileType[0]),$;  'I' or 'H'
		   fileNm    :basename(fname),$
           nfreq     :nfreq  ,$    ;
           dopLen    :long(a.doplen),$
           fill1     :string(a.fill1),$ ;  "cad"
           minH      :a.minH,$         ; first height .. 90.km
           maxH      :a.maxH,$         ; last heigth .. 510 km
           pps       :long(a.pps),$    ; pulse per sec
           npulseAvg :long(a.npulseAvg),$ ; 
           fill2     :string(a.fill2),$ ;   ".d" 
           basethr   :a.bthr100/100.,$     ; base threshold
           noisethr  :a.nthr100/100.,$     ; noise threshold
           minDop    :long(a.mindop),$     ; min dop channels kept before save
           smpPeriod :(a.secBSmp[0:3]),$; sec between samples was 7 bytes fill2a    :string(a.secBsmp),$ ,$; all 7 bytes os secBsmp
		   gainCtl   :gainctl,$; N-->0 (actually should be 2..)
		   sigProc   :string(a.sigProc),$;    'F,T,N' 
           nrcv      :long(a.nrcv),$
		   fill3     :string(a.fill3),$  ; probably junk
		   sec1970   :0l,$               ; sec 1970 rec start time
		   recMin    :long(a1.tmMin),$
		   recSec    :long(a1.tmSec)}
;
;	compute sec1970 for start rec  from filedate and recMin,recSec
;
;                            mon     day       hr       min n  sec        year
;                             1       2        3         4      5          6
	a=stregex(hdr.fileTm,"^([^ ]*) *([^ ]*) *([0-9]*):([0-9]*):([0-9]*) *([0-9]*)",/sub,/extr)
	yr=long(a[6])
	mon=montonum(a[1])
	day=long(a[2])
	hr =long(a[3])
	min=long(a[4])
	sec=long(a[5])
	yymmdd=yr*10000L + mon*100 + day
	hhmmss=hr*10000l  + min*100l +sec
	secF=hr*3600l + min*60l + sec
	secR=hr*3600l + hdr.recmin*60l + hdr.recsec
;	check if hour changed for rec.. need to inc by 3600l
	incToRec=(secR lt secF)?3600:0l
	astToUtc=4l*3600l
	hdr.sec1970=tosecs1970(yymmdd,hhmmss) + incToRec + astToUtc

	point_lun,-lun,curPos
	bytesToRead=bytesTot-curPos
	cbuf=bytarr(bytesToRead)
	readu,lun,cbuf
;
;	now decode the rest of the junk
;
	gflag='e0'xb + hdr.gainCtl   ; should be E2.. unless gainctl=N -> 0.. then need to fix above..
    BaseThr='f0'xb
    noiseThr='f1'xb
	ifreq=0l	 ; first freq
	i    =0l
	rec={ freq        :0.,$
		   avgNoisePwr:0.,$
		   gainFlag   :0,$  ; -1 none or n=0..f (atten is 5db*n). -1 is actually 2*5db 
           thrFlag    :0,$  ; 1 -> noise threshold, 2-> base threshold, 0 -> bad match
		   nhghtDop   :0l,$   ; number of dopheights (1 hght can have up to 8 dops)
		   ind1stHght :-1l}   ; -1 --> no entry into our data array
	entry={ifreq:0L,$ ; frequency index into  freq array
		    ih  :0l,$ ; hght index 0=first hght.. actual is h - firstH/3 (h - 30)
			ifile:0l,$; points to frqar[*,ifile]  if we concat different files
			dopBin:0l,$; doppler bin
			iq    :fltarr(2)}
	fAr=replicate(rec,hdr.nfreq)
	maxEntry=5000l
	eAr=replicate(entry,maxentry)
	minHghtVal=(hdr.minh/dhStepI) ; since steps of 3 km
	while i lt (bytesToRead-1) do begin &$
    	fAr[ifreq].freq=freqAr[ifreq]
		gflagIn=cbuf[i] &$
		if (gflagIn eq 255) then break	; after last freq there is  255
    	nflagIn=cbuf[i+1] &$
		; check gain flag to make sure we are synced
		if gflagIn ne gflag then begin
			print,"GainFlag err:",gflag,gflagin,ifreq,i + curPos,$
				format='(a," exp:",z2," inp:",z2," freqInd:",i3," byteInd:",i4)' 
			retstat=-2	
			goto,done
		endif
		far[ifreq].gainFlag=(gflagIn eq 'ef'xb)?-1:gflagin - 'e0'xb
		far[ifreq].thrFlag =(nflagIn eq 'f0'xb)?1:(nflagIn eq 'f1'xb)?2:0l
		far[ifreq].avgNoisePwr= ((float(cbuf[i+2])) + (float(cbuf[i+3])*256.))*.1 ; in a/d counts
		i+=4l
		if i ge (bytesToRead - 1) then break
		; loop till we get a height range that is > 510/3 =170 
    	k=0l &$
    	while cbuf[i+k] le maxHghtFlag do begin &$
			if k eq 0 then far[ifreq].ind1sthght=ie	; first index this freq in entryAr
        	h=cbuf[i+k++] &$
        	ndop=cbuf[i + k++] &$
        	ih=(h - minHghtVal) &$
        	for j=0,ndop-1 do begin &$
            	eAr[ie].ifreq=ifreq
            	eAr[ie].ih   =ih
			    eAr[ie].dopbin=cbuf[i+k++] &$
            	iq=fix([cbuf[i+k],cbuf[i+k+1]]) &$
            	for l=0,1 do if iq[l] gt 127 then iq[l]-=256 &$
            	eAr[ie].iq=float(iq)
				far[ifreq].nhghtDop++
            	k+=2 &$
				ie++
        	endfor &$
    	endwhile &$
    	i+=k &$
    	ifreq+=1 &$
    	if ifreq ge hdr.nfreq then break &$
	endwhile
	retstat=1
done:
	if lun gt -1 then free_lun,lun
	if ie eq 0 then begin
			Ear=''
	endif else begin
		if ie lt maxEntry then Ear=Ear[0l:ie-1]
	endelse
	return,retstat
ioerr: retstat=-3
	goto,done
end
