;+
;NAME:
;cgengetdays - input requested days of data
;SYNTAX: n=cgengetdays(yymmdd,d,ndays=ndays,hhmmss=hhmmss,badpnts=bandpnts,nbad=nbad,allmon=allmon)
;ARGS: 
; yymmdd: long  starting day to read
;KEYWORDS:
; hhmmss     : long  start time for first day. 
; ndays      : long number of days to read (def:1)
;                   if Less than 0, then count back from yymmdd.
;                   (-1 gives current day from midnite)
; badpnts[m] : {} array of pnts with bad  values read in
; nband      : long  number of bad pnts found.
; allmon     : int   if set then all data for month in yymmdd
;                    ignores ndays. hhmmss still used 
;RETURNS:
;    n  : long  number of records we read.
;                > 0  number of records returned
;                     a warning message is output if we
;                     don't get all the data
;                0 - no data for this date
;               -1 - read error.  no data   returned
;               -2 - open error
;  d[n]: {}     array of structs holding the info 
;DESCRIPTION:
;   Read in n days of  cummings generator data.
;ISSUES:
;   When stopping totkw looks like it goes negative?
;   force it positive
; - When gen are taken  offline , they give garbage results..
;   for now check genI.state=255  .. if true, set these values to 0
;-
function cgengetdays,yymmdd,b,allmon=allmon,hhmmss=hhmmss,ndays=ndays,$
			badpnts=badpnts,nbad=nbad
	
;    print,"yymmdd:",yymmdd," allmon:",allmon," hhmmss:",hhmmss," ndays:",ndays
	badstate=255	; if 255 assume generator is offline, 0 data
	nbad=0 
	allmon=n_elements(allmon) eq 0?0:allmon
    maxkw=1100l		; max allowable value totkw 1 generator.
    minFuel=0l   	; min cumulative fuel for 1 gen gallon.. .. set to 0 when gen offline
    maxFuel=1e6   	; max cumulative fuel for 1 gen gallon.. 
    maxkw=1100		; max allowable value totkw 1 generator.
	ngenoff=n_elements(genoff)
	ndaysL=(n_elements(ndays) eq 0)?1l:ndays
	if ndaysL eq 0 then ndaysL= 1l
	hhmmssL=(n_elements(hhmmss) ne 0)?hhmmss:0l
	if hhmmssL lt 0 then hhmmssL=0l
	yymmdd1=yymmdd
	yr=yymmdd1/10000L
	if yr lt 50 then yymmdd1+=20000000L
;   if ndays < 0  ignore yymmdd1, count back from current date. -1 is current -2 is yesterday
	if ndaysL lt 0 then begin
		tmNow=bin_date(systime(0))
;                     dayNm  mon  daynum 
		yymmdd1=tmNow[0]*10000L + tmNow[1]*100L + tmNow[2]
;	    hhmmssN=tmNow[3]*10000L + tmNow[4]*100l + tmNow[5]
;		print,"n_elements(hhmmss):",n_elements(hhmmss)
;		if (hhmmssL) gt 0 h
;		if (n_elements(hhmmss) ne 0) then begin	
;			if hhmmss lt 0 then hhmmss=hhmmssN
;		endif
;		if n_elements(hhmmss) eq 0 then hhmmss=hhmmssN
;		go to unix secs, then subtract N days
		epsSec=1d
		astToUtcSecs=3600d*4
		nn=abs(ndaysL) - 1
		if nn lt 0 then nn =0l
;	  	sec0=tosecs1970(yymmdd1,0l)+astToUtcSecs - (abs(ndays))*86400d + epsSec
 	  	sec0=tosecs1970(yymmdd1,0l)+astToUtcSecs - (nn)*86400d + epsSec
	 	a=fromsecs1970(sec0)
	  	yymmdd1=a[1]
	endif else begin
		if keyword_set(allmon) then begin
			yymmdd1=long(yymmdd1/100l)* 100 + 1 
			mon=(yymmdd1/100l) mod 100l
			ndaysl=daysinmon(yr,mon)
		endif
	endelse
	secStart=0l
	if n_elements(hhmmssL) ne 0 then secStart=long(hms1_hr(hhmmssL)*3600d)
;
; figure out the month files we need to read.
;
	sec0=tosecs1970(yymmdd1,000000) + 4*3600d 
;	sec1=sec0 + abs(ndaysL)*86400d -1d + secStart
 	sec1=sec0 + abs(ndaysL)*86400d -1d 
;
; now go back to yymmdd
;
	a=fromsecs1970(sec1)
;   .. we need all yymmdd2 data
	yymmdd2=a[1]
	yymm1  = (yymmdd1/100L)
	yymm2  = (yymmdd2/100L)
;
;	loop inputing the months
;
	yymm=yymm1
	totRecs=0L
;   in case an error reading one month.
	retStat=0l

;	print,"yymm1,yymm2:",yymm1,yymm2
	while (1) do begin
;		print,"yymm,yymm2:",yymm,yymm2," totRecs:",totRecs
	    if (yymm gt yymm2) then break
		fname=cgenpath() + "cgen_" + string(format='(i6.6)',yymm) + ".dat"
;		print,fname
		ioerr=0
		lun=-1
		openr,lun,fname,/get_lun,error=ioerr
		if ioerr ne 0 then begin
			if ioerr eq -248 then goto,botloop			; no file 
			print,"err opening " + fname + ":" + !error_state.msg
			retStat=-2
			goto,botloop
		endif
		f=fstat(lun)
		fsize=f.size
		reclen=n_tags({cgeninfo},/len)
		nrec=fsize/reclen 
		b1=replicate({cgeninfo},nrec)
		on_ioerror,ioerr
		rew,lun
		b1.recnum=-1
		ok=0
		readu,lun,b1
		ok=1
ioerr:
		ii=where(b1.recnum ne -1,inprecs)
		if inprecs ne nrec then begin
			b1=(inprecs gt 0)?b1[ii]:''
		endif
		if (inprecs eq 0) then goto,botloop
;       first we saved
		if (totRecs eq 0L) then begin
;          check for hour start on first month
		   if (yymm eq yymm1) and (secStart ne 0) then begin
			  ii=where((b1.yyyymmdd eq yymmdd1) and $
							  (b1.secmid lt secStart),cnt)
			  if cnt gt 0 then begin
				okAr=intarr(inprecs) + 1
				okAr[ii]=0
				ii=where(okAr eq 1,inprecs)
				if inprecs eq 0 then goto,botloop
			    b1=b1[ii]
			  endif
			endif
		   b=b1
		endif else begin
		   b=[b,b1]
	    endelse
	    totRecs+=inprecs
		on_ioerror,NULL
	; trouble on input
		if ok eq 0 then begin
			hiteof=eof(lun)
			if inprecs eq 0 then begin
				if (hiteof)  then goto,botloop
				print,"warning:readerr " + fname + ":" + !error_state.msg
				retStat=-1
				goto,botloop
			endif
		endif
botloop: if lun gt -1 then free_lun,lun
	   lun=-1	
;      compute next month
	   if yymm ge yymm2 then break
	   yy= yymm/100l
	   mm= yymm mod 100l
	   mm+=1
	   if (mm gt 12) then begin
		   yy+=1
	       mm=1
	   endif
	   yymm=yy*100l + mm
	endwhile
;
	if lun ne -1 then begin
		free_lun,lun
		lun=-1
	endif
;
;  now fix up the dates they want.
;
;	print,totRecs,yymmdd1,yymmdd1
	if (totRecs eq 0) then begin
 		b=''
		goto,done
	endif
	if totRecs gt 0 then begin
;		dd1=yymmdd1 mod 100l
		ok=intarr(totRecs)    
;        fall within requested dates
		ii=where((b.yyyymmdd ge yymmdd1) and (b.yyyymmdd le yymmdd2),cnt)
		if cnt eq 0 then begin
 			b=''
			totRecs=0l
			goto,done
		endif
		ok[ii]=1
;      if first day, must be after starting time
		ii=where((b.yyyymmdd eq yymmdd1) and (b.secmid lt secStart),cnt)
		if cnt gt 0 then ok[ii]=0
		ii=where(ok ne 0,cnt)
		if cnt eq 0 then begin
 			b=''
			totRecs=0l
			goto,done
		endif
		if cnt ne n_elements(b) then begin
			b=b[ii]	
		endif
		totRecs=n_elements(b)

		if totRecs eq 0 then begin
			b=''
			goto,done
		endif
	endif
;
;	fix up some of the variables
;
	KtoC=-273.16
	kpaToPsi=0.14503773800721814
	b.geni.oilPres*=kpaToPsi
	b.geni.oiltemp+=KtoC
	b.geni.coolanttemp+=KtoC
	b.geni.misctemp1+=KtoC
	b.geni.misctemp2+=KtoC
;   if any generators offline, just 0 then values in case garbage
	nn=n_elements(b)
	ntags=n_tags(b[0].genI[0])
	for igen=0,3 do begin 	
		ii=where(b.genI[igen].state eq badstate,cnt)
		if cnt gt 0 then for j=0,ntags-1 do  b[ii].genI[igen].(j)*=0.
	endfor
	for i=0,3 do begin
		ii=where(b.geni[i].totkw gt 32768,cnt)
 		if cnt gt 0 then begin
 			b[ii].geni[i].totkw-=65536L 
 			b[ii].geni[i].totkw=abs(b[ii].geni[i].totkw)
		endif
	endfor
; checkfor valid data... power and cumulative fuel
; let 0 be ok, 1 or more be bad
	ok=intarr(totRecs)    
	ii=where(b.geni.totkw gt maxKw,nn)
    if (nn gt 0) then begin
		ok4=intarr(4,totRecs)
		ok4[ii]=1
		okL=reform(total(ok4,1))
		ii=where(okL ne 0,nbad)
		if nbad gt 0 then ok[ii]=1
	endif
	ii=where((b.geni.totfuel lt minFuel) or (b.geni.totfuel gt maxFuel),nn)
    if (nn gt 0) then begin
		ok4=intarr(4,totRecs) 
		ok4[ii]=1
		okL=reform(total(ok4,1))
		ii=where(okL ne 0,nbad)
		if nbad gt 0 then ok[ii]=1
	endif
	ii=where(ok ne 0,nbad)
	if nbad gt 0 then begin
		badpnts=b[ii]
		ii=where(ok eq 0,totRecs)
		if totRecs eq 0 then begin
			b=''
			goto,done
	    endif
		b=b[ii]
	endif
done:
	if lun ne -1 then begin
		free_lun,lun
		lun=-1
	endif
	if (totRecs eq 0) and (retstat ne 0) then begin
		b=''
		return,retstat
	endif
	return,totRecs
end
