;+
;NAME:
;angletosterad - angle to steradian
;SYNTAS: sterad=angletosterad(theta,deg=deg)
;ARGS:
;theta: float/double  angle in radiabns to convert to steradians 
;KEYWORDS:
;deg  :               if set then theta is in degrees.
;RETURNS:
;  sterad: double  steradians that angle subtends
;DESCRIPTION:
;	Convert theta to steraradians. This assumes that theta
;is the full opening angle of a cone (not the half angle)l
; You can derive this by integrating the area of a sphere from 0 to th/2
;with a radius of 1
; for below let th be the half angle...
;
; a= integral(2*pi*rPrime*dthp) integrate thp from 0 to th
; but rPrime=sin(thp) if r =1 so..
;a =2*pi *integral(sin(thp)*dthp) from 0 th = 2*pi*(-cos(thp)) eval at 0,th = 2*pi*(1-cos(th))
; except this routine wants the full angle, not the half angle ...
;-
function angletosterad,theta,deg=deg 
;
	
	dtorL=!dpi/180D
	if keyword_set(deg) then return,2d*!dpi*(1d -cos(theta/2d*dtorL))
	return,2d*!dpi*(1d -cos(theta/2d))
end
