;+
;NAME:
;avgchanbyrms - use rmsbychan to throw out outliers when averaging
;
;SYNTAX:  avgAr=avgchanbyrms(d,median=median,rmsar=rmsar,nsig=nsig,cntar=cntar,$
;		         nodiv=nodiv,double=double)
;  ARGS:
;     d[m,n]  : array to average over 2nd dimension
;KEYWORDS:
;     median: if set then use median rather than mean when doing the avg , and dividing
;             the rms by the mean.
;     rmsAr[m]: rms values for each chan used for thresholding
;     nsig  : when averaging, use all points <- nsig. def=3
;    double : if set the compute using doubles
;   
; RETURNS:
;     avgAr[m]: average array
;     cntar[m] : long number averaged in each channel
;     rmsAr[m] : long number averaged in each channel
; DESCTRIPTION:
;    compute the standard deviation/mean  by channel.
;-
function avgchanbyrms,d,median=median,rmsAr=rmsAr,nsig=nsig,cntar=cntar,double=double
    a=size(d)
	if n_elements(nsig) eq 0 then nsig=3.
    if a[0] ne 2 then begin
        print,'array should be 2d'
        return,0
    endif
	useDbl=(keyword_set(double) or (a[3] eq 5))
	useMedian=(keyword_set(median))?1:0
    nx=a[1]
    ny=a[2]
	nodiv=1
	rmsAr=rmsbychan(d,median=median,nodiv=nodiv,meanar=meanar)
	avgAr=(useDbl)?dblarr(nx):fltarr(nx)
	cntAr=lonarr(nx)	
	clip=rmsAr*nsig
	one=(useDbl)?1d:1.

	for i=0,nx-1 do begin
		ii=where(abs(d[i,*] - meanar[i]) lt  clip[i],n)
	    cntAr[i]=n
		avgAr[i]=(useMedian)?median(one*d[i,ii]):mean(one*d[i,ii])
	endfor
    return,avgAr
end
