;+
;NAME:
;drawcircle - draw a circle 
;SYNTAX: drawcircle,x,y,radius,npnts=npnts,color=color,thick=thick,$
;				    arc=arc,xret=xret,yret=yret,$
;		 	       _extra=_e
; x,y	float	center of circle 
; radius: float radius of circle
;KEYWORDS:
;   npnts: int  number of points to use in drawing the circle. The default 
;               is 9 points. The circle will be drawn as an n-1 sided 
;               polyhedron.
;   color: int  number 0 to 10. Color to use when plotting symbol. The 
;               default is the same color as the lines beging drawn. See
;               shcolsym for a mapping of numbers to colors.
;   thick:float the line thicknes to use when drawing the lines. 1. is the
;               default.
;   arc[2]:fltarr [deg] if supplied then draw an arc rather than a full circle
;                 arc[0]= min theta
;                 arc[1]= max theta.. theta is measured CCW from the x axis
; xret[npnts]:fltarr return the x points of the circle/arc
; yret[npnts]:fltarr return the y points of the circle/arc
;   over :      If set then oplot rather than plot
; _extra=_e     any other params to plot,oplot
;
;DESCRIPTION:
;   draw a circle about x,y with given radius
;
;- 
pro drawcircle,x,y,radius,npnts=npnts,color=color,thick=thick,arc=arc,$
			over=over,xret=xret,yret=yret,_extra=_e
    common colph,decomposedph,colph

    if n_elements(npnts) eq 0 then npnts=51
	useArc=n_elements(arc) eq 2
    icol=(n_elements(color) ne 0)?color:1
	if useArc then begin 
		thMin=arc[0]
		thMax=arc[1]
	    dth=(thMax - thMin)/(npnts*1.)
		a=(findgen(npnts+1)*dth + thMin)*!dtor
	endif else begin
    	a=findgen(npnts)/(npnts-1)*2.*!pi
	endelse
	if keyword_set(over) then begin
		oplot,x+radius*cos(a),y+radius*sin(a),thick=thick,$
			color=colph[icol],_extra=_e
	endif else begin
		plot,x+radius*cos(a),y+radius*sin(a),thick=thick,$
			color=colph[icol],_extra=_e
	endelse
	if arg_present(xret) then xret=x + radius*cos(a)
	if arg_present(yret) then yret=y + radius*sin(a)
    return
end
