;+
;NAME:
;filereadsock - read file via socket.
;SYNTAX: istat=filereadsock(cpu,fname,dat,verb=verb ,tm=tm,usesh=usesh)
;ARGS:
; cpu:   string  name of remote cpu where file is located
; fname: string  name of the file to read (on remote machine).
; dat  :  xxx    data to read into. User should allocate prior to
;                call. Data will be read to fill this array. 
;KEYWORDS:
;verb:   int     if set then output some debugging info (dd cmd etc..)
; tm:     double if supplied the return time to execute routine
;usesh:  int     if true then use a shell. If not supplied or set to
;                0 then start child without shell.
;returns: istat:   1  ok
;                 -1  error probably not enough data
;                     see !error_state.msg
;DESCRIPTION:
;	We normally use nfs to read remote files. This routine will read
;a disc file using a socket and rsh.  The command used is:
;  - /usr/bin/rsh  cpu  /bin/dd bs=65536 if=fname conv=notrunc status=none  
;
;	How it works:
;  - The idl spawn routine is used with the lun= option
;  - idl spawns the command and then attaches an lun to the 
;    output of the pipe.
;  - The routine then does a  readu,dat
;    to read in the data.
;  - when done the pipe is closed.
;  What you need to use this routine:
;  - rsh must be enabled on the machine you are running on. 
;  - the remote cpu must be in your .rhosts file
;  Data will be read to fill the dat[] array the user passes in (so you must
;  allocate it prior to calling this routine.
;  - If the read hits eof before filling dat[] then istat returns with -1
;    and !error_state.msg will have the error message.
;
;-
function filereadsock,cpu,fname,dat,verb=verb,tm=tm,usesh=usesh
;
;
	istat=0
	dotm=arg_present(tm)
	if dotm then t0=systime(1)
	on_ioerror,ioerr
	if keyword_set(usesh) then begin
		cmd=string(format='("/usr/bin/rsh ",a," /bin/dd bs=65536 if=",a," conv=notrunc status=none")',cpu,fname)
		sh=1
		noshell=0
	endif else begin
		cmd=strarr(7)
		cmd[0]="/usr/bin/rsh"
		cmd[1]=cpu
		cmd[2]="/bin/dd"
		cmd[3]="bs=65536"
		cmd[4]="if="+fname
		cmd[5]="conv=notrunc"
		cmd[6]="status=none"
		sh=0
		noshell=1
	endelse
    if keyword_set(verb) then print,"start file:",fname
	t0=systime(1)
	if keyword_set(verb) then print,"cmd:",cmd
	lun=0
	catch,spawnErr
	if spawnErr ne 0 then begin
		print,"spawn error.."
		stop
	endif
	spawn,cmd,sh=sh,noshell=noshell,unit=lun
	readu,lun,dat
	istat=1
ioerr:
	if istat ne 1 then begin
		if keyword_set(verb) then begin
			print,"Error occurred"
			print,!error_state.msg
			flush,-1
			stop
		endif
		istat=-1
	endif
	free_lun,lun,exit_status=exitstat
	on_ioerror,NULL
;	print,"Exit status:",exitstat
	if dotm then tm=systime(1) - t0
	return,istat
end
