;+
;NAME:
;fluxfitvla - return source flux using vla formula
;SYNTAX: flux=fluxfitvla(coef,freq,newfit=newfit)
;ARGS:
;   coef[2,3,4...]:    float   coefficients for fit.
;      freq:    float   Frequency in Mhz.
;KEYWORD:
;newfit    :    if set then force using the newer vla fit format(aka 1999)
;               The new fit coef are for Ghz, not Mhz 
;RETURNS:
;      flux:    float  flux in Janskies.
;
;DESCRIPTION:
;   Evaluate the function
; 
;log(s)= coef[0]+coef[1]*log(freq)+coef[2]*(log(freq)^2) + coef[3]*log(freq)^3...
;
;This can be used for the standard calibrators: 3C286,3C48, and 3C147.
;You must input the coefficients for each source.
;It is taken from the vla calibration manual (chris salters copy
;or the web). 
;There are no corrections to baars et scale done here.
;If number of coef > 3 then the newer fit (circa 1999) will be used
;that includes freq^3,4... terms). 
;-
function fluxfitvla,coef,freq,newfit=newfit

	coefL=coef*1D
	freqL=freq*1d
	ncoefl=n_elements(coefL)
	case ncoefL of
		2 : begin
        	logfreq=alog10(freqL)
    		return,10d^(coefl[0]+coefl[1]*logfreq)
		   end
		3 : begin
;           coef for newer fits are for ghz, not Mhz.
        	logfreq=(keyword_set(newfit))?alog10(freqL*.001d):alog10(freqL)
    		return,10d^(coefL[0]+coefL[1]*logfreq+coefL[2]*(logfreq^2))
			end
	else  : begin
		ncoef=n_elements(coefL) 
        logfreq=alog10(freqL*.001D)
		sum=coefL[0]*1d
		for i=1,ncoef-1 do sum +=coefL[i]*logFreq^i
    	return,10^(sum)
	    end
	endcase
end
