;+
;NAME:
;fwhmtosigf - convert factor fwhm to sigma 
;SYNTAX: scl=fwhmtosigf(div2=div2)
;KEYWORDS:
;div2:     if set then return 1/(sqrt(8*log(2))
;DESCRIPTION:
;	Returns factor to go from fwhm to sigma for a 
;gaussian of:  y=a0*epx(x^2/sig^2) 
;	If div2 keyword is set then return factor for:
;    y=a0*exp(.5* x^2/sig^2)
;
;Example:
;	let y=exp( - (x/sig)^2)
; for fwhm y=.5
; if fwhm=x0  then x=x0/2  is the one sided value
; so  log(.5)= - (x/sig)^2
; x=sig * sqrt(-log(.5))  .. but log(1/2)=-log(2)..
;so
; x =sqrt(log(2))*sig
; x0=C*sig  where c = .5*sqrt(log(2))
;To convert fwhm to sig units you multiply by 1/C
;
;	This can be used in guass fitting..
;After fitting, you get the widths in sigmas.. got get back
; fwhm, you divide by scl
; sigma/scl=fhwm
;-
function fwhmtosigf,div2=div2
    if keyword_set(div2) then begin
        return,1.D/(sqrt(8D*alog(2.)))
    endif else begin
        return,1.D/(2.D*sqrt(alog(2.)))
    endelse

end
