;+
;NAME:
;pltazelusage_12m - plot the 2D az,el coverage.
;
;SYNTAX: pltazelusage_12m,az,el,title=title,sym=sym,over=over,_extra=e,$
;				    nodec=nodec
;
;ARGS:
;   az[npts]    : float azimuth positions (degrees).
;   el[npts]    : float zenith angle positions (degrees).
;
;KEYWORDS:
;    title: string label for top of plot
;      sym: int symbol to plot at each position.Default is *.
;     over:     if set then overplot this data with what is there.
;    nodec:     if set then don't plot lines of constant dec
;    _extra:    extra keyword values to pass to plot and oplot routine.
;               eg (color=n).
;RETURNS:
;
;DESCRIPTION:
;   Plot the azimuth, el positions as a cartesian x,y plot. Elevation is the radius.
;This routine can give an idea of how well a set of sources has covered the sky
;--> does not give very clear plots (as el goes to 0) ... use pltazzausage_12m instead 
;-
pro pltazelusage_12m,az,el,sym=sym,over=over,title=title,_extra=e,$
		nodec=nodec
;
	forward_function dectoazza
    common colph,decomposedph,colph

	nodec=(n_elements(nodec) eq 0)?0:nodec
	font=1
	xp=.01
	cs=1.4
	csn=1.5
	xr=!x.range
	yr=!y.range
    symloc=1
    if keyword_set(sym) then  symloc=sym
    if symloc lt 0 then symloc=-symloc
    if not keyword_set(over) then over=0
    if not keyword_set(title) then title=''
	icolel=2
	icolD=10
	icolaz=3
;
;	recorded az starts north, increases CW
;   xy coord has az start on right, increase CCW 
;   so map the az so we have az=0 top, and increase CW
;   
	azl=-(az - 90.)
    azr=azl*!dtor

	hor,-95,95
	ver,-95,95
	x=el*cos(azr)
	y=el*sin(azr)
    if (not over) then begin &$
;        plot,x,y,psym=symloc,_extra=e,/isotropic,$
        plot,el,azl*!dtor,psym=symloc,_extra=e,/isotropic,$
		/polar,$
		font=font,chars=cs,$
        xtitle='West(setting)   (Transit)   East(rising)',$
        ytitle='src_south           src_north',title=title &$
    endif  else begin &$
        oplot,xaz,yaz,psym=symloc,_extra=e &$
    endelse
;
;	rings of constant el
;
	nn=50
    th=findgen(nn)/(nn-1) * 360 * !dtor
    elAr=findgen(9)*10 + 10.
    for i=0,n_elements(elAr)-1 do begin &$
       r=fltarr(nn) + elAr[i]   &$
	   ls=((elar[i] mod 30 ) eq 0)?0:2 &$
       oplot,r,th,/polar ,linestyle=ls,color=colph[icolel] &$
    endfor
;
;   plot, lines of az=0,90
;
	ls=0
	oplot,[-90,90],[0,0],col=colph[icolaz],linestyle=ls
	oplot,[0,0], [-90,90],col=colph[icolaz],linestyle=ls
;
; now declination in N deg steps
;
	if (nodec eq 0) then begin
    dec=fltarr(3)
    ls=0
	ha=findgen(2400)/100. - 12. 
    for i=-65,70,15 do begin &$
        dec[0]=i  &$
        npts=dectoazza(dec,az1,za1,ha=ha,zamax=80.) &$
		if npts gt 1 then begin &$
;       feed to source for dome added 180, remove it
		az1=az1-180 &$ &$ &$
	    azl=-(az1 - 90.) &$
        azr=azl*!dtor &$
    	radius=90-za1 &$
		x=radius*cos(azr) &$
		y=radius*sin(azr) &$
		oplot,x,y,col=colph[icolD],linestyle=ls &$
		maxel=max(abs(y),ind)&$
		x0=0 &$
		y0=y[ind] &$
;		print,i,x0,y0 &$
		xyouts,x0,y0,string(format='(i3,"Dec")',i),chars=csn,font=font,col=colph[icold] &$
		endif &$
	endfor
	endif
	x0=0
	y0=90
	xyouts,x0,y0,"Az=0",chars=csn,font=font,col=colph[icolaz]
	x0=0
	y0=-95
	xyouts,x0,y0,"Az=180",chars=csn,font=font,col=colph[icolaz]
	x0=80
	y0=0
	xyouts,x0,y0,"Az=90",chars=csn,font=font,col=colph[icolaz]
	x0=-95
	y0=0
	xyouts,x0,y0,"Az=270",chars=csn,font=font,col=colph[icolaz]

	scl=.7
	ln=12
	note,ln,'Az,El polar plot',chars=csn,font=font,xp=xp
	note,ln+1*scl,'Az=Theta',chars=csn,font=font,xp=xp
	note,ln+2*scl,'El=Radius',chars=csn,font=font,xp=xp

	ln=26.5
	if (nodec eq 0) then $
	note,ln+0*scl,'Constant Dec',chars=csn,font=font,col=colph[icolD],xp=xp
	note,ln+1*scl,'Constant El (step 10deg)',chars=csn,font=font,col=colph[icolel],xp=xp
;
done:
	
    !x.range=xr
    !y.range=yr
    return
end
