;+
;NAME:
;pltazzausage12m - plot the 2D az,za coverage. mods for 12m
;
;SYNTAX: pltazzausage12m,az,za,title=title,sym=sym,over=over,dx=dx,$
;                     zamax=zamax,_extra=e
;
;ARGS:
;   az[npts]    : float azimuth positions (degrees).
;   za[npts]    : float zenith angle positions (degrees).
;
;KEYWORDS:
;    title: string label for top of plot
;      sym: int symbol to plot at each position.Default is *.
;     over:     if set then overplot this data with what is there.
;       dx:     The step size in feet along the x,y axis. default is 10 feet.
;   zamax : float max za to plot def is 20 
; radiusza:     if set then radius will be zamax. default will be 870foot radius
; srcind[npts]; int hold src number for each source; 0... nsrc-1
;                   will plot with color isrc+1
;    _extra:    extra keyword values to pass to plot and oplot routine.
;               eg (color=n).
;RETURNS:
;
;DESCRIPTION:
;   Plot the azimuth, za positions as a cartesian x,y plot. The axes are
;feet from the center of the dish (projected onto z=0). This routine can
;give an idea of how well a set of sources has covered the dish.
;-
pro pltazzausage12m,az,za,sym=sym,over=over,title=title,_extra=e,dx=dx,$
		zamax=zamax,srcind=srcind
		
;
	forward_function dectoazza
    common colph,decomposedph,colph

    symloc=2
	n=n_elements(az)
    if keyword_set(sym) then  symloc=sym
    if not keyword_set(dx)  then  dx=1.
    if symloc lt 0 then symloc=-symloc
    if not keyword_set(over) then over=0
    if not keyword_set(title) then title=''
	if n_elements(zamax) eq 0 then zamax=90
	useSrcInd=n_elements(srcind) eq n 
;   sin,cos want az x, CCW, TEL IS Y ccw FIX IT
    azr=(90-az)*!dtor
;
	rr=za 
    xaz=rr*cos(azr)
    yaz=rr*sin(azr)
    xr=!x.range
    yr=!y.range
   	hor,-zamax,zamax
   	ver,-zamax,zamax
	if usesrcind then begin
		 usrcind=srcind[uniq(srcind,sort(srcind))]
		 nsrc=n_elements(usrcind)
		 if (not over) then begin
            plot,xaz,yaz,psym=symloc,_extra=e,/isotropic,$
			/nodata,$
            xtitle='feed_west(setting)   deg     feed_east(rising)',$
             ytitle='feed_south           feed_north',title=title
		 endif
		 for isrc=0,nsrc-1 do begin
			   icol= (isrc mod 10) + 1
			   ii=where(srcind eq usrcind[isrc],cnt)
			   if cnt gt 0 then $
         	   oplot,xaz[ii],yaz[ii],psym=symloc,col=colph[icol]
		   endfor
	endif else begin
      if (not over) then begin
         plot,xaz,yaz,psym=symloc,_extra=e,/isotropic,$
          xtitle='feed_west(setting)   deg     feed_east(rising)',$
          ytitle='feed_south           feed_north',title=title
      endif else begin
          oplot,xaz,yaz,psym=symloc,_extra=e
       endelse
	endelse
    if keyword_set(over) then goto,done


; plot the decs
	
	colD=4
	coldA=2
    dec=fltarr(3)
    lns=2
	haAr=(findgen(100)/100. - .5 )*12.
	decAr=[-60,-40,-20,0,40,60]*1.
    for i=0,n_elements(decAr) -1 do begin
        dec[0]=decAr[i] 
        npts=dectoazza(dec,azl,zal,zamax=zamax,ha=haar)
        rr=zal
		aa=azl + 180.   ; source az
		aa=(90-aa)      ; for sin,cos
        xaz=rr*cos(aa*!dtor)
        yaz=rr*sin(aa*!dtor)
        lns=2
        lns=0
        j=n_elements(azl)-1
        xyouts,dx+xaz[0],yaz[0],'dec'+ string(format='(i3)',long(decAr[i])),$
                  color=colph[cold]
        oplot,xaz,yaz,color=colph[cold],linestyle=lns
    endfor
	dec[0]=18.2
        npts=dectoazza(dec,azl,zal,zamax=zamax,ha=haar,/deg)
        rr=zal
        aa=azl + 180.   ; source az
        aa=(90-aa)      ; for sin,cos
        xaz=rr*cos(aa*!dtor)
        yaz=rr*sin(aa*!dtor)
        lns=2
        lcol=2
        lns=0
        j=n_elements(azl)-1
	    lab=string(format='("dec",f5.1)',dec[0])
        xyouts,dx+xaz[0],yaz[0],lab,$
                  color=colph[colda]
        oplot,xaz,yaz,color=colph[colda],linestyle=lns

;
;   plot za rings every 10 degs za
;
	   th=findgen(50)/49 * 360 * !dtor
    	r =fltarr(50);
		zaAr=lindgen(9)*10 + 10
		ls=0
		col=1
		for i=0,n_elements(zaAr)-1 do begin
			  r[*]= zaAR[i]
	          oplot,r,th,/polar ,linestyle=ls,color=colph[col]
		endfor
done:
	
    !x.range=xr
    !y.range=yr
    return
end
