;+
;NAME:
;pncodeinfo - initialize the code info for the pncodes
;SYNTAX: maxcodes=pncodeinfo(pncodeI)
;RETURNS:
;maxcodes: long	that we know how to create
;pncodeI[maxcodes]: {} codeinfo struct for each code:
;DESCRIPTION:
;	Initialize the codeInfo structure for the pncodes that we know how to
;create. These codes are the ones generated by the pncode generators
;online.
; 	Each array element contains:
;IDL> help,pncodeI,/st
;** Structure CODEINFO, 4 tags, length=92, data length=92:
;   NUM_REG         LONG        1
;   LEN             LONG        1
;   NUM_FDBACK      LONG        1
;   FDBACK          LONG      Array[20]
;   galois          int         i   ; 0==> fibonnaci, 1==> galois lfsr
;   startVal        ulong		0   ; for galois
;   endVal          ulong		0   ; for galois
;
;	The codeinfo struct gets passed to the routine that generates the
;code.
; Note that the fdback register positions are 1 based. When we use them
;in the shiftregcmp routine we subtract one to get the 0 based index into
;the shift register.
;-
function pncodeinfo,pncodeI
;
;  struct to hold the pncode info
    a={ codeinfo,$
        num_reg: 0L, $ ; number of registers for this code
            len: 0L, $ ; lenght of this code
     num_fdback: 0L, $ ; number of feedbacks this code
         fdback: lonarr(20),$ ; max of 20 feedback registers.
		 galois: 0L  , $ ; 
		 startVal:0UL, $ ; 
		 endVal:  0UL}
;
; pncode used for radar:
;
	maxCodes=17
	pncodeI=replicate({codeinfo},maxCodes)

;   1
	i=0
    pncodeI[i].num_reg   =1
    pncodeI[i].len       =1
    pncodeI[i].num_fdback=1
    pncodeI[i].fdback[0] =1
;
; 2^2 - 1= 3
;
	i=1
    pncodeI[i].num_reg   =2
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =1
    pncodeI[i].fdback[1] =2
;
; 2^3 - 1= 7
;
	i=2
    pncodeI[i].num_reg   =3
    pncodeI[i].len       =2L^pncodeI[i].num_reg-1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =2
    pncodeI[i].fdback[1] =3
;
; 2^4 - 1= 15
;
    i=3
    pncodeI[i].num_reg   =4
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =3
    pncodeI[i].fdback[1] =4
;
; 2^5 - 1= 31
;
    i=4
    pncodeI[i].num_reg   =5
    pncodeI[i].len       =2L^pncodeI[i].num_reg -1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =3
    pncodeI[i].fdback[1] =5
;
; 2^6 - 1= 63
;
    i=5
    pncodeI[i].num_reg   =6
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =5
    pncodeI[i].fdback[1] =6
;
; 2^7 - 1= 127
;
    i=6
    pncodeI[i].num_reg   =7
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =6
    pncodeI[i].fdback[1] =7
;
; 2^8 - 1= 255
;
    i=7
    pncodeI[i].num_reg   =8
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=4
    pncodeI[i].fdback[0] =4
    pncodeI[i].fdback[1] =5
    pncodeI[i].fdback[2] =6
    pncodeI[i].fdback[3] =8
;
; 2^9 - 1= 511
;
    i=8
    pncodeI[i].num_reg   =9
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =5
    pncodeI[i].fdback[1] =9
;
; 2^10 - 1= 1023
;
    i=9
    pncodeI[i].num_reg   =10
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =7
    pncodeI[i].fdback[1] =10
;   
; 2^11 - 1= 2047
;
    i=10
    pncodeI[i].num_reg   =11
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =9
    pncodeI[i].fdback[1] =11
;   
; 2^12 - 1= 4095
;
    i=11
    pncodeI[i].num_reg   =12
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=4
    pncodeI[i].fdback[0] =6
    pncodeI[i].fdback[1] =8 
    pncodeI[i].fdback[2] =11
    pncodeI[i].fdback[3] =12
;   
; 2^13 - 1= 8191
;
    i=12
    pncodeI[i].num_reg   =13
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=4
    pncodeI[i].fdback[0] =10
    pncodeI[i].fdback[1] =9 
    pncodeI[i].fdback[2] =12
    pncodeI[i].fdback[3] =13
;
;   
; 2^14 - 1= 16383
;
    i=13
    pncodeI[i].num_reg   =14
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=4
    pncodeI[i].fdback[0] =2 
    pncodeI[i].fdback[1] =3
    pncodeI[i].fdback[2] =13
    pncodeI[i].fdback[3] =14
;   
; 2^15 - 1= 32767
;
    i=14
    pncodeI[i].num_reg   =15
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =14
    pncodeI[i].fdback[1] =15
;   
; 2^16 - 1= 65535
;
    i=15
    pncodeI[i].num_reg   =16
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=4
    pncodeI[i].fdback[0] =11
    pncodeI[i].fdback[1] =13
    pncodeI[i].fdback[2] =14
    pncodeI[i].fdback[3] =16
;   
; 2^17 - 1= 131071
;
    i=16
    pncodeI[i].num_reg   =17
    pncodeI[i].len       =2L^pncodeI[i].num_reg - 1
    pncodeI[i].num_fdback=2
    pncodeI[i].fdback[0] =14
    pncodeI[i].fdback[1] =17
	i++
	return,i
end
