;+ 
;NAME:
;yfactor - compute Tdev for hot,cold load measurements
;SYNTAX: Tdev=yfactor(yhot,ycold,thot,tcold)
;ARGS:
;   yhot[n]: float  spectral density on hot load
;   ycold[n]: float  spectral density on cold load 
;   Thot    : float  temperature host load
;   Tcold   : float  temperature cold load 
;RETURNS:
;Tdev[n]: float   device temp vs freq
;
;DESCRIPTION:
;   Use the y factor measurement to compute the device under test temperature.
;The inputs are the spectral density measured on hot and cold loads.
;You must specify the temperature of the hot and cold load.
;   The equations are:
; let c,h be hot,cold, 
; let yc,yh be the meausured spectra, and g is the gain between loads and spectroeter/spectrum analyzer   
; (Tc + Td)*g =Yc
; (Th + Td)*g =Yh
;yh/yc= (Th + Td)/(Tc +Td)
; Yf=yH/Yc
;Yf*(Tc + Td)= (Th + Td)
;Td*(Yf-1) + Yf*Tc=Th
;
;Td=(Th - Yf*Tc)/(Yf -1)
; or
; Td=(Th - Yh*Tc/Yc)/(Yh/Yc-1)
; Td=[(Th*Yc - Yh*Tc)/Yc] / [ (yh-yc)/yc]       
; Td=(Th*Yc - Yh*Tc)/(yh - yc)
;-
function yfactor,yhot,ycold,thot,tcold
	
	Yf=Yhot/ycold
	return,(Thot - Yf*Tcold)/(Yf -1.)	
end
