;-
;NAME:
;hf_cplrtoxmitpwr: compute output pwr from coupler measurement
;SYNTAX: valKW=hf_cplrtoxmitpwr(cplrdbm,cablelossdb=cablelossdb,band=band)
;ARGS:
;clprdbm[n]: float    60db coupler  value read 
;KEYWORDS:
;cablelossdb: float   use this value for cable loss coupler to spectrum
;                     analyzer. default is 1.11 db 
;band       : int     either 5 or 8 Mhz.. def: 5
;RETURNS:
;valKW[n]   :float    output power
;
;Description:
;	This routine uses the coupler values and cable loss. It does
;not use the dummy load calorimetric measurements.
;-
function hf_cplrtoxmitpwr,cvaldbm,cablelossdb=cablelossdb,band=band
;
;
;
	if n_elements(band) eq 0 then band=5
	if n_elements(cablelossdb) gt 0 then begin
		cblLossDb=(cablelossdb gt 0)?-cablelossdb:cablelossdb 
	endif else begin
		cblLossDb=-1.11
	endelse
	cplrDb  =(band eq 5)?-61.6:(band eq 8)?-59.7: -999
	if cplrDb eq -999 then begin
		print,"Band is 5 or 8  mhz"
		return,-1
	endif
;
	xmitDbm=cvaldbm - cplrDb - cblLossDb  
	xmitKW =10.^((xmitDbm-30)*.1)*1e-3
	return,xmitKW
end
