;+
;NAME:
;hf_inpdbfclpr - input dbf,coupler values from ascii file
;SYNTAX:n=hf_inpdbfclpr(fname,txI)
;ARGS:
; fname: string   name of file to input
;RETURNS:
; n     : int  number of entries in txI
;txI[n] : {}   return info
;Description:
;  When measuring  the dbf drive versus rf coupler output, we generate
;files holding the data. Their format is:
;#
;# bringing up tx individually, each on sky
;# see x101/151029/dbf_cplr.pro
;#drive   spana
;tx 1
;-30   -6.7
;-25   -2.2
;-20   2.4
;-15   7.1
;-12   10.2
;-9    13.8
;-8    15.2
;-7    16.5
;tx 3
;-30    -12
;-25    -7.7
;-20    -3.6
;-15    3.96
;-12    5.3
;-9     8.6
;-8     9.9
;-7     11.2
;-6     12.5
; ..
; .. reset of tx
; This routine will read one of these files and return an array of txI structures holding the data.
;  txI will contain:
;	txI.txnum 
;   txI.dbf
;   txI.rfdbm
; This can then be used to plot the rf output pwr vs input drive.
;-
function hf_inpdbfcplr,fname,txI 
	nlines=readasciifile(fname,inp,comment="#")
	if (nlines le 0) then begin
		print,"No data/file :",fname
		return,-1
	endif

	a={$
	txnum: 0,$ 
      dbf: 0.,$
    rfdbm: 0.}
	txI=replicate(a,30*6)
	curTx=-1
	icur=0
	for i=0,nlines-1 do begin
		a=strsplit(inp[i],/extract)
		if (a[0] eq 'tx') then begin
			curTx=fix(a[1])
		endif else begin
			txI[icur].txnum=curTx
            txI[icur].dbf  = float(a[0])
            txI[icur].rfdbm= float(a[1])
		    icur++
		endelse
	endfor
    n=icur
	if n ne n_elements(txI) then begin
		if n eq 0 then begin
			txI=''
			return,0
		endif
		txI=txI[0:n-1]
	endif
	return,n
end
