;+
;NAME:
;hf_inpsynlog - input synth (amp,phase) logfile
;SYNTAX: n=hf_inpsynlog(yymmdd,logI,dir=dir,fname=fname)
;ARGS:
;yymmdd: long  date to input
;KEYWORDS:
;dir   : string  directory to use. def='/share/megs/phil/x101/hf/synlog/'
;fname : string  if present, ignore yymmdd,dir=, this will be complete
;                 dir/filename. 
;RETURNS:
;   n    : long    number of entries
; logI[n]: {}       array of hfsyn{} structs
; logI.action:
;              -1 bad
;               1 write amp,deg
;               2 read
;               3 rf on
;               4 rfoff
;               5 shutdown
;               6 pulseon
;               7 pulseOff
;               8 pulseEndUsr
;Description:
;	The gui that drives the hf phase's logs what it does.
;This routine reads in one of these log files into an array of structs.
;;  the returned struct contains:
;    s={ yyyymmdd:0L,$
;        hhmmss  :0l,$
;        yr      :0l,$
;        dayNum  :0l,$
;        secMid  :0l,$
;        action  :0 ,$ ; -1 bad:1 writAmpPh,2 reading,3 rfon,4 rfoff, 5 shutdown,
;        rfOn    :0 ,$ ; after this action executes
;        phDeg   :fltarr(6),$
;        Ampdbf  :fltarr(6) $
;    }
;-
;
function hf_inpsynlog,yymmdd,logI,dir=dir,fname=fname
;  struct to return
	s={ yyyymmdd:0L,$
		hhmmss  :0l,$
		yr		:0l,$
		dayNum  :0l,$
		secMid  :0l,$
		action  :0 ,$ ; -1 bad:1 writAmpPh,2 reading,3 rfon,4 rfoff, 5 shutdown,

		rfOn    :0 ,$ ; after this action executes
		phDeg   :fltarr(6),$
 		Ampdbf  :fltarr(6) $
	}
	maxEntry=10000l 
	logI=replicate(s,maxEntry)
;   codes for active  field
    actBad=-1
    actWrAmpDeg=1
    actRd  =2
    actrfOn=3
    actRfOff=4
    actshutdown=5
    actPulseOn =6
    actPulseOff=7
    actPulseEndUsr=8
	dpath='/share/megs/phil/x101/hf/synlog/'
	fnameAr=strarr(24)
	nfiles=0 
	if (n_elements(fname) eq 1) then begin
		fnameAr[0]=fname
		nfiles=1
	endif else begin
		dirL=(n_elements(dir) eq 1)?dir:dpath
		if (strmid(dirL,0,/rever) ne '/') then dirL+='/'
		yymmddL=(yymmdd lt 999999L)?yymmdd + 20000000L : yymmdd
		pathSpec=dirL + string(format='(i08)',yymmddL) + '*.log'
		fnameAr=file_search(pathSpec,count=nfiles)
	endelse
	ncur=0
	if nfiles eq 0 then return,0
	for ifile=0,nfiles-1 do begin
		nlines=readasciifile(fnameAr[ifile],inpl)
		if nlines eq -1 then begin
			print,"error opening file:",fnameAr[ifile]
			return,-1
		endif
		if nlines eq 0 then continue
;
; parse the lines
;
;            yyyymmdd     hh       mm     ss             act    on/off   ph,amp
;               1         2        3        4              5         6       7
	regExp='^([0-9]+) +([0-9]+):([0-9]+):([0-9]*)[^\|]*\|([^|]*)\|([^\|]*)\|(.*$)'	
	a=stregex(inpl,regExp,/extr,/sub) 
	iact=5
	ii=where(a[iact,*] ne 'CONFIG PULSE',cnt); skip config  pulse lines.. not amp,phase info
	if cnt ne nlines then begin
		if cnt ne 0 then a=a[*,ii]
		nlines=cnt
	endif
	if nlines eq 0 then continue
	i0=ncur
	i1=ncur+nlines-1
	
	logI[i0:i1].yyyymmdd=reform(long(a[1,*]))
	logI[i0:i1].hhmmss  =reform(long(a[2,*]))*10000L +   reform(long(a[3,*]))*100L +   reform(long(a[4,*]))  
	logI[i0:i1].yr=logI[i0:i1].yyyymmdd/10000L
    mon=(logI[i0:i1].yyyymmdd/100L) mod 100L 
    day=logI[i0:i1].yyyymmdd mod 100L 
	logI[i0:i1].daynum  =dmtodayno(day,mon,logI[i0:i1].yr)
    logI[i0:i1].secMid  =long( hms1_hr(logI[i0:i1].hhmmss)*3600 + .5)

	jj=lindgen(nlines) + i0
	ii=where(a[6,*] eq 'ON',cnt)
	if cnt gt 0 then logI[jj[ii]].rfOn=1

	logI[i0:i1].action  = actBad
	ii=where(a[iact,*] eq 'WRITING',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actWrAmpDeg
	ii=where(a[iact,*] eq 'READING',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actRd
	ii=where(a[iact,*] eq 'RF ON',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actRfOn
	ii=where(a[iact,*] eq 'RF OFF',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actRfOff
	ii=where(a[iact,*] eq 'SHUTDOWN',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actShutDown
	ii=where(a[iact,*] eq 'PULSE ON',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actPulseOn
	ii=where(a[iact,*] eq 'PULSE OFF',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actPulseOff
	ii=where(a[iact,*] eq 'PULSE END USER',cnt)
	if cnt gt 0 then logI[jj[ii]].action=actPulseEndUsr

;;	for jj=0,nlines-1 do print,jj," ",a[iact,jj]," ",logI[i0+jj].action
;
;
; 	now parse the ampphase
;             a0      p0        a1      p1       a2       p2 
    p1='([^,]*),([^\|]*)'
	sep="\|"
	regExp=p1 + sep + p1 + sep + p1 + sep + p1 + sep + p1 + sep + p1
	aa=stregex(reform(a[7,*]),regExp,/extr,/sub)
	for i=0,5 do begin
		logI[i0:i1].phDeg[i] =reform(float(aa[1+2*i,*]))
		logI[i0:i1].ampDbf[i]=reform(float(aa[1+2*i+1,*]))
	endfor
	ncur+=nlines
	
	endfor
	if ncur ne  n_elements(logI) then begin
		if ncur eq 0 then begin
			logI=''
		endif else begin
			logI=logI[0L:ncur-1]
		endelse
	endif
;
;	make sure sorted in time order
;
	tm=logI.yyyymmdd * 1d + logI.secMid/86400d
	ii=sort(tm)
	logI=logI[ii]
	return,ncur
end
