;+/
;NAME:
;hf_pltdbfvsclpr - plot rf output power vs rf drive.
;SYNTAX:istat=hf_pltdbfvsclpr(file,txI,ldate,hard=hard,ltitpre=ltitpre,har=har,var=var
;ARGS:
;file: string 	filename have the rfdrive and coupler output by tx
;ldate: string  'yymmdd' added to ps filename if hardcopy
;ARGS:
;hard: int      if set then output .ps file with name:
;                'pwroutVsDrv_yymmdd.ps'
;ltitPre:string  add this as a prefix to the title of the plot
;               tit=ldate + ltitPre + " Output pwr vs rf drive (dbm vs dbf).'
;har[2]: fltarr horizontal range for plot. def: -35,0. dbf
;var[2]: fltarr vertical  range for plot. def: -20,18 dbm
;RETURNS:
; istat:  int   -1 error input file
;txI[] : struct  data read from file by hf_inpdbfclpr()
;DESCRIPTION:
;	Read the dbf vs rf coupler data by tx. This routine calls
;hf_inpdbfclpr() with the specified filename
; 	It then plots the data rfclprOutput(dbm) vs dbfsynDrive.
;-
function hf_pltdbfvscplr,file,txI,ldate,hard=hard,ltitpre=ltitpre,har=har,var=var
    common colph,decomposedph,colph

	if n_elements(ltitpre) eq 0 then begin
		ltitpre=""
	endif
	harL=[-35,0]
	varL=[-20,18]
	if n_elements(har) eq 2 then  harL=har
	if n_elements(var) eq 2 then  varL=var
	n=hf_inpdbfcplr(file,txI)
	if (n le 0) then begin
		print,"error inputing file:",file
		return,-1
	endif
;
if keyword_set(hard) then begin
	pscol,'pwroutVsDrv_' + ldate + ".ps",/full
	font=1
endif
!p.multi=0
cs=1.4
ver,varl[0],varl[1]
hor,harl[0],harl[1]
sym=-1
colar=[1,2,3,4,5,7]
plot,[0,1],[0,1],/nodata,/iso,chars=cs,font=font,$
	xtit='rf drive [db below full scale]',$
	ytit='Coupler power [dbm]',$
	tit=ldate + ltitpre  + ' Output pwr vs rf drive (dbm vs dbf).'
;
for itx=1,6 do begin &$
	icol=colar[itx-1] &$
	ii=where(txI.txnum eq itx,cnt) &$
	tx1=txI[ii] &$
	tx1=tx1[sort(tx1.dbf)] &$
	oplot,tx1.dbf,tx1.rfdbm,psym=sym,col=colph[icol] &$
endfor
ln=12
xp=.04
scl=.8
csn=1.5
for i=1,6  do begin
	icol=colar[i-1]
	note,ln + (i-1)*scl,string(format='("tx",i1)',i),chars=csn,font=font,$
		col=colph[icol],xp=xp
endfor
dx=50
y0=-20
ls=1
for i=-80,-4,2 do begin
	oplot,[i,i+dx],[y0,y0+dx],col=colph[10],linestyle=ls 
endfor
if keyword_set(hard) then begin
	 hardcopy
	 x
	ldcolph
endif
end
