;+
;NAME:
;hf_pltsynlog - input synth (amp,phase) logfile and plotit
;SYNTAX: hf_pltsynlog,logI,nophase=nophase,tp=tp,tmtp=tmtp,cs=cs,font=font,tit0=tit0,sym=sym,$
;                        v1=v1,v2=v2,rfOn=rfOn,colar=colar 
;ARGS:
;logI[n]: {}      array of struct holding logI
;KEYWORDS:
;nophase:int     if set then don't plot the phase
;tp[m] : float   total power from ch 
;tmtp[m]:float   hour of data for tp samples
;cs    dir   : string  directory to use. def='/share/megs/phil/x101/hf/synlog/'
; v1[1]: float    ver scale for amp. def:-65 to 5
; v2[3]: float    ver scale for phase. def -10,360
; rfon[2]: float  rfon[0]. y val to start plotting rfOn.def=63
;                 rfon[1]. increment for rfon true. def=10.
; sym  : int      symbol to use def none=0
;RETURNS:
;   n    : long    number of entries
; logI[n]: {}       array of hfsyn{} structs
;-
;
pro hf_pltsynlog,logI,tp=tp,tmtp=tmtp,cs=cs,font=font,tit=tit,sym=sym,$
		v1=v1,v2=v2,v3=v3,tit0=tit0,rfOn=rfOn,colar=colar,lnrf=lnrf,nophase=nophase

	    common colph,decomposedph,colph

	useTp=(n_elements(tp) gt 2) and (n_elements(tmtp) gt 2)
	if n_elements(lnrf) eq 0 then lnrf=10
	if n_elements(tit0) eq 0 then tit0=''
	rfOnL=fltarr(2)
	case n_elements(rfon) of
	  0: rfOn=[-63.,10.]
	  1: rfOnL=[rfon,10.]
	else:rfOnL=rfOn[0:1]
	endcase

	useRfOn=rfOnL[0] gt -999 
	if n_elements(colar) lt 6 then colar=[1,2,3,4,5,7]
	if n_elements(cs)  eq 0 then cs=1.4
	if n_elements(sym)  eq 0 then sym=-1
	nl=n_elements(logI)
	csn=1.5
	lI=replicate(logI[0],nl*2)
	lI=reform(lI,2,nl)
	for i=0,nl-1 do begin
		lI[0,i]=logI[i]
		lI[1,i]=logI[i]
		if i le (nl-2) then lI[1,i].secMid=logI[i+1].secMid - .1
	endfor
	lI[1,nl-1].secMid=lI[0,nl-1].secmid
	lI=reform(lI,2*nl)
	nl=n_elements(lI)
	csn=1.5
	titD=string(format='(i08)',logI[0].yyyymmdd) + " "
	if n_elements(cs) eq 0 then  cs=1.8
	ver,-65,5
	if n_elements(v1) eq 2 then ver,v1[0],v1[1]
	hrL=lI.secMid/3600.
	!p.multi=[0,1,2]
	stripsxy,hrL,transpose(lI.ampdbf),0,0,/step,psym=sym,$
		chars=cs,font=font,colAr=colAr,$
		xtitle='hr of day',ytitle='db below full scale',$
	    tit=tit0 + ' synth drive amplitude'
	ls=2
	if useRfOn then begin 
    	oplot,hrl,lI.rfOn*rfOnL[1] + rfOnL[0] ,linestyle=ls,col=colph[3]
	endif
	ln=2
	xp=.05
	xpinc=.06
	for i=1,6 do begin
		lab=string(format='("tx",i1)',i)
		icol=colar[i-1]
		note,ln,lab,chars=csn,col=colph[icol],xp=xp + xpinc*(i-1),font=font
	endfor
	if useRfOn then $
	note,lnrf,'Rf on',xp=xp,chars=csn,font=font,col=colph[3]
		print,"usetp:",usetp
	if (usetp) then begin
		oplot,tmtp,tp,col=colph[2]
		note,lnrf+1*.8,"ch tp",xp=xp,chars=csn,font=font,col=colph[2]
	endif
	if keyword_set(nophase) then return	

	ver,-10,360
	if n_elements(v2) eq 2 then ver,v2[0],v2[1]
	stripsxy,hrL,transpose(lI.phDeg),0,0,/step,psym=sym,$
		chars=cs,font=font,$
		xtitle='hr of day',ytitle='phase [deg]',$
	    tit=tit0 + ' synth phase'
	return
end
