;+
;NAME:
;0imdoc - interference mon documentation.
;
;These routines will access the hilltop monitor rfi data. It uses a frontend ( antenna, amps, filter bank) as
;well as an hp spectraum analyzer to record the data. There are 20 bands covering 0 to 10 GHz. The system
;does a 1 minute peak hold at each band, cycling through all of the bands. Each spectra has 401 points
;(the bandwidths of the bands are not all the same).
;The band center frequencies are (in MHz):
;      70.0000      165.000      235.000      330.000      430.000      550.000      725.000      955.000      1075.00
;     1325.00      1400.00      2200.00      3600.00      4500.00      5500.00      6500.00      7500.00      8500.00 
;     9500.00
;To use these routines:
;
; idl
;@phil
;@iminit
;
;A days worth of data (at all freq) can be input with:
; iminpday,yymmdd,d  
;IDL> help,d,/st
; - the data is returned in the structure d
;** Structure <18c3dd8>, 6 tags, length=1982636, data length=1982634, refs=1:
;   YYMMDD          LONG            180101
;   NRECS           LONG              1203
;   FRQL            FLOAT     Array[19]               ..this contains a list of all bands in this data set
;   R               STRUCT    -> IMDREC Array[1203]   ..this holds the 1 minute peak hold spectra for the day 
;   CREC            INT              0
;   CFRQ            FLOAT          -1.00000
;
; The spectra are stored in r[]
;IDL> help,d.r,/st
;** Structure IMDREC, 2 tags, length=1648, data length=1648:
;   H               STRUCT    -> IMHDR Array[1]
;   D               FLOAT     Array[401]
;IDL> help,d.r.h,/st
;** Structure IMHDR, 11 tags, length=44, data length=44:
;   HDRMARKER       BYTE      Array[4]
;   HDRLEN          LONG                44
;   RECLEN          LONG               846
;   VERSION         BYTE      Array[4]
;   DATE            LONG           2021060
;   SECMID          LONG                43
;   CFRDATAMHZ      FLOAT           1325.00
;   CFRANAMHZ       FLOAT           1325.00
;   SPANMHZ         FLOAT           250.000
;   INTEGTIME       LONG                60
;  SRCAZDEG        LONG                -1
;
;You can select a single freq for the d struct with
; imgfrq,d,frq,d1freq
;   - where frq is one of the hilltop monitor freq bands
;   - d1frq is the same format at d but only contains the specified freq.
;
; To plot 1 spectra
; Use
; - implot,d.r[10] 
; or 
;   xfrq=immkfrq(d.r[10])
;   plot,xfrq,d.r[10].d
;
;A number of routines do not show up in the documetaton list.
;the table below is a short summary (until the more complete documentation is written]

;*DAY-----------------------
;imgfrq,{imday},frq,{imday}  - extract 1 freq subset from {imday}
;iminpday,yymmdd ,{imday}    - input the days worth of data
;imls                      - ls current im files online
;imopen  ,yymmdd ,lun      - open file, return lun in lun
;{imdrec}=imavg  ,{imday1frq} -return average rec for day. use imgfrq 1st
;*PLOTTING_-----------------
;implot  ,{imdrec}         - plot a an im data structure
;implloop,{imday} ,delay   - loop plotting imd with delay secs between each
;x[401]=immkfrq ,{imdrec}  - return x array holding the freq for the rec
;immktm  ,{imday} ,y       - return y array holding the times(hour)for the rec
;*PLOTTING SEQUENTIAL-------
;imfreq  ,{imday} ,freq    - freq to plot or -1 freq any freq
;imd     ,{imday} ,recnum  - plot recnumber
;imc     ,{imday}          - replot current rec
;imn     ,{imday}          - plot next rec of selected freq
;*MISC----------------------
;iminprec,lun,{imdrec}     - input the next record from the file
;imlin   ,{imday}          - convert data from db to linear scale
;imdb    ,{imday}          - convert data from linear to db
;tsys=imtsys,freq          - return tsys for this freq. 0 if not known
;davg=imavg(imday)         - compute average 1 freq, 1 day
;drms=imrms(imday)         - rms by channel 1 freq, 1 day
;
;*STRUCTURES----------------
;d:{imday}          - returned by iminpday
;d:yymmdd           - int
;d.nrecs            - how many records in day
;d.frql[int]        - list of frequencies for this day
;d.r[imdrec]        - array of data records. hdr and data
;d.crec             - current rec for plotting 1..nrecs
;d.cfrq             - current rec for plotting (or -1).
;d.r.d[12]          - data record 12, 401 points
;
;r:{imdrec}         - one integration in {imday}
;r.h                - {imhdr} header
;r.d                - [float 401]   data
;
;h:{imhdr}          - header routine for each record
;h.hdrMarker        - bytarr(4)
;h.hdrlen           - 0L
;h.reclen           - 0L
;h.versionj         - bytarr(4)
;h.date             - yyyyddd
;h.secMid           - 0L
;h.cfrDataMhz       - float
;h.cfrAnaMhz        - float
;h.spanMhz          - float
;h.integTime        - long, seconds
;h.srcAzDeg:        -   0L
;-
