;+
;NAME:
;masazswinginp - input an azimuth swing.
;SYNTAX: istat=masazswinginp(fnmI,fnum,azStart,azEnd,dat,azAr,freqAr,hwc=hwc)
;ARGS:
;  fnmI[n]: {}  hold info for files to search
; fnum    : long file number to process (one or more beams)
;azStart  : float   deg. starting az
;azEnd    : float   deg  ending az
;KEYWORDS:
;  hwc    :         if set then data has hardware winking cal. just return the cal Off data 
;Returns:
;istat    : -1 trouble
;         :  >0 number of spectra returned
;dat[nchan,nbms,npnts]:float spectra for swing
;azAr[npnts]  :        azimuth for each spectra
;freqAr[nchn] :    for the spectra
;DESCRIPTION:
;  input a mock  azswing, return spectra and azpos for each spectra.
;Also return the freqar.
;	The user inputs fnmI that holds the files to search for fnum.
;Fnum is the file number to use. there can be more than 1 file, if 
;multiple beams were used.
;	Azstart,azend are the start, stop azimuth to use for the swing.
;This should be in the order the data was taken,
;	On return, the spectra will be returned in increasing freq order
;(as will freqAr). The center channel will be interpolated across (to get rid of dc).
; 	The azAr and the order of the dat will be returned in increasing
;azimuth order..
; 12meter notes: 29mar22
; --> not needed since hdr_enc_az has the negative 51G
;  -reported azimuths are positive 0..359.000
;  -If you use a negative number for azstart or azend then 
;   is will map the measured azimuth to -180 to 360.
;   eg. If azstart < 0 then it will map az[0] to 0 deg to -az (assumed CW) 
;       if azEnd   <0  then it will search for az 0 in the points and all folloing points will az-360.
;   kludge until a change 12m program to return the  -180 to 360.
; - added nudump
; 
;-
function masazswinginp,fnmI,fnum,azStart,azEnd,dat,azAr,freqAr,hwc=hwc
;
; grab file for this file number
;
	usehwc=keyword_set(hwc)
	iifn=where(fnmI.num  eq fnum,nbms)
	if nbms eq 0 then begin
		print,"file number:", fnum," not found in fnmiAr"
		return,-1
	endif
	for ibm=0,nbms-1 do begin
		if usehwc then begin
			istat=masgethwcal(fnmI[iifn[ibm]],calI,bonar,b,/dcintp)
		    spcIntegration=.04
		endif else begin
			istat=masgetfile('',b,fnmI=fnmI[iifn[ibm]])
		    spcIntegration=b[0].h.cdelt5
		endelse
		if ibm eq 0 then begin
			ndump=b[0].ndump
			azpos=b.h.enc_azimuth
			if azStart lt 0 then begin
				ii=where(azpos lt azpos[0],cnt)
				if cnt gt 0 then begin
					i0=ii[0]-1
					azpos[0:i0]= azpos[0:i0]-360.
				endif
			endif
			if azEnd lt 0 then begin
				ii=where(azpos gt azpos[0],cnt)
				if cnt gt 0 then begin
					i0=ii[0]
					azpos[i0:*]= azpos[i0:*]-360.
				endif
			endif
			if azStart lt azEnd then begin
				iikp=where((azpos ge azStart) and (azPos lt azEnd),cnt)
			endif else begin
				iikp=where((azpos le azStart) and (azPos gt azEnd),cnt)
			endelse
			b=b[iikp]
			azpos=azpos[iikp]
	 		nchn=b[0].nchan
			nspc=n_elements(b)*ndump
			dat=fltarr(nchn,nspc,nbms)
;
;			interpolate az position to data time stamp
;
			azPostm=b.h.enc_time - 4*3600.
			dattm=findgen(nspc)*spcIntegration + spcIntegration/2. + $
					b[0].h.crval5 - 3600.*4.
			azAr=interpol(azPos,azPostm,datTm)
			freqAr=dblarr(nchn,nbms) &$
		endif else begin &$
			b=b[iikp] &$
	    endelse &$
		flip=(b[0].h.cdelt1 lt 0) &$
		freqAr[*,ibm]=(flip)?reverse(masfreq(b[0].h)):masfreq(b[0].h) &$
		dat[*,*,ibm]= reform(total(b.d,2)*.5,nchn,nspc)
;
; get rid of dc
;
		dat[nchn/2,*,ibm]=(dat[nchn/2l -1,*,ibm] + dat[nchn/2 + 1,*,ibm])*.5
		if flip then dat[*,*,ibm]=reverse(dat[*,*,ibm],1)
		; if azstart > azend flip data
	    if (azStart gt azEnd) then dat[*,*,ibm]=reverse(dat[*,*,ibm],2)
	endfor
	if azstart gt azend then azAr=reverse(azAr)
	return,nspc
end
