;+
;NAME:
;mascalvalspc - return the pol A/B  cal values/info for a mas struct over the freq
;
;SYNTAX: stat=mascalvalspc(hdr,calI,date=date)
;						
;
;ARGS:
;     hdr: {b.hdr}    header for spectra input via masget
;
;KEYWORDS:
; date[2]: intarray [year,dayNum] if provided, then compute the calvalues
;                      that were valid at this epoch. Default is to use date in hdr
;                    
;RETURNS:
; calI:{}         structure containing:
;                 calI.nchan          number of freq chan 
;                 calI.freq[nchan]    freq (mhz) for the data
;                 calI.npol           number of pols. if 4 pols, we just return a,b
;                 calI.flippped       if true then the hdr channels were flippped in freq.
;                                     (the cal values will be in the same order).
;                 calI.calVal[nchan,npol]:polA, b cal value for the freq range of spectra (in degK)
;
;      stat: int   .. -1 error, 0 got the values ok.
;
;DESCRIPTION:
;   Return the cal values in degrees K for the requested spectra. The 
;measured calvalues will be interpolated to the freq range of the specra.
;If the requested freq range is outside the cal values, then the cal values
;at the edge will be repeated.
;By default the date in the header is used to determine
;which cal values should be used. You can override this with the date
;keyword.
;	This routine can be used in place of mascalval() if you want the cal values
;across the freq band. This routine is normally called by mascalonoffspc().
;
;NOTE:
;mascalonoffspc,mascalsclspc, gen/calget1
;-
;history:
; 30dec22 - stole from mascalval()
;
function mascalvalspc,hdr,calI,date=date
;
	forward_function masisp12m
;
; retstat: -1 error, ge 0 ok
;
	usep12m=masisp12m(hdr[0])
  	nchan=fix(hdr[0].crpix1 - 1 + .5)*2
	nPol=hdr.num_pols 
	flipped=hdr[0].cdelt1 lt 0
	if n_elements(date) eq 0 then begin
;		warning this is utc.. so be careful on date cals change.
        year  =long(strmid(hdr.datexxobs,0,4))
        mon   =long(strmid(hdr.datexxobs,5,2))
        day   =long(strmid(hdr.datexxobs,8,2))
        date=[year,dmtodayno(day,mon,year)]
	endif
	calnum= (hdr.caltype eq 'hcorcal')?1:$ 
	        (hdr.caltype eq 'lcorcal')?0:$
	        (hdr.caltype eq 'hcal'   )?5:$ 
	        (hdr.caltype eq 'lcal'   )?4:$
	        (hdr.caltype eq 'hxcal'  )?3:$
	        (hdr.caltype eq 'lxcal'  )?2:$
	        (hdr.caltype eq 'h90cal' )?7:$
	        (hdr.caltype eq 'l90cal' )?6:-1
	if calnum eq -1 then begin
		print,"Unknown caltype in header:",hdr.caltype
		return,-1
	endif
;   if hybrid in then average pola, polB cals.
	hybrid =(((hdr.rfnum eq 5)  and (hdr.lbwhyb ne 0)) or  $
			((hdr.if1sel eq 4) and (hdr.hybrid ne 0))) and $
			(hdr.rfnum ne 17)
	if hdr.rfnum eq 100 then begin
		hybrid=0
		calnum=5
	endif
;	struct
	freq=masfreq(hdr[0]) 
	if (npol eq 1) then begin
		calI={nchan     : nchan,$
		  nPol      : npol,$;    assume it;s stokes I, avg cala,b
		  flipped   : flipped,$ ; 1 if band is flipped
		  freq      : freq,$
          exposure  : 0.,$      ; secs cal integration. filled in by calonoffspc
          edgeFract : fltarr(2),$; filled in by mascalonoffspc
		  mask      : intarr(nchan),$; filled in by mascalonoffspc 1-> used chan
		  ngdpnts   : 0l,$           ; number of good freq chan in mask (filled in by mascalonoffspc()
		  calval    : fltarr(nchan),$  ;  cal values
          cntsToK   : fltarr(nchan)}   ; conver spec to degK
	endif else begin
		calI={nchan     : nchan,$
		   nPol   : npol,$;   
		  flipped   : flipped,$ ; 1 if band is flipped
		  freq      : freq,$
          exposure  : 0.,$      ; secs cal integration. filled in by calonoffspc
          edgeFract : fltarr(2),$; filled in by mascalonoffspc
		  mask      : intarr(nchan),$; filled in by mascalonoffspc 1-> used chan
		  ngdpnts   : 0l,$           ; number of good freq chan in mask (filled in by mascalonoffspc()
		  calval    : fltarr(nchan,npol),$ ;  cal values	`
          cntsToK   : fltarr(nchan,npol)}   ; conver spec to degK
	endelse
;
	alfaBmNum=hdr.beam
    istat=calget1(hdr.rfnum,calnum,freq,calval,hybrid=hybrid,date=date,$
			alfabmnum=alfaBmNum,p12m=usep12m)
    calval=transpose(calval);   we want nchan,2 not 2,nchan
;
	if npol eq 1 then begin
		calval=(calval[*,0] + calval[*,1])*.5
	endif
	calI.calval=calval
	return,istat
end
