;+
;NAME:
;mascmppwrrms - compute total power exluding rfi via rms.
;SYNTAX: istat=mascmppwrrms(bar,tpI,fixblank=fixblank,norm=norm,startmask=startmask,$
;                   maskar=maskar,brms=brms,$
; )
;ARGS:
;	bar[N]:{}	array of data from masgetm
;KEYWORDS:
;fixblank: 	if set the correct for any blanked spectra so they
;           all have the standard integration time.
;norm    :  if set then normalize tp to median value
;startMask[nchan] : if supplied then this is the mask to begin with.
;                   we then add to this. 0-> skip,1-> used
;                   These points will always be excluded
;RETURNS:
;istat:	int 	0 ok, -1 error 
;tpi:{}		structure hold total power info
;maskAr[nchan,npol]: float mask used 
;brms :        return rms by chan if supplied
;-
;
function mascmppwrrms,bar,tpI,fixblank=fixblank,startMask=startMask,maskAr=maskAr,norm=norm,brms=brms

    nrows=n_elements(bar)
    ndumps=bar[0].ndump
    nspc=nrows*ndumps
    nchan=bar[0].nchan
	mjdtojd=2400000.5D
	deg=1
	maskInit=(n_elements(startmask) eq nchan)?startMask:intarr(nchan)+1
	iiSkip=where(maskInit eq 0,nskip) 
;
;   figure out number scans in file and where the cal and
;   data is
;
    brms=masrms(bar)
    x=findgen(nchan)/nchan
	npol=(brms[0].npol < 2)
;
    tpI={  hdr      : bar[0].h   ,$
           nspc     : nspc      ,$  ; number of spectra (600) 
           maskFract: fltarr(npol),$ ; fraction used for mask 
			rms     : fltarr(npol),$ ; median value of rms
               tp   : fltarr(nspc,npol)} ;tpSpc/median(tpSpc all spc)
	nblank=0L
	retMask=arg_present(maskAr)
	if retMask then begin
		maskar=fltarr(nchan,npol)
	endif
	if keyword_set(fixblank) and (not bar[0].blankCorDone) then begin
		fftaccumStd=max(bar.st.fftaccum)
		iiblnk=where(fftaccumstd ne bar.st.fftaccum,nblank)
		if nblank ne 0 then begin
			blankCor=fftaccumStd*1./((reform(bar.st.fftaccum,nspc))[iiblnk])
		endif
	endif
 	for ipol=0,npol-1 do begin
		coef=robfit_poly(x,brms.d[*,ipol],deg,gindx=gindx,ngood=ngood,$
				fpnts=fpnts,mask=maskInit)
	    ; fix up gindx to make sure any requested channels are not included
		if (nskip gt 0) then begin
			ok=intarr(nchan)
			ok[gindx]=1
			ok[iiskip]=0
			gindx=where(ok eq 1,ngood)
			fpnts=(ngood*1.)/nchan
		endif

		if retMask then maskAr[gindx,ipol]=1.
		tpI.maskFract[ipol]=fpnts
		if ndumps gt 1 then begin
			tpi.tp[*,ipol]= reform(total(bar.d[gindx,ipol,*],1)/ngood,nspc)
		endif else begin
			tpi.tp[*,ipol]= reform(total(bar.d[gindx,ipol],1)/ngood,nspc)
		endelse
;	
		if nblank gt 0 then tpI.tp[iiblnk,ipol]*=blankCor
		if keyword_set(norm) then $
			tpI.tp[*,ipol]=tpI.tp[*,ipol]/median(tpI.tp[*,ipol])
		tpi.rms[ipol] =median(brms.d[gindx,ipol])
		
	endfor
	tpI.hdr=bar[0].h
	return,0
end
