;+
;NAME:
;mascrossfit2d - 2d gauss fit to az,el strips done  on 12meter.
;SYNTAX: nfit=mascrossfit2d(cIAr,fitI,verb=verb,remMod=remMod,pol=pol,$
;                       zfitar=zfitar,$
;                        wait=wait,dbg=dbg,nosidelobe=nosidelobe,rot=rot,rembase=rembase)
;ARGS:
;cIAr[ncross]:{}  array of structs hold strip info for 2 strips in each cross
;                 see mascrossinp()
;KEYWORDS:230603_crosslist.tcl
;verb   :          if set then plot results each fit
;remMod :          if set then remove current model before fitting.(not yet implemented)
;pol    :  int     1->polA,2=polB.. anyother value (or default) is to add pols
;wait   :          if set and verb set, then wait for keystroke before moving to
;                  the next fit.
;nosidelobe: int   if set then don't exclude sidelobes from the fit. use this for weak sources.
;                  def is to loop fitting twice, where the 2nd loop excludes the sidelobe regions.
;rot    : int      if set then include rotation of beam ellipse in the fit. by default don't rotate.
;                  the 12m beam is not elliptical, rotating just causes problems. 
;                  (The 305m had an elliptical beam). 
;                  Warning: if  /rot used then returned results (widths,pnterr are along
;                  the rotated major,minor axis of the ellipse (not the az,el directions).
;rembase: int      if set then remove a linear  baseline from the az and el strips before the
;                  2d gaussfit is done. The fit coef[0] will no longer contain tsys (you'll need
;                  to look at the baseline fit info.
;RETURNS:
;  nfit  :  int      number masmon2dfits,
; fitI[nfit]: {}    array of structs holding fitinfo for each cross.
;zfitAr     :fltarr(pntsStrip,2,nbms,nfit) .. holds evaluated fit. If /rembase used then the
;                    baselines will have been removed from zfitAr
;mask[smpstrip*2,nbms]:int  mask to use for each strip (az,el) for each bm
;                     1-> use, 0 -> don't use
;
;DESCRIPTION:
; 	Perform a 2d gaussfit to the az,el strip pairs for each cross taken on the 12meter.
;The cross is done with constant rate great  circle offsets relative to the
;source we are  tracking. 
;
;Strip 1: az strip. constant great circle rate in az, while el offset (relative to sourcer)
;         doesn't change
;Strip 2: el strip. constant great circle rate in el, while az offset relative to source
;         does not change.
;Note: the fit  offsets are relative to the source. Since the source is moving  in az,el
;      the encoder el will change during the az  strip.
; -----------------------------------
;Some of the keyword options:
; pol=1,2  (default add pols)
;        Normally the routine averages polA,B prior  to fitting. 
;        If the pol= keyword is used then it ;will fit either polA(1) or polB(2).
; nosidelobe:  (def:loop twice excluding sidelobes locations)
;       By default the routine iterates the fit 2 times
;      1stloop: 2d gaussfit everything
;      2ndLoop: from first fit, find the beam center and width. Then compute where the sidelobes
;               are located. On the 2nd loop exclude these sidelobes from the fitting.
;       This is important for strong sources casA,cygA, crab.
;      For weak sources the sidelobes are not detectable. you should set /nosidelobe.
;      This will give you a better fit by including  the area of the sidelobes.
; rot:  (default no rotation).
;      if  /rot is set then the fit will include rotating the x,y axis to align with the 
;      major,minor axis of the elliptical beam (this was needed for the old 305m elliptical beam).
;      The bmwidths, pnterrs will then be relative to the ellipse axis rather than the az,el
;      directions.
;      The 12meter beam is circular, so the rotation angle is not well defined. Including /rot
;      will  cause the bmwidths and pnterrors to point in random directions (unless the beam
;      ends up becoming elliptical?..)
;
; ---------------------------------
; The fitI structure contains:
;
; help,fiti1,/st
; SRCNM          STRING '3C286'        ; srcname
; STRIPLEND      FLOAT  1.00000        ; strip length in deg
; PNTSTRIP       INT    600            ; samples in strip
; PATID          LONG   221500426      ; pattern id for cross
; TMST           LONG64 Array[2]       ; starttm (secs 1970) az,el strips
; OFFARD         DOUBLE Array[600, 2]  ; strip offset from source (deg) for az,el used for fitting
; ELOFF          DOUBLE Array[600, 2]  ; elevation  offset from middle of cross. used for elSlope in fit.
; AZREQCEND      DOUBLE 299.98128      ; central az for cross
; ELREQCEND      DOUBLE 60.868295      ; central el for cross
; NCOEF          INT    8              ; number of  coefin fit
; NGOODFITS      LONG   7              ; number of  good fits(in the Nbeams)
; REMOVEBASELINE INT    1              ; not 0 if we removed a linear baseline first from strips
; FITIBM         STRUCT -> <Anonymous> Array[7]; fitinfofor each beam used
; ---------------------------------
; info from each  frequency band fit (up to 7 bands (also called bms.. alfa holdover:)
; help,fiti.fitibm,/st
; Z               DOUBLE  Array[600, 2] ; z values used for az,el fits
;;                                        if baseline removes,then it is nolonger in z
; CFRMHZ          DOUBLE  8219.0000     ; center freq MHz for this band
; COEF            DOUBLE  Array[8]      ; coef from fit (see below)
; BLFIT           STRUCT  -> <Anonymous> Array[1]; blfit baseline fitinfo (see below(
; SIGCOEF         DOUBLE  Array[8]      ; sigma for each coef from the fit
; SIGFIT          DOUBLE  0.032022892   ; sigma from the fit
; CHISQ           DOUBLE  0.0010306230  ; chisq from the fit (but we don't give correct errors)
; TROUBLE         INT     0             ; if not 0 then fit didn't converge
; ---------------------------------
; if /rembase is used then a linear baseline will be removed from the az,el strips before the 
; the 2d gaussfit (so the 2d fit coef[0] will be close to 0). The linear fits info
; is stored in .blfit.az,el . You can extract the Tsys from thes structs.
;
; help,fiti.fitibm.blfit,/st
; AZ              STRUCT    -> <Anonymous> Array[1]  az baseline fit info (if used)
; EL              STRUCT    -> <Anonymous> Array[1]  el baseline fit info (if used)
; help,fiti1.fitibm.blfit.az,/st
; COEF            DOUBLE    Array[2]  bl=coef[0] + offarD[*,x]*coef[1]
; AVGVAL          DOUBLE    99.322503 avg value of fit
; and similar for ..blfit.el.. 
; You can reconstruct the baselinf from:j
;	azbaseline=coef[0] +fitI[i].offarD[*,0]*coef[1]
;	elbaseline=coef[0] +fitI[i].offarD[*,1]*ceof[1]
; The average baseline fit values (Tsys) are stored int
;   blfit.az.avgVal
;   blfit.ez.avgVal
; To get tsys you should probably average these to values.
; ---------------230603_crosslist.tcl------------------
;
;The 2dgaus fit is:
; z(x,y)= a0 + a1*exp[-xp^2/sigxp^2 - yp^2/sigyp^2] + a7*el
; 
; xp,yp have been rotated to align the x,y axis with the major,
;       minor axis of the possibly ellipitcal beam.
; note: rotation is only done if /rot is supplied. The 12m data shouldn't be rotated
;           (the beam is not elliptical)
; where:
; eg:
;	xm=(x-x0)
;	ym=(y-y0)
;  if /rot was supplied then x,y axis are rotated to the major, minor axis of the
;  elliptical bm
;  if /rot not supplied then the rotation is not done (th=0._
;
;	xp = xm*cos(th)  + ym*sin(th)
;	yp =-xm*sin(th)  + ym*cos(th)
;
; The fit parameters used in the fit equation are:
;	a0 - constant
;	a1 : amplitude
;	a2 : xoffset ,az coord direction offset is az units
;	a3 : yoffset ,el coord direction offset in el units
;	a4 : sigx^2  ,in prime coordinate system. See returned units
;	a5 : sigy^2  ,in prime coordinate system: see returned units
;   a6 : theta   ,rotate unprimed to primed aligned along ellipsoid of beam,Deg
;   a7 : elslope ,The el slope in amplitude units per el unit
;
;
; RETURNED UNITS:
;fitI[i].coef[0] = offset (or tsys) in input units. if /rembase is used then this will
;                  be close to 0 (baselines removed before 2dfit).Look at blfit info for Tsys.
;fitI[i].coef[1] = Amplitude of source deflection from fit.
;fitI[i].coef[2] = az error in az units. Note that since the strips
;                  are done az greatcircle strips, the az error in a great
;                  circle error.
;fitI[i].coef[3] = el error in el units.
;fitI[i].coef[4] = az fwhm from fit (we convert to fwhm from sigmas when
;                  returning the fit info.
;fitI[i].coef[5] = el fwhm from fit
;fitI[i].coef[6] = theta in deg. rotation angle to get az,el axis to 
;                  align with gaussian axis. will be 0 unless /rot is supplied.
;fitI[i].coef[7] = slope of baseline in el direction
;                  dz/del
;	
;	You should check fiti[i].trouble. if it is not zero, you should ignore the fit.
;
;Note:
;   the errors are computed at:
;  (x-x0)  (y -y0)
;: assume the strip is -10 to +10. No error would be 0
;: assume the peaks is at +3 in x (after the center) . then x0 =3
;: (x-x0) would put the peak back at zero offset.
;: so add these offsets to the current model to have the center of the strip
;  be at the peak.
;:-> Need to check this..
;
;30aug21: added patid to struct	
;09sep22: 
;  1.used weights to exclude sidelobes
;     - fit twice
;     - 1. first equal weights
;     - 2.find center,bmwd use to set weights for sidelobe to 0.
;  2. when doing robfit_poly for baseline, tsys, i was using mask to 
;     not include main beam and sidelobes. but fit routine only uses mask
;     on first iteration, after that i just keeps points within n sigma.
;    - change to use 1st 1/6, last 1/6 of strip
;       1 bm/ 4bms sidelobe,mainbm,sidelobe/ 1bm
;10mar23:added rot= keyword. only rotate if /rot is set. New default is no rotation
;14mar23:--> WARNINGS. the returned struct fitI  has changed. It now contains
;            fitI.removebaseline and
;            fiti.fitibm.blcoef(2,2) ({a0,a1},{az,el}) for linear baseline fits using fit
;-
;------------------------------------------------------------
; evaluate the full fit return zfit in case we fit with a  mask
; azoff[smpstrip,2]  deg
; eloff[smpstrip,2] deg
; elAr[smpstrips,2] deg
; 
function evalFit,x,y,elAr,coefAr
        fwhm2tosig2=1.D/(4.D*alog(2.)); fwhm^2 to sig^2
		a=coefAr
        fwhm=a[4]
        a[4]=fwhm*fwhm*fwhm2tosig2
        fwhm=a[5]
        a[5]=fwhm*fwhm*fwhm2tosig2
  a[6]=a[6]*!dtor
        costh =cos(a[6])
        sinth =sin(a[6])
        xm =  x - a[2]
        ym =  y - a[3]
        xp = xm*costh  + ym*sinth
        yp =-xm*sinth  + ym*costh
        sigX2=(1d-16 > a[4])
        sigY2=(1d-16 > a[5])
;       see if it contains linear elevation fit
        if n_elements(a) gt 7 then begin
            zret=a[0] + a[7]*elAr + a[1]*exp(-(xp*xp)/sigX2 - (yp*yp)/sigY2)
        endif else begin
            zret=a[0] + a[1]*exp(-(xp*xp)/sigX2 - (yp*yp)/sigY2)
        endelse
		return,zret
end
;
	
function mascrossfit2d,cIar,fitI,verb=verb,$
			remMod=remMod,pol=pol,wait=wait,zfitAr=zfitAr,nosidelobe=nosidelobe,$
			rot=rot,rembase=rembase,$
			mask=mask,$
			cfplot=cfplot,cfparms=cfparms,itmax=itmax,dbg=dbg,estAr=estar
;
    common colph,decomposedph,colph
	forward_function gsfit2d_12m


	userembase=keyword_set(rembase)
	use_mask=n_elements(mask) gt 0
	retEst=arg_present(estar)
	dbgL=keyword_set(dbg)
	ncross=n_elements(ciar)
	nbms=ciar[0].nbms
	smpstrip=cIar[0].smpstrip
	if use_mask then begin
		a=size(mask)
		case a[0] of
			1: nn=a[1]
			2: nn=a[1]*a[2]
			3: nn=a[1]*a[2]*a[3]
			else: begin
				print, "mask dimenstion must equal smpstrip*2*nbms"
				return,-1
				 end
		endcase
		mm=reform(mask,smpstrip,2,nbms)
		for ibm=0,nbms-1 do begin
			iiaz=where(mm[*,0,ibm] ne 0,cntaz)
			iiel=where(mm[*,1,ibm] ne 0,cntel)
			if (cntaz eq 0) or (cntel eq 0) then begin
			   print,"err:mask bm:",ibm," az,el nonzero points:",cntaz,cntel
			   return,-1
			endif
		endfor
	endif
	retZfit=arg_present(zfitAr)
	remModL=(keyword_set(remMod))?1:0
	fitForsidelobe=keyword_set(nosidelobe) eq 0
;	print,"mascrossfit2d. remMod:",remModL
	ddtor=!dpi/180d
;   model3A got xbbw: 10.1amin, sband: 39.9
	cfrAr=cIar[0].bmI.cfr
	fwhm=(cfrAr[0] lt 3000)?.665:.168 ; fhwm sband,xband from model3A
	sigtofwhm=2.*sqrt(2*alog(2.))
	ncoef=8
	est=dblarr(ncoef)	; estimates for start
	usepol=12
	if n_elements(pol) eq 1 then begin
		if (pol eq 1 ) or (pol eq 2)  then  usepol=pol
	endif

	blfit1={coef : dblarr(2),$ ; linear fit
           avgVal: 0d}         ; average value

    blfit={az:blfit1,$
		   el:blfit1}
	
;      struct for fit to each band

	aa={         z:dblarr(smpstrip,2),$ ; measured deflection used for fitting
            cfrMhz:  0d ,$              ;  center freq Mhz this band
            coef  :dblarr(ncoef),$      ; 
	        blfit :blfit  ,$             ; if baseline removed. linear fits usine offarD[*,0,1]
		   sigCoef:dblarr(ncoef),$      ;
		    sigFit: 0d,$
	        chisq : 0d,$
		  trouble : 0 } ; 0 converged, <--- see gsfit2d_12m for latest codes
;                      -1 chisq infinite,
;                      -2 flamdacount>30*10/flstep
;                      -3 iteration > iterationmax def. 20
;                      -4 alpha/c not finite.. probably 0 in partial deriv
;                       ...
;                    -10 ..pnt err too large (from this routine)
;   hold info for all fits one pattern
	a={     $; dim 2 is az strip then el strip
		srcNm    : '',$
		stripLenD: 0.,$ ;  length of strip in degrees
		 pntStrip: 0 ,$ ; samples in strip
		patId    : 0L,$ ; pattern id for this cross.
		tmSt     :lon64arr(2),$ ; sec 1970 start az,el strips
		;  offsets az for azstrip (great circle), eloffset for el strip 
		offArD   :dblarr(smpstrip,2),$; offset used from center of source for az el points
		elOff    :dblarr(smpstrip,2),$; need for linear fit to el. elReqCenD - elEncoder 
		;  warning.. do these two have the model included?
		azReqCenD:0d,$	;  az  center of cross (start of elstrip
	    elReqCenD:0d,$  ;  el  center of cross (end of azstrip)
		   ncoef : ncoef,$  ; number of coef.. 8
		   ngoodFits: 0l,$;  number of good fits in fitibm. 0 to nbms
		  removebaseline:0,$; if true then linear  baselines removed
		   fitIbm: replicate(aa,nbms)}; info from fit to each beam

	fitI=replicate(a,ncross)
;   we're assuming each call is the same source ..
	fitI.srcNm  =cIar.bmI[0].hdraz.object
	fitI.stripLenD=cIar[0].azlenD; assume all the same length
	fitI.pntStrip=cIar[0].smpstrip
	; for starting amplitude use peak val of inner 50%
	iiPk=lindgen(smpstrip/2 ) + smpstrip/4 
	elAr =dblarr(smpstrip,2) ; 
	if (retZfit) then zfitAr=fltarr(smpstrip,2,nbms,ncross)
	maxPntErrD=fitI[0].stripLenD*.3  ; if pnt err too big, flag as trouble
;
;   generate the offset array.
; 1. rate=length strip/smpstrip = distance/sample
; 2. start at len/2  + 1/2 rate  since data  avg is from middle of strip 
	azLend=ciar[0].azlend
	elLend=ciar[0].ellend
;   note cross moves at a constant greatcircle rate in az
    rate=azlend/smpstrip
	offaz=dindgen(smpstrip)*rate - azlend/2d + rate/2d
	offel=dindgen(smpstrip)*rate - azlend/2d + rate/2d
;   for linear fits exclude sidelobes and beam
;   strips are usually 6 bms, so keep 1/6 at start, end
	maskL=intarr(smpstrip) + 1; 
;   keep 1/6 on each edge 2*1/6=1/3  .. so exlude 2/3
	nexclude=long(smpstrip*2./3.)
	ii=lindgen(nexclude) + smpstrip/6
	maskL[ii]=0
	iiLinfit=where(maskL ne 0)
;
;  for baseline removal (or estimate tsys) ignore bm and possibly sidelobes
;
	m=intarr(smpstrip) +1
; if ignore sidelobes, fit 1st 3rd, last 3rd,else 1/6 each side
	nstp=(keyword_set(nosidelobe))?smpstrip/3:smpstrip/6
	n1=nstp
    n2=smpstrip-nstp
	m[n1:n2]=0
	iibl=where(m ne 0)
	bldeg=1
;
	if retEst then estAr=dblarr(ncoef,nbms,ncross)
	for ic=0,ncross-1 do begin
		; istr=0 az, istr=1 el
		; this is npnts,2
		xoff=dblarr(smpstrip,2)
		yoff=dblarr(smpstrip,2)
		xoff[*,0]=cIAr[ic].azoffd
		yoff[*,1]=cIAr[ic].eloffd
	    azStSec=tosecs1970(0,0,mjd=ciar[ic].bmI[0].hdraz.MJDXXOBS)
	    elStSec=tosecs1970(0,0,mjd=ciar[ic].bmI[0].hdrel.MJDXXOBS)
		stSec1970=[azstsec,elstsec]
		fiti[ic].azreqCenD=ciar[ic].crosscend[0] ; start of el strip.. 1/2 way
		fiti[ic].elreqCenD=ciar[ic].crosscend[1] ; end of az strip..1/2 way
		fitI[ic].offArD[*,0]= cIAr[ic].azoffd
		fitI[ic].offArD[*,1]= cIAr[ic].eloffd
		fiti[ic].tmSt     =stSec1970

		elAr=ciar[ic].elPosD -  ciar[ic].crossCenD[1]; el center of cross (end az strip) &$
		fitI[ic].elOff=elAr
	    fitI[ic].patId=ciar[ic].bmI[0].hdrAz.pattern_id
		fitI[ic].removebaseline=userembase
 		for ibm=0,nbms-1 do begin
			if (remmodL) then begin
				print,"Remove model not yet implemented.."
			    return,-1
				xoff+=criar[i].posI[0:n-1,*].logI.pl.corAzD*$
					cos(criar[i].posI[0:n-1,*].logI.pl.elReqD*ddtor)
		        yoff+=criar[i].posI[0:n-1,*].logI.pl.corElD
		    endif else begin
				; without this, the fits don't converge !!!
 				xoff+=1e-6
   				yoff+=1e-6
			endelse
			; use actual el offset from center of az strip 
;  do linear fit to az,el strip to get rid
;  of el dependence for max, tsys.
;
			z=dblarr(smpstrip,2)
			if usepol ne 12 then begin
				z[*,0]=ciar[ic].bmI[ibm].tpaz[*,usepol-1]
				z[*,1]=ciar[ic].bmI[ibm].tpel[*,usepol-1]
		    endif else begin
				z[*,0]=total(ciar[ic].bmI[ibm].tpaz,2)*.5  ; add pols
				z[*,1]=total(ciar[ic].bmI[ibm].tpel,2)*.5  ; add pols
			endelse
;
;	  fit  for linear baseline. 
;    use to estimate Tsys , or remove linear baseline
;
			iibl1=iibl
			for i=0,1 do begin
				if use_mask then begin
					m=intarr(smpstrip)
					m[iibl]=1
					ii=where(mm[*,i,ibm] eq 1,cnt)
			    	m[ii]+=1
					iibl1=where(m eq 2,cnt)
				endif
				coef=robfit_poly(fitI[ic].offArD[iibl1,i],z[iibl1,i],bldeg)
				if i eq 0 then begin
				   coefAz=coef
				   yfitAzOff=poly(fitI[ic].offArD[*,i],coef)
			       tsysAzAvg=yfitAzOff[smpstrip/2]
				endif else begin
				   coefEl=coef
				   yfitElOff=poly(fitI[ic].offArD[*,i],coef)
				   tsysElAvg=yfitElOff[smpstrip/2]
				endelse
			endfor
;  do we remove the baseleine?
		    if userembase ne 0 then begin
				fitI[ic].fitibm[ibm].blfit.az.coef=coefaz
			    fitI[ic].fitibm[ibm].blfit.az.avgval=tsysAzAvg
			    z[*,0]-=yfitAzOff
				fitI[ic].fitibm[ibm].blfit.el.coef=coefel
				fitI[ic].fitibm[ibm].blfit.el.avgval=TsysElAvg
				z[*,1]-=yfitElOff
;               new estimate should be 0
				TsysAzavg=0.
				TsysElavg=0.
			endif
			fitI[ic].fitIbm[ibm].z=z
			fitI[ic].fitIbm[ibm].cfrMhz=ciar[ic].bmI[ibm].cfr

;		for weak sources, the Tsys el change is greater than the source
;       to find the el strip offset, remove linear term and then find peak
;       for guassian 1st est. use peak az strip for the 2d peak val

		  	yaz=z[*,0]
		  	yel=z[*,1]
;           fit for el slope probably 0 if we removed baselines
		    yelfit=poly(elAr[*,1],coefel) ; get complete fit
;
		  	est[0]=(tsysAzAvg + tsysElAvg)*.5  ; guess for tsys
			iipkaz=iipk
		 	iipkel=iipk
			if (use_mask) then begin
				for i=0,1 do begin 
					m=intarr(smpstrip)
					m[iipk]=1
					ii=where(mm[*,i,ibm] eq 1,cnt)
					m[ii]+=1
				    ii=where(m eq 2,cnt)
					if i eq 0 then begin
						iipkaz=ii
					endif else begin
						iipkel=ii
					endelse
				endfor
			endif
			if (userembase) then  begin
		  		xmax  =max(yaz[iiPkaz],ixmax) ;amplitudeq.. we already remvoed baseline
		  	    ymax  =max(yel[iiPkel],iymax)
			endif else begin
			    xmax  =max((yaz -yfitAzOff)[iipkAz],ixmax)
                ymax  =max((yel -yfitELOff)[iipkEl],iymax)
			endelse
		  	est[1]=xmax                     ; just use az, el has tsys variation
	 	  	est[2]=xoff[iiPkAz[ixmax],0]  ; x offset x peak
		  	est[3]=yoff[iiPkEl[iymax],1]  ; y offset y peak
		  	est[4]=fwhm						 ; az fwhm
		  	est[5]=fwhm                      ; el fwhm
		  	est[6]=0.                        ; the rotation  
;          for el dependence use both az,el strips
		  	deg=1
			if (use_mask) then begin
				m=intarr(smpstrip,2)
				m[iiLinfit,*]=1
				ii=where(mm[*,*,ibm] eq 1,cnt)
				m[ii]+=1
			    ii=where(m eq 1,cnt)
		  		coefelAll=robfit_poly(elAR[ii],z[ii],deg)
			endif else begin
		  		coefelAll=robfit_poly(elAR[iiLinfit,*],z[iiLinFit,*],deg)
			endelse
		    yelfitAll=poly(elAr,coefelAll) ; get complete fit
;          for el dependence use both az,el strips
 		  	est[7]=coefelAll[1]            ; use slope from both stripselstrip, more variation
			if retEst then estAr[*,ibm,ic]=est
		  	if keyword_set(cfplot) then begin
				 hor
			 	ver
			 	!p.multi=0
		  	endif 
;
;			loop twice.. first time weights=1
;           2nd time, use pnterr, bmwidths to weight the sidelobes to 0
;
			weights=dblarr(smpstrip*2) + 1.
			ii=lindgen(smpstrip*2)
			if (use_mask) then begin
				ii=where(mm[*,*,ibm] eq 1,cnt)
			endif
		  	fitCoef=gsfit2d_12m(xoff[ii],yoff[ii],z[ii],elAr[ii],est,zfit=zfit,$
		       covar=covar,sigCoef=sigCoef,chisq=chisq,sigma=sigma,itmax=itmax,$
			   rot=rot,$
			    trouble=trouble,weights=weights[ii],cfplot=cfplot,cfparm=cfparms)
			
		  	if keyword_set(cfplot) then key=checkkey(/wait)
			; check pnterro
			if ((abs(fitcoef[2]) gt maxPntErrd) or (abs(fitcoef[3])  gt maxPntErrd)) then begin 
				trouble=-10
			endif
		  	fitI[ic].fitIbm[ibm].trouble = trouble
			if use_mask then zfit=evalFit(xoff,yoff,elAr,fitcoef)
		 	zfit=reform(zfit,smpstrip,2)
;
;			if (0) then begin
;		   2nd fit iteration
			if (trouble eq 0) and (fitForSidelobe) then begin
				weights=dblarr(smpstrip,2) + 1.	
;               make sure we round correctly for neg numbers.
				sgn=(fitcoef[2] lt 0)?-1:1				
				azoffSmp=long(smpstrip*fitcoef[2]/ciar[ic].azLenD + .5*sgn)
				sgn=(fitcoef[3] lt 0)?-1:1				
				eloffSmp=long(smpstrip*fitcoef[3]/ciar[ic].elLenD + .5*sgn)
				azfwhmSmp=long(smpstrip*fitcoef[4]/ciar[ic].azLenD + .5)
				elfwhmSmp=long(smpstrip*fitcoef[5]/ciar[ic].azLenD + .5)
;               sidelobes centers:  +/- 1.5 fwhm from peak
;               width of sidelobe fwhmsmp
;                        az strip
				icen=smpStrip/2 - azOffsmp; index pk az
			    isdlb1= ((icen -      azfwhmsmp*2)   > 0) < (smpstrip -1)
			    isdlb2= ((icen -      azfwhmsmp*1)  > 0 )  < (smpStrip -1)
				weights[isdlb1:isdlb2,0]=0.
			    isdlb1= ((icen +      azfwhmsmp*1) > 0)  < (smpstrip-1)
			    isdlb2= ((icen +      azfwhmsmp*2) > 0)  < (smpstrip-1)
					
				weights[isdlb1:isdlb2,0]=0.
;                        el strip
				icen=smpStrip/2 - elOffsmp; index pk az
			    isdlb1= ((icen -      elfwhmsmp*2)   > 0) < (smpstrip -1)
			    isdlb2= ((icen -      elfwhmsmp*1)   > 0 ) < (smpstrip -1)
				weights[isdlb1:isdlb2,1]=0.
			    isdlb1= ((icen +      elfwhmsmp*1) > 0)  < (smpstrip-1)
			    isdlb2= ((icen +      elfwhmsmp*2) > 0)  < (smpstrip-1)
				weights[isdlb1:isdlb2,1]=0.
;
			    est=fitcoef
		  	    fitCoef=gsfit2d_12m(xoff[ii],yoff[ii],z[ii],elAr[ii],est,zfit=zfit,$
		           covar=covar,sigCoef=sigCoef,chisq=chisq,sigma=sigma,itmax=itmax,$
				   rot=rot,$
			       trouble=trouble,weights=weights[ii],cfplot=cfplot,cfparm=cfparms)
		     	if keyword_set(cfplot) then key=checkkey(/wait)
		  		fitI[ic].fitIbm[ibm].trouble = trouble
			    if use_mask then zfit=evalFit(xoff,yoff,elAr,fitcoef)
		  		zfit=reform(zfit,smpstrip,2)
			endif
;		  endif
		  	!p.multi=[0,1,3]
		  	cs=2.0
			font=0
		  	if trouble ne 0 then begin
				if dbgL then print,'trouble:',trouble,',fitcoef:',fitcoef
		  	endif else begin
		    	fitI[ic].fitIbm[ibm].coef=fitCoef
		    	fiti[ic].fitIbm[ibm].sigCoef=sigcoef
		    	fiti[ic].fitIbm[ibm].chisq  =chisq
		    	fiti[ic].fitIbm[ibm].sigFit  =sigma
		    	if (retZfit) then zfitAr[*,*,ibm,ic]=zfit
		  	endelse
		  	if (keyword_set(verb)) then begin
;              src cfr:  az,el, yymmdd,hh:mm:ss, az strip
				a=fromsecs1970(fiti[ic].tmst[0])
				ldate=string(format='(i06)',a[1] mod 1000000l)
				ltm=fisecmidhms3(long(hms1_secmid(a[0])))
				tit=string(format=$
					'(" 2dGsFit: ",a," cfr:",f6.1," az,el:(",i3,",",i2,")",1x,a,1x,a)',$
						   fitI[ic].srcnm,fitI[ic].fitibm[ibm].cfrMhz,long(ciar[ic].crosscenD),ldate,ltm)
				ltype=' az strip '
;
;			plot, az strip
;			
				hor
		    	ver
				ytit=(ciAr[ic].units eq 3)?"Deg K":'totPwr'
				plot,xoff[*,0],z[*,0],chars=cs,$
					xtit='az offset [deg]',ytit=ytit,$
					tit=tit + ltype
				oplot,xoff[*,0],zfit[*,0],col=colph[2]
				flag,fitCoef[2],linestyle=2,col=colph[2]
				ln=2
				scl=.7
				xp=.04
				note,ln      ,"az strip data",chars=csn,font=font,xp=xp,col=colph[1]
				note,ln+1*scl,'2dFit to azstrip',chars=csn,font=font,xp=xp,col=colph[2]
				lin=string(format='("azErr:",f7.2," Amin")',fitCoef[2]*60.)
				note,ln+2*scl,lin,chars=csn,font=font,xp=xp,col=colph[1]
;
;			plot, el strip
;			
				a=fromsecs1970(fiti[ic].tmst[1])
				ldate=string(format='(i06)',a[1] mod 1000000l)
				ltm=fisecmidhms3(long(hms1_secmid(a[0])))
				ltype=' el strip '
				tit=ltm + ltype 
				plot,yoff[*,1],z[*,1],chars=cs,$
					xtit='el offset[deg]',ytit=ytit,$
					tit=tit
				oplot,yoff[*,1],zfit[*,1],col=colph[3]
				flag,fitCoef[3],linestyle=2,col=colph[3]
				ln=12	
				note,ln      ,"el strip data",chars=csn,font=font,xp=xp,col=colph[1]
				note,ln+1*scl,'2dFit to elstrip',chars=csn,font=font,xp=xp,col=colph[3]
				lin=string(format='("elErr:",f7.2," Amin")',fitCoef[3]*60.)
				note,ln+2*scl,lin,chars=csn,font=font,xp=xp,col=colph[1]
;
;     plot both vs el offset of cross
;
				hor,min(elar),max(elar)
				ver,min(z),max(z)
				tit=(trouble ne 0 )?"TROUBLE":"fit ok"
				tit="data,fits vs cross elCenter. " + tit
				plot,elar[*,0],z[*,0],chars=cs,tit=tit,$
					ytit=ytit,$
					xtit='El offset from cross center'
				oplot,elar[*,1],z[*,1],col=colph[1] 
				oplot,elar[*,0],zfit[*,0],col=colph[2]
				oplot,elar[*,1],zfit[*,1],col=colph[3]
                ln=22
				note,ln      ,'Az strip fit',chars=csn,font=font,xp=xp,col=colph[2]
				note,ln+1*scl,'El strip fit',chars=csn,font=font,xp=xp,col=colph[3] 
	      	endif 
		  	if (keyword_set(verb) and ( keyword_set(wait)) ) then begin
		  		key=checkkey(/WAIT)	
				if key eq 's' then stop
		  	endif
	  	endfor ; end ibm loop
		ii=where(fitI[ic].fitIbm.trouble eq 0,cnt)
		fitI[ic].ngoodFits=cnt
	endfor     ; end ic cross loop
;
	return,ncross
end
