;+
;NAME:
;masgetfiles - input a set of files
;SYNTAX: istat=masgetfiles(fnmIAr,bar,avg=avg,median=median,
;               float=float,double=double,fnmAr=fnmAr,blankcor=blankcor,$
;				tpAr=tpAr,remdc=remdc) 
;ARGS:
;  fnmIAr[nfiles]: {} from masfileslist. files to input
;KEYWORDS: 
;     avg:      if keyword set then return the average of each file rather than the individual recs.
;               It will average over nrows and ndumps per row.
;               the returned data structure will store the averaged
;               spectra as a float. use /double if you want a double
;				see also : median
;  median:      if set then return the median value for the file. This
;               reads the entire file into memory so you need room to
;               hold it.
;  float:       the averaged data should be returned as float.
;				if any averaging is done then the default is float.
;  double:      The data should be returned as doubles.
; fnmAr[nfiles]: string if present then ignore fnmIAr and use fnmAr to find the files
;                it should hold the complete filenames.:w

;blankcor:   if set then do  the correction for blanking. The 
;              blanked spectra will be corrected to have the same number of 
;              spectral accumulations as the unblanked spectra.
;             If /avg,/ravg,or /median then blankcor is also enabled.
; remdc  :    If set then interpolate across the dc channel in the spectra
;RETURNS:
;  istat: 1 got all the requested files
;       : 0 found no files
;       : -1 did not correctly read one file
;  bAr[n,nfiles]: {}   array of structs holding the data
; tp[n*m,2,nfiles]: float array holding the total power for each spectra/sbc
;              m depends on the number of spectra per row
;descRet{}:   if supplied and filename or fnmi is present, then the file descriptor will
;             be left open and returned in descRet
;DESCRPTION:
;	Input a set of files. This is normally used to input files from different
;frequency bands that were taken simultaneously. The files must have the same
;format and the same number of rows.
;	You would normally used fnmIAr from masfilelist() to specify the files.
;If just have a list of filenames (with directories) then use the fnmAr= keyword
;
;-
function masgetfiles,fnmIAr,bAr,avg=avg,median=median,$
                float=float,double=double,fnmAr=fnmAr,$
 				blankcor=blankcor, tpAr=tpAr,remdc=remdc 
;
	useTp=arg_present(tpar)
	usefnmar=(n_elements(fnmAr) gt 0)
	nfiles=(usefnmar)?n_elements(fnmAr):n_elements(fnmIAr)
	medianL=keyword_set(median)?1:0
	avgL  =keyword_set(avg)?1:0
	useDouble=keyword_set(double)
	if (medianL) then begin
		avgL=0
	endif
	blankcorL=(keyword_set(blankcor))||avgL || medianL
	start=1
	for ifile=0,nfiles-1 do begin
	    fname=(usefnmAr)?fnmAr[ifile]:fnmIAr[ifile].dir + fnmIAr[ifile].fname
		if useTp then begin
	 		istat=masgetfile(desc,b,avg=avg,median=median,float=float,double=double,$
				  filename=fname,blankcor=blankcor,tp=tp,remdc=remdc)
		endif else begin
	 		istat=masgetfile(desc,b,avg=avg,median=median,float=float,double=double,$
				  filename=fname,blankcor=blankcor,remdc=remdc)
		endelse
		if (istat  ne 1) then begin
			print,"masgetfile returned status:",istat," for file ",fname 
			return,-1
	    endif 
		if start then begin
			nrecs=n_elements(b)
			ndump=b[0].ndump
			npol=b[0].npol
			bar=replicate(b[0],nrecs,nfiles)
			if useTp then begin
			    a=size(tp)
			    case 1 of
				   a[0] eq 1: tpar=(useDouble)?dblarr(a[1],nfiles):fltarr(a[1],nfiles)
				   a[0] eq 2: tpar=(useDouble)?dblarr(a[1],a[2],nfiles):fltarr(a[1],a[2],nfiles)
			       else: begin
						print,"Bug masgetfiles. tp dimension from masgetfile should be 1 or 2. was:",a[0]
				        return,-2
				        end
				endcase
			endif
			start=0
		endif
		bar[*,ifile]=b
		if usetp then begin
		    a=size(tp)
		    case 1 of
			   a[0] eq 1: tpar[*,ifile]=tp
			   a[0] eq 2: tpar[*,*,ifile]=tp
			 endcase
		endif
	endfor
	bar=reform(bar) ; incase first dim is 1
;   
	return,1
end
