;+
;NAME:
;masmon2dplot1 - plot 1 fit from 2d fits
;SYNTAX: masmon2dplot1,fiti,ibm,pwr=pwr,lab=lab,remtsys=remtsys
;ARGS:
;fitI: {}      structure returned from mascrossfit2d()
;ibm : int     index (0..6) for bm to plot in fitI.fitibm[ibm]. 
;KEYWORDS:
;pwr :         if set then data units are spectrometer pwr. Def: degK
;lab : string  add to title of plot 
;var[2]: float  set vertical scale. def: autoscale
;remTsys:    if set then remove constant Tsys value before plotting
;DESCRIPTION
; 	This routine is used by masmon2dfits()
;-
pro masmon2dplot1,fitI,ibm,pwr=pwr,lab=lab,var=var,remtsys=remtsys

    common colph,decomposedph,colph

	remTsysL=(keyword_set(remTsys))?1:0
	if n_elements(lab) eq 0 then lab=''
	hor
	useVar=n_elements(var) eq 2
	if useVar then begin
		ver,var[0],var[1]
	endif else begin
	    ver
	endelse
	!p.multi=[0,1,3]
	cs=2.2
	csn=1.5
	font=1
;   plot az strip
	a=fromsecs1970(fiti.tmst[0])
	ldate=string(format='(i06)',a[1] mod 1000000l)
	ltm=fisecmidhms3(long(hms1_secmid(a[0])))
	tit=string(format=$
		'(" 2dGsFit: ",a," cfr:",f6.1," az,el:(",i3,",",i2,")",1x,a,1x,a,a)',$
						   fitI.srcnm,fitI.fitibm[ibm].cfrMhz,$
			long([fiti.azreqcend,fiti.elreqcend]),ldate,ltm,lab)
	Tsys=fitI.fitibm[ibm].coef[0]
	T0=(remTsys)?Tsys:0
	ltype=' az strip '
	ytit=(keyword_set(pwr))?"totPwr":"Deg K"
	xoff=fiti.offard[*,0]
	zdat=fiti.fitibm[ibm].z -T0
    zfit=gsfit2deval_12m(fiti) -T0
    plot,xoff,zdat[*,0],chars=cs,$
			xtit='az offset [deg]',ytit=ytit,$
			tit=tit + ltype
	oplot,xoff,zfit[*,0,ibm],col=colph[2]
	flag,fiti.fitibm[ibm].coef[2],linestyle=2,col=colph[2]
	ln=2
	scl=.7
	xp=.04
	note,ln      ,"az strip data",chars=csn,font=font,xp=xp,col=colph[1]
	note,ln+1*scl,'2dFit to azstrip',chars=csn,font=font,xp=xp,col=colph[2]
	lin=string(format='("azErr:",f7.2," Amin")',fiti.fitibm[ibm].Coef[2]*60.)
	note,ln+2*scl,lin,chars=csn,font=font,xp=xp,col=colph[1]
	if (remTsysL) then begin
		note,ln+3*scl,"Tsys:"+string(format='(f5.1)',Tsys),chars=csn,font=font,xp=xp
	endif
;
;			plot, el strip
;			
	xoff=fiti.offard[*,1]
	a=fromsecs1970(fiti.tmst[1])
	ldate=string(format='(i06)',a[1] mod 1000000l)
	ltm=fisecmidhms3(long(hms1_secmid(a[0])))
	ltype=' el strip '
	tit=ltm + ltype 
	plot,xoff,zdat[*,1],chars=cs,$
			xtit='el offset[deg]',ytit=ytit,$
			tit=tit + ltype
	oplot,xoff,zfit[*,1,ibm],col=colph[3]
	flag,fitI.fitibm[ibm].coef[3],linestyle=2,col=colph[3]
	ln=12	
	note,ln      ,"el strip data",chars=csn,font=font,xp=xp,col=colph[1]
	note,ln+1*scl,'2dFit to elstrip',chars=csn,font=font,xp=xp,col=colph[3]
	lin=string(format='("elErr:",f7.2," Amin")',fiti.fitibm[ibm].coef[3]*60.)
	note,ln+2*scl,lin,chars=csn,font=font,xp=xp,col=colph[1]
;
;
;     plot both vs el offset of cross
;
	elar=fiti.eloff
	hor,min(elar),max(elar)
	if not useVar then ver,min(zdat),max(zdat)
	trouble=fiti.fitibm[ibm].trouble
	tit=(trouble ne 0 )?"TROUBLE":"fit ok"
	tit="data,fits vs cross elCenter. " + tit
	plot,elar[*,0],zdat[*,0],chars=cs,tit=tit,$
			ytit=ytit,$
			xtit='El offset from cross center'
			oplot,elar[*,1],zdat[*,1],col=colph[1] 
			oplot,elar[*,0],zfit[*,0,ibm],col=colph[2]
			oplot,elar[*,1],zfit[*,1,ibm],col=colph[3]
     ln=22
     note,ln      ,'Az strip fit',chars=csn,font=font,xp=xp,col=colph[2]
	 note,ln+1*scl,'El strip fit',chars=csn,font=font,xp=xp,col=colph[3] 
	 empty
	return
end
