;+
;NAME:
;masmonstripch - stripchart recording of total power
;masmonstripch,bsg=bsg,num=num,projid=projid,date=date,maxpnt=maxpnt,$
;        rec=rec,v1=v1,$
;        rdstep=rdstep,pltDelay=pltDelay,sub=sub,win=win,polList=polList,$
;		 median=median,maskar=maskar,colar=colar,noappbm=noappbm,tming=tming,dirI=dirI
;
; -> Warning.. i kludged this documentation from masmon and an older version of masstripch
;              I need to verify that i've updated the documentation correctly
; ARGS:
;KEYWORDS:
;    bsg: string beam,band,group to monitor. Format is bBsSgG where:
;                B =0..6 is the beam
;                S =0..1 is the band (0=1450 band, 1=1300 band)
;                G =0..1 is the group.
;                default:'b0s0g0'
;    num: int    the file number to start with. (The default is the most recent)
; projid: string project id (first part of filename) to monitor. The default
;                is the most recent one written.
; date  : long   The date (in the filename) to start monitoring. The
;                default is the current date. Entering "*" will allow any date.
;                The format is yyyymmdd or "*".
;   polList:int     pols to use. 1,12,-1 (all pols a,b def)
;   maxpnt: long    max number of points to display at once. default: 3600
;   v1[2] : float   min,max value for top plot
;   sub   :         if set then subtract running mean
;   v1[2] : float   min,max value for top plot
;   sub   :         if set then subtract running mean
;pltDelay: float    number of seconds to wait after each plot. Use this
;                   to slowly scan a file that already exists.
;   win   : long    window number to plot in. Default is 0
;median   :         if set, use the median to compute the power
;maskar[nchn]:int   if provided then use to mask off chan
;                   with rfi. use chan where maskAr[] > 0
;freqexcl[2,n]:float freq ranges to exclude when computing total power.
;                    1st dim is min,max freq, You can then have n different bands.
;colar[2] :int      color indices to use for plotting polA,B
;                   def: 1-white,2-red
;                   1-black,2-red,3-green,4=blue,5=yellow,6=
;DESCRIPTION:
;   The routine makes a stripchart recording of the total power and power
;difference polA-polB. It will step through the data file displaying
;up to MAXPNT pnts on the screen. When this value is reached, the plot will
;start scolling to the left. When the end of file is hit, the routine
;will wait rdDelay seconds (default of 2 second) and then try to read
;any new data in the file. This allows you to monitor data as it is 
;being taken. If you are scrolling through a file offline, use PLTDELAY
;to slow down the plotting rate (if it is too fast). At the end of the file
;hit any key and the enter q to quit (see below).
;
;   The top plot is the 0lag total power. The units are linear in power and the
;definition is measured/optimum power (for statistics of 3/9level sampling).
;   v1[2] : float   min,max value for top plot
;   sub   :         if set then subtract running mean
;You can change the vertical scale with the v1[min,max] keyword or from the
;menu displayed you hit any key. The line colors correspond to the 8 
;subcorrelators available on the interim correlator.
;
;   You can stop the plotting by touching any key on the keyboard.
;A menu will be presented that lets you modify some parameters and then
;continue. The menu is:
;
;Cmd CurVal    function
;
; -->  PLOTTING:
; p   1234       pols to plot (1..4)
; h   low high   set horizontal plot range ..no args --> autoscale
; v   low high   set vertical   plot range ..no args --> autoscale
; delay secs     secs to delay between plots..
;
; -->  POSITIONING:
; bsg  b0s0g0     beam,band,grp to use (change all at once)
; bm   0          beam to plot
; band 0          band to display (0 = 1450, 1=1300)
; d    20081011   date to use. First number of data displayed
; num  00801      number.. file number to display
; r       1       position to row. maxRows:  99
; l    (all)      list files this date (all --> all dates)
;
; -->  MISC:
; hdr            display last header read
; s      0       step mode. 1-on,0-off
; z              stop in procedure (for debugging)
; q              to quit
; x              quit leaving the current file open. return description in desc keyword
;otherKeys       continue plotting
;
;
;EXAMPLES:
;1. monitor the online datataking:
;   masmonstripch,bsg='b0s1g0',proj=proj
;
;2. set fewer points per plot for better resolution. Set the top vertical
;   scale to .8,2. 
;   masmonstripch,desc,maxpnt=600,v1=[.8,2]
;
;3. If you want to position to a different filenumber:
;   hit any character
;   num  newFileNumbe r 
;
;4. If you want to monitor a file offline, with no wait between
;   updates, and 500 points plotted:
;   masmonstripch,bsg=bsg,proj=proj,maxpnt=500,v1=[.5,3]
;
;5. Do the same thing but wait 1 second between plots and read 200 points at
;   a time:
;   masmonstripch,bsg=bsg,proj=proj,lun,maxpnt=200,v1=[.5,3],pltDelay=1
;
;NOTE:
;   You can change the size of the plot by expanding or contracting the
;plot window. The plot will rescale itself.
;-
; history
; ----------------------------------------------------------------------------
; opennewfilech
; 0 ok, 
; -1 could not open
function opennewfilech,curFI,newFI,desc
;
    desc1=''
    istat=masopen(newFI.fdir+newFI.fbase,desc1)
    if (istat eq 0 ) then begin
        if n_tags(desc) gt 1 then masclose,desc
        desc=desc1
        curFI=newFI
    endif else begin
        print,"Error openning file:",newFI.fbase
    endelse
    return,istat
end
; ----------------------------------------------------------------------------
; displayMenuch:  display menu
;
;
;           Cmd CurVal   Function
;           -->  PLOTTING
;            p   n        pols to plot 1,2,1234
;            h   h1 h2    hor min,max
;            v   v1 v2    ver min,max
;            -->  POSITIONING:
;            bsg  b6s1g0     beam,band,grp to use
;            bm   0..6 0     beam 0..6
;            band 0,1        band 0,1
;            d    20081013   move to first file of date
;            num  01103      move to this file number
;            r      41       position to row. maxRows: 241
;            l    (all)      list files this date (all --> all dates)
;           -->  MISC
;            hdr          print current hdr
;            s   n        stepMode s 1 on,s 0 off
;            d   -        debug.. just stop in routine
;            q   -        quit
;            x   -        quit leaving file open

pro displayMenuch,key,prgI,desc,curFI,b,dirI=dirI,noappbm=noappbm
;
    prgI.dbgStop=0
	needRestart=0
    print,'Cmd CurVal    function'
    print,''
    print,'-->  PLOTTING:'
    lab=string(format='(" p     ",i4,"       pol to use (1..4,-1=all)")',prgI.pollist)
    print,lab
    print," h    low high   set horizontal plot range ..no args --> autoscale"
    print," v    low high   set vertical   plot range ..no args --> autoscale"
    lab=string(format='(" delay " ,f5.2,"  plot delay secs")',$
                    prgI.secsToDelayPlot)
    print,lab
;
    print,''
    print,"-->  POSITIONING:"
    lab=string(format='(" bsg  ", a,"         beam,band,grp to use")',curFI.bsg)
    print,lab 
    bm=strmid(curFI.bsg,1,1)
    lab=string(format='(" bm   ", a,"              beam (0..6) to use")',bm)
    print,lab 
    band=strmid(curFI.bsg,3,1)
    lab=string(format='(" band  ", a,"             band to use (0=1450,1=1300)")',band)
    print,lab 
    lab=string(format=$
            '(" d    ", a,"       move to first file of date")',curFI.ldate)
    print,lab
    lab=string(format=$
            '(" dn   ", a," ",a," move to date and filenum")',curFI.ldate,curFI.lnum)
    print,lab
    lab=string(format='(" num  ", a,"          number of file to use")',curFI.lnum)
    print,lab
    lab=string(format=$
            '(" r    ",i4,"           row of file to position. maxRows:",i4)',$
            desc.curRow,desc.totRows);
    print,lab
    print," l    (all)          list files this date (all --> all dates)"

    print,''
    print,"-->  MISC:"
    print,' cur            track cursor position'

    print,' hdr            print current header'
    lab=string(format=$
            '(" s   ",i4,"       step mode. 1-on,0-off")',prgI.stepmode)
    print,lab
    print,' z              stop in procedure (for debugging)'
    print,' q              to230623_crosslist.tcl quit'
    print,' x              to quit leaving file open'
    print,'otherKeys       continue plotting'
    inpstr=''
    read,inpstr
    toks=strsplit(inpstr,' ,',/extract)
    cmd=toks[0]
;
    switch cmd of
    'p':begin
        validPol=[-1,1,2,3,4,12,123,1234,13,14,124,134,23,234,34]
        polList=(n_elements(toks) lt 2) ? -2 : toks[1]
        ii=where(pollist eq validPol,cnt)
        if cnt gt 0 then begin
            prgI.polList=polList
        endif else begin
            print,"enter p -1,1,2,3,4,1234, etc for pols to plot"
        endelse
        break
        end
    'h':begin
        if n_elements(toks) eq 1 then begin
            hor
        endif else begin
            if (n_elements(toks) eq 3) then begin
                hor,toks[1],toks[2]
            endif else begin
                print,"Enter: h  hormin hormax"
            endelse
        endelse
        break
        end
    'v':begin
        if n_elements(toks) eq 1 then begin
            ver
        endif else begin
            if (n_elements(toks) eq 3) then begin
                ver,toks[1],toks[2]
            endif else begin
                print,"Enter: v  vermin vermax"
            endelse
        endelse
        break
        end

   ;   plot delay

    'delay':begin
        if n_elements(toks) ne 2 then begin
            print,'Enter delay secsToDelay'
        endif else begin
            prgI.secsToDelayPlot=toks[1]
        endelse
        break
        end
;
    'z':begin &$
        prgI.dbgStop=1
        return 
        end

    ;   bsg: go use

    'bsg':begin
        if n_elements(toks) ne 2 then begin
            print,'Enter bsg  b0s0g0 for beam,band,group to use'
        endif else begin
            bsg=toks[1]
            istat=masmostrecentfile(curFI.proj,curFI.ldate,bsg,curFI.lnum,$
                          newFI,flist=flist,dirI=dirI,noappbm=noappbm)
            if istat eq 1 then begin
                istat=opennewfilech(curFI,newFI,desc)
                prgI.dataAvail=0
				needRestart=1
            endif else begin
                print,"no files found for " + bsg + "for this date and number"
            endelse
        endelse
        break
        end

      'bm':begin
        if (n_elements(toks) ne 2) || ((toks[1] lt 0) or (toks[1] gt 6)) $
            then begin
            print,'Enter bm  0..6 beam to use'
        endif else begin
            bm=toks[1]
            bsg=curFI.bsg
            strput,bsg,bm,1 
            istat=masmostrecentfile(curFI.proj,curFI.ldate,bsg,curFI.lnum,$
                          newFI,flist=flist,dirI=dirI,noappbm=noappbm)
            if istat eq 1 then begin
                istat=opennewfilech(curFI,newFI,desc)
                prgI.dataAvail=0
				needRestart=1
            endif else begin
                print,"no files found for " + bsg + "for this date and number"
            endelse
        endelse
        break
        end

      'band':begin
        if (n_elements(toks) ne 2) || ((toks[1] lt 0) or (toks[1] gt 1)) $
            then begin
            print,'Enter band  0..1  band to use'
        endif else begin
            band=toks[1]
            bsg=curFI.bsg
            strput,bsg,band,3 
            istat=masmostrecentfile(curFI.proj,curFI.ldate,bsg,curFI.lnum,$
                          newFI,flist=flist,dirI=dirI,noappbm=noappbm)
            if istat eq 1 then begin 
                istat=opennewfilech(curFI,newFI,desc)
                prgI.dataAvail=0
				needRestart=1
            endif else begin
                print,"no files found for " + bsg + "for this date and number"
            endelse
        endelse
        break
        end

;   date: postion to start of date
;   dn    date num together

    'dn':
    'd' :begin
            if (cmd eq 'd') then begin 
                if n_elements(toks) ne 2 then begin
                    print,'Enter d  yyyymmdd for date to position to'
                    break
                endif
                lnum='*'
                oldest=1
            endif else begin
                if n_elements(toks) ne 3 then begin
                    print,'Enter dn  yyyymmdd number for date filenumber to position to'
                    break
                endif
                lnum=string(format='(i05)',toks[2])
                oldest=0
            endelse
            lldate=toks[1]
            istat=masmostrecentfile(curFI.proj,lldate,curFI.bsg,lnum,$
                         newFI,flist=flist,oldest=oldest,dirI=dirI,noappbm=noappbm)
            if istat eq 1 then begin
                istat=opennewfilech(curFI,newFI,desc)
                prgI.dataAvail=0
				needRestart=1
            endif
        break
        end
;
;   num: postion to this file number
;
    'num':begin
        if n_elements(toks) ne 2 then begin
            print,'Enter n   number position to this file number'
        endif else begin
            lnum=string(format='(i05)',toks[1])
            istat=masmostrecentfile(curFI.proj,curFI.ldate,curFI.bsg,lnum,$
                          newFI,flist=flist,dirI=dirI,noappbm=noappbm)
            if istat eq 1 then begin
                istat=opennewfilech(curFI,newFI,desc)
                prgI.dataAvail=0
				needRestart=1
            endif else begin
                print,'file Number:'+lnum +" does not exists for date:",$
                    curFI.ldate
            endelse
        endelse
        break
        end

;
    'l':begin
        ldate=curFI.ldate
        ldate=((n_elements(toks) eq 2) && (toks[1] eq 'all')) $
              ?"*":curFI.ldate
        istat=masmostrecentfile(curFI.proj,ldate,curFI.bsg,"*",$
                    flist=flist,dirI=dirI,noappbm=noappbm)
        if istat eq 1 then begin
            for i=0,n_elements(flist)-1 do begin
                l=strpos(flist[i],"/",/reverse_offset,/reverse_search)
                print,strmid(flist[i],l)
           endfor
        endif
        break
        end

;       position to row

        'r':begin
            if n_elements(toks) lt 2 then begin
                print,'Enter: r  rownumber'
            endif else begin
                if (n_tags(desc) lt 2) then begin
                     print,'No file currenlty open.. no positioning allowed'
                endif else begin
                    irow=toks[1] -1
                    irow=(irow>0)<(desc.totRows-1)
                    desc.curRow=irow
                    prgI.dataAvail=0
				    needRestart=1
                endelse     
            endelse
            break
            end
        'q':begin
            print,'quitting...'
            prgI.done=1
            prgI.dataAvail=0
            break
            end
        'x':begin
            print,'quitting leaving file open...'
            prgI.done=2
            prgI.dataAvail=0
            break
            end
        's':begin
            if n_elements(toks) lt 2 then begin
                print,'Enter s 0 or 1 .. turn off,on step mode'
            endif else begin
                prgI.stepmode=(toks[1] eq 0) ? 0 : 1
            endelse
            break
            end
       'hdr':begin &$
              help,b.h,/st          ; display header
             break
             end
       'cur':begin
            print,"track cursor. LeftMouseButton:MarkPosition, RightMouseButton:done"
            i=rdcur(icur)
            break
            end
        else: break
    endswitch
    prgI.restart=needRestart
    print,'continuing...'
    return
end
; -----------------------------------------------------------------
; compute the power
pro cmppwr,b,usea,useb,tp,TsysN,median=median,usemask=usemask,iigd=iigd

	tp=fltarr(2)
	useMed=keyword_set(median)
	ndump=b.ndump
	if useA then begin
		if ndump gt 1 then begin
		  if useMask then begin
			tp[0]=(usemed)?median(b.d[iigd,0,*]):mean(b.d[iigd,0,*]) 
		  endif else begin
			tp[0]=(usemed)?median(b.d[*,0,*]):mean(b.d[*,0,*]) 
		  endelse
		endif else begin
		  if useMask then begin
			tp[0]=(usemed)?median(b.d[iigd,0]):mean(b.d[iigd,0]) 
		  endif else begin
			tp[0]=(usemed)?median(b.d[*,0]):mean(b.d[*,0]) 
		  endelse
		endelse
		if tsysN[0] lt 0. then tsysN[0]=tp[0] 
		tp[0]/=tsysN[0]
	endif
	if useB then begin
		if ndump gt 1 then begin
		  if useMask then begin
			tp[1]=(usemed)?median(b.d[iigd,1,*]):mean(b.d[iigd,1,*]) 
		  endif else begin
			tp[1]=(usemed)?median(b.d[*,1,*]):mean(b.d[*,1,*]) 
		  endelse
		endif else begin
		  if useMask then begin
			tp[1]=(usemed)?median(b.d[iigd,1]):mean(b.d[iigd,1]) 
		  endif else begin
			tp[1]=(usemed)?median(b.d[*,1]):mean(b.d[*,1]) 
		  endelse
		endelse
		if TsysN[1]  lt 0. then TsysN[1]=tp[1]
		tp[1]/=tsysN[1]
	endif
	return
	end
; -----------------------------------------------------------------
;         
pro masmonstripch,bsg=bsg,num=num,projid=projid,date=date,maxpnt=maxpnt,$
        rec=rec,v1=v1,$
        rdstep=rdstep,pltDelay=pltDelay,sub=sub,win=win,polList=polList,$
			median=median,maskar=maskar,colar=colar,noappbm=noappbm,tming=tming,dirI=dirI,$
		    freqExcl=freqExcl
;
;   
    common colph,decomposedph,colph
    forward_function checkkey
    !x.style=!x.style or 1
    !y.style=!y.style or 1

    prgI={$
       dbgStop : 0        ,$ ; if true then stop in masmon after checkkey
       stepMode: 0        ,$ ; if one then menu each plot
       polList : -1       ,$ ; by default use all
       dataAvail: 0       ,$ ; 1 if data avail to plot
           done : 0       ,$; 1--> exit, 2--> exit leaving file open
        noavg   : 0       ,$; if 1 then don't average
		restart : 0       ,$; if they jumped around, need to reinitialize buffer
    secsToSleepFile: 2.    ,$; secs to sleep after ls -lt and no new file
    secsToDelayPlot: 0.     $; secs to 
    }


	desc=''
    bsgL='b0s1g0'
    if n_elements(bsg) gt 0 then bsgL=bsg
    lnum=(n_elements(num) gt 0)?string(format='(i05)',num):'*'
    if n_elements(projid) eq 0 then projid='*'
    if n_elements(date) eq 0 then  begin
        a=bin_date(systime(0))
        date=a[0]*10000l + a[1]*100 + a[2]
    endif
    ldate=(size(date,/type) ne 7)?string(format='(i8)',date) :date
    prgI.polList=(n_elements(polList) gt 0)?polList:-1
	if n_elements(colar) ne 2 then colar=[1,2]
	   xdimdef=640
    ydimdef=512
    wpixwintouse=4
    nlines=2L               ; a,b 
    if (n_elements(maskAr) gt 0) then begin
        useMask=1
        iiuse=where(maskAr gt .01,ngd)
    endif
	useFreqExcl=(n_elements(freqExcl) ge 2 )
	bandCfrCur=-1
;
    if not keyword_set(sub) then sub=0
    if n_elements(rdstep) eq 0 then rdstep=1L
    ; hardcode to 1 for now
    rdstep=1L
    if n_elements(maxpnt) eq 0 then maxpnt=3600L
    if n_elements(pltDelay) eq 0 then  pltDelay=0
	prgI.secsToDelayPlot=pltDelay
    maxpntl=long(maxpnt)
    if (maxpntl mod rdstep) ne 0 then  begin
        n=long(maxpntl)/long(rdstep)
        maxpntl=(n + 1) * rdstep
    endif
    maxpntl2=maxpntl*2L
    if keyword_set(sub) then begin
        v1def=[-.01,.01]
    endif else begin
        v1def=[.9,1.2]
    endelse
    if n_elements(v1)  ne  2 then v1=v1def
	ver,v1[0],v1[1]
	;
;   pixwin setup
;
    if n_elements(win) eq 0 then  begin
        win=0
        window,0,xsize=xdimdef,ysize=ydimdef
    endif else begin
        if win eq 4 then begin
            message,$
        'window 4 is use for the internal pixwin,pick another window...'
        endif
        wset,win
    endelse
    xdim=!d.x_size
    ydim=!d.y_size
    wpixwin=-1                  ; not allocated yet

	usemask=(n_elements(maskar) gt 0)
	iigd=(useMask)?where(maskAr gt .01):0
	TsysN=[-1d,-1d]			; use first point to define Tsys
	if prgI.polList eq -1 then begin
		useA=1
		useB=1
	endif else begin
		l=string(prgI.polList)
		useA=strpos(l,'1') ne -1
		useB=strpos(l,'2') ne -1
	endelse
    istat=masmostrecentfile(projid,ldate,bsgL,lnum,curFI,dirI=dirI,noappbm=noappbm)
    if istat ne 1 then begin
       if n_elements(bsg) eq 0 then begin
          bsgL='b0s0g0' ; try other band
          istat=masmostrecentfile(projid,ldate,bsgL,lnum,curFI,dirI=dirI,noappbm=noappbm)
       endif
       if istat ne 1 then begin
          print,'no files found for requested range'
          return
       endif
    endif
    masclose,/all
    istat=masopen(curFI.fdir+curFI.fbase,desc)
    prgI.done=(istat lt 0)
	prgI.restart=1
	while (prgI.done eq 0 ) do begin
restart:
	   if prgI.restart then begin
	      TsysN=[-1d,-1d]			; use first point to define Tsys
	      npts=0
    	  d=fltarr(maxpntl2,nlines)
    	  !p.multi=0
    	  x=findgen(maxpntl2)
          i1=0L                   ; start of dataset index
          i2=0L                   ; end of dataset   index
	      firstTm=1
          xinc1=.04
          xinc2=.03
          xp=.02
    	  ln2=17
          ln1=2
          n=rdstep
          labpol=['A ','B ']
          csn=1.2
          ch=checkkey()                   ; flush any chars here
		  prgI.restart=0
		endif
        istatget=masget(desc,b)
        prgI.dataAvail=(istatget eq 1)
        ; hit eof ..
        if ( not prgI.dataAvail)   then begin
            ; see if file has grown since last open
            istatupd=masupdfsize(desc)
            if istatupd eq 1 then continue  ; file grew.. read again
            istat1=masmostrecentfile(curFI.proj,"*",curFI.bsg,"*",newFI,$
                    curFI=curFI,dirI=dirI,noappbm=noappbm)
            ; moved to a new file
            if (newFi.fbase ne curFI.fbase) then begin
                istat=opennewfilech(curFI,newFI,desc)
                if istat lt 0 then wait,prgI.secsToSleepFile
            endif else begin
;                print,'waiting..'
                wait,prgI.secsToSleepFile
                if keyword_set(tming) then begin
                lab=systime(0)
                print,lab + ": After secsToSleepFile"
                endif
            endelse
        endif
        key=checkkey();
        if keyword_set(tming) then begin
        	 lab=systime(0)
        	print,lab + ": After checkKey, key:",key
        endif
        if (key ne '') or (prgI.stepMode) then begin
            displayMenuch,key,prgI,desc,curFI,b,dirI=dirI,noappbm=noappbm
			if (prgI.done ne 0) then goto,done
			if prgI.restart then goto,restart
            if prgI.dbgStop then begin
            print,"stopping in masmon (for debugging).  .continue to continue"
            stop
            prgI.dbgStop=0
            endif
        endif
        if prgI.dataAvail ne 1 then continue

		if (useFreqExcl) then begin
			if (bandCfrCur ne b[0].h.crval1) then begin
				freq=masfreq(b[0].h)
				nchan=b[0].nchan
				ok=intarr(nchan) +1
				f0=min(freq)
				f1=max(freq)
			    nsets=n_elements(freqexcl)/2
				for iset=0,nsets-1 do begin
					if (((freqExcl[0,iset] ge f0) and  (freqExcl[0,iset] le f1)) or $
					    ((freqExcl[1,iset] ge f0) and  (freqExcl[0,iset] le f1))) then begin
						 ii=where((freq ge freqExcl[0,iset]) and (freq le freqExcl[1,iset]),cnt) &$
						 if cnt gt 0 then ok[ii]=0
					endif
				endfor
				iigd=where(ok eq 1,cnt)
				usemask=1
				if cnt eq 0 then begin
				   print,"--> freqExcl params removes all channels from band"
				   print,"--> freqExcl mask for this band turned off"
				   stop
				   usemask=0
				endif
				bandCfrCur=b[0].h.crval1
			endif
		endif
;
		cmppwr,b,useA,useB,tp,TsysN,median=median,usemask=usemask,iigd=iigd
		npnt=1L
        if (i2 + npnt) ge (maxpntl2) then begin
           nnkeep=i2-i1 - npnt + 1
           if nnkeep gt 0 then begin
              d[0L:nnkeep-1L,*]=d[i2-nnkeep+1:i2,*]
              x=x+i2-nnkeep+1L
              i2=nnkeep-1L
           endif else begin
              x=x+i2-nnkeep+1L
              i2=0L
		      firstTm=1
           endelse
           i1=0L
;               d=reform(shift(reform(d,maxpntl*nlines,/overwrite),-npnt),$
;                   maxpntl,nlines,/overwrite)
;               i1=i1-npnt
        endif
        if (i2 eq 0) and firstTm then begin
           d[i2:i2+npnt-1,*]= reform(tp,npnt,nlines)
           i2=i2+npnt-1l
		   firstTm=0
        endif else begin
           d[i2+1:i2+npnt,*]= reform(tp,npnt,nlines)
           i2= i2+npnt
        endelse
        if (i2 ge maxpntl) then i1=i2-maxpntl+1L
        if i2 gt 1 then begin &$
;
;           write into the pixwin        first
;
          if (!d.x_size ne xdim) or (!d.y_size ne ydim) or $
              (wpixwin lt 0)  then begin
                xdim=!d.x_size
                ydim=!d.y_size
                window,wpixwintouse,/pixmap,xsize=xdim,ysize=ydim 
		    	wpixwin=!d.window
          endif
          wset,wpixwin
;
          if (keyword_set(sub)) then begin
             mean2=total(d[i1:i2,*],1)/(i2-i1+1.)
;            print,npnt,i1,i2,mean8
             y=d[i1:i2,*]
             for k=0,nlines-1 do y[*,k]=y[*,k]-mean2[k]
          endif else begin
             y=d[i1:i2,*]
          endelse
		  secMid=long(b[0].h.crval5 - 4*3600L + .5)
		  if secMid lt 0 then secMid +=86400L
          lab=string(format=$
               '("TP ",a,"(AST) scan:",i9," az,el:",f6.1,1x,f4.1," file:",a)',fisecmidhms3(secMid),$
				b[0].h.scan_id, b[0].h.azimuth,b[0].h.elevatio,curFI.fbase)
          plot,x[i1:i2],y[*,0],$
                   xtitle='sample',ytitle='power',$
                   title=lab,/nodata
          if (useA) then oplot,x[i1:i2],y[*,0],col=colph[colar[0]]
          if (useB) then oplot,x[i1:i2],y[*,1],col=colph[colar[1]]

;           pixwin copy     
;
          wset,win
          device,copy=[0,0,xdim,ydim,0,0,wpixwin]
          if prgI.secsToDelayPlot gt 0. then wait,prgI.secsToDelayPlot
        endif 
    endwhile
done: return
end
