;-
;NAME:
;mastsysp12m - compute tsys from winking calfiles
;SYNTAX: stat=mastsysp12m(yyyymmdd,projId,fileNum,tsysI,lineOut,$
;                verbose=verbose)
;ARGS:
;yyyymmdd: long	date for files to process
;projid  : string projid for files to process
;fileNum : long   filenumber of date,projid to process. -1-> use last
;KEYWORDS:
; verbose:        if set the output info to  stdout
;RETURNS:
;stat	: long	  0 ok , -1 error
;tsysI  : {}      structure holding the tsys info computed
;lineOut[]: strarr array holding the tsys output info for each
;                  freq band computed
;DESCRIPTION:
;	Compute tsys for p12m  data taken with the hardware winking cal. The user
;supplies the data,projid, and filenumber (or -1 to search). The routine then finds the
;files for this specification that were taken.
;
;	The data should be taken with the hardware winking cal.
;The processing  for each band of beam is:
;	1. input  the entire files using  masgethwcal().
;   2. call mascalonoff() to compute the calonoff
;   3. call mascalscl() using the caloff  data to compute Tsys
;      for each cal off spectra.
;   4. compute the average Tsys for all of the calOff spectra.
;-
; compute tsys for alfa using winking cal
;
function  mastsysp12m,yyyymmdd,projid,filenum,tsysI,lineOut,$
			verbose=verbose,edge=edge
;
;   this is the order they come out  band[0] (1450) then band 1(1300)
;
	band=1
	grp=0
	fileNumL=fileNum
	lineOut=''
	
	if filenum eq -1 then begin
		nfiles=masfilelist('',fnmI,proj=projid,band=band,grp=grp,yymmdd=yyyymmdd,/appbm)
		filenumL=max(fnmI.num)
		ii=where(fnmI.num eq filenumL,cnt)
		fnmI=fnmI[ii]
		nfiles=n_elements(fnmI)
	endif else begin
		nfiles=masfilelist('',fnmI,proj=projid,band=band,grp=grp,yymmdd=yyyymmdd,/appbm,$
							num=fileNumL)
	endelse
;
;  make sure all are winking cal
;
	if (nfiles eq 0) then begin
		print,"mastsysp12m: no files matching fnum:",fileNumL," "+projid+" ",yyyymmdd
	    return,-1
	endif

	hwcalport=2
	istat=masfilesum('',sumI,fnmI=fnmI[0])
	if (sumI.h.calsrc ne hwcalport) then begin &$
		print,"yymmdd,proj,num not hwcal:",yyyymmdd,projid,filenumL
		return, -1
	endif
;
;   let mastsyshwcal do all the work
; 
	istat=mastsyshwcal('',tsysI1,fnmIar=fnmI,verb=verb,edge=edge,rmsDigAr=rmsDigAr)
	a={  cfr : 0.,$
		 bw  : 0.,$
 	 	bm  : 0,$
		yymmdd:0l,$
		secmid:0l,$
		az    :0.,$
	    el    :0.,$
		adrms: fltarr(2,2),$   [iq,ab]
	 	Tsys: fltarr(2),$
		calVal:fltarr(2),$
	fractUsed:0.}

	tsysI=replicate(a,nfiles)
	lineOut=strarr(nfiles)
	iline=0
	tit=$
"  bm  cfr   calA   calB    TsysA  TsysB   digIQ_A    digIQ_B"
	tsysI.cfr=tsysI1.cfr
	tsysI.bw=tsysI1.h.bandwid
	tsysI.bm=tsysI1.bm
	tsysI.az=tsysI1.az
	tsysI.el=tsysI1.el
	tsysI.yymmdd=tsysI1.yymmdd
	tsysI.secMid=tsysI1.secmid
	tsysI.tsys[0,*]=reform(tsysI1.tsysA,1,nfiles)
	tsysI.tsys[1,*]=reform(tsysI1.tsysB,1,nfiles)
	tsysI.fractUsed=tsysI1.calI.fractused
	tsysI.calval   =tsysI1.calI.calval
	tsysI.adrms    =rmsDigAr
	tit="  Id   bm  cfr   calA   calB    TsysA  TsysB    digIQ_A     digIQ_B   fractUsed" &$
	for i=0,nfiles-1 do begin
			lineOut[i]=string(format=$
'(a7,1x,i1,1x,f6.1,1x,f6.3,1x,f6.3," |",f5.1,2x,f5.1," |",f5.1,1x,f5.1,1x,f5.1,1x,f5.1,1x,f4.2)',$
		projId,tsysI[i].bm,tsysI[i].cfr,tsysI[i].calval,$
    		tsysI[i].tsys,TsysI[i].adrms,tsysI[i].fractUsed)
			if keyword_set(verbose) then begin
				if iline eq 0 then print,tit
			    print,lineOut[i]
			endif
			iline++
	endfor
	return,0
end
