;+
;NAME: 
;p12mgettemp - get 12m pedestal temp for a month.
;SYNTAX: n=p12mgettemp(yymm,tIped,tIctl=tictl,yymmdd=yymmdd)
;ARGS:
;yymm: long   month to get
;KEYWORDS:
;yymmdd  : long  if present then ignore yymm and just return this day's data
;RETURNS;
;  n:     > 0 number of entries found
;        < 0  error reading file
;tiPed[n] : {}    struct holding pedestal temp info
;tICtl[n] : {}    struct holding motor cabinet temp
;
;DESCRIPTION:
;   input the temperatures measured in the 12meter pedestal.
; return ti[n] with tI struct holding
;IDL> help,ti,/st
;   YYMMDD          LONG          20210501   (ast)
;   SECMID          LONG                 0   (ast)
;   TEMP            FLOAT           79.5000  ; in deg F pedestal/hub
;   HUMIDITY        FLOAT           79.5000  ; % humidity
;   TEMPDEW         FLOAT           79.5000  ; temp dew point?
; notes:
;
; 202202xx ow includes 12meter pedestal and
;                      12meter controller (patriot box)
;-
function p12mgettemp,yymm,tIPed,tiCtl=tiCtl,yymmdd=yymmdd
;
	q2='"'
	q1="'"
    useDay=keyword_set(yymmdd) 
	if useDay then begin
		yyyymmdd=yymmdd
	    if yyyymmdd lt 999999 then yyyymmdd+= 20000000l
		yymm4= (yymmdd/ 100l ) mod (10000)
	endif else begin
		yymm4=yymm
	endelse
	yymm4 = yymm4 mod 10000l
;
	getctl=arg_present(tiCtl)
	bothPresent=1
	if yymm4 lt 2202 then begin
		getctl=0  ; started 2202
		bothPresent=0
	endif
;   get current date

	lesc=string(byte(27))
	tdir='/share/oplog/tlog/'
	bd=bin_date(systime(0))
	yymm6= yymm4 + 200000l
	curMon=(bd[0] *100 + bd[1]) eq yymm6
	dir='/share/oplog/tlog'	
	filebase="TempLog"
	if  not curMon then filebase+=string(format='("-",i06,".xz")',yymm6)
	file=tdir+filebase
;
; starting jul21 no embdedded esc sequences
;
	if (file_test(file,/read) eq 0) then begin
	   print,"No 12meter temp files for",yymm6
	  return,-1
	endif

    esccmd=(yymm4 lt 2107)?'|sed -e "s/' + lesc + '[^m]*m//g"': ' '
;
;  generate the shell command  unpack,strip escape sequences and grep for 12meter
;
	prefix=(useDay)?string(format='("^",i08,".*")',yyyymmdd):''
	if curMon then begin
		cmd='grep ' + q2 + prefix + '12 meter ' + q2 + " " +  file +  esccmd
	endif else begin
		cmd="xzcat " + file + '|grep ' + q2 + prefix + '12 meter' + q2 + esccmd
	endelse
	spawn,cmd,retval
;
;   now grab  the temp info we want
;                      yyyymmdd   hh       mm                 temp
	str={yymmdd:0l,$
          secMid:0l,$
	        temp :0.,$ ; in pedestal/hub
	        Humidity:0.,$ ; in pedestal/hub
			dewpnt :0}   ; deg F
	n=(getctl)?2:1
	for i=0,n-1 do begin
		if i eq 0 then begin
			if (bothPresent) then begin
				ind=strpos(retval,"ped")
				ii=where(ind ne -1,cnt)
			endif else begin
				cnt=n_elements(retval)
				ii=lindgen(cnt)
			endelse
		endif else begin
			ind=strpos(retval,"con")
			ii=where(ind ne -1,cnt)
		endelse
	    a=stregex(retval[ii],'^([0-9]*)-([0-9]*):([0-9]*).*12 meter[^0-9.]*([0-9.]*)[^0-9.]*([0-9.]*)[^0-9.]*([0-9.]*)',/sub,/extr) 
		jj=where(a[0,*] ne '',cnt)
		if i eq 0 then begin
			tIPed=replicate(str,cnt)
			tIPed.yymmdd=reform(long(a[1,jj]))
			tIPed.secMid=reform(long(a[2,jj]))*3600l + reform(long(a[3,jj]))*60L
			tIPed.temp=reform(float(a[4,jj]))
			tIPed.humidity=reform(float(a[5,jj]))
			tIPed.dewpnt=reform(float(a[6,jj]))
		endif else begin
			tICtl=replicate(str,cnt)
			tICtl.yymmdd=reform(long(a[1,jj]))
			tICtl.secMid=reform(long(a[2,jj]))*3600l + reform(long(a[3,jj]))*60L
			tICtl.temp=reform(float(a[4,jj]))
			tICtl.humidity=reform(float(a[5,jj]))
			tICtl.dewpnt=reform(float(a[6,jj]))
		endelse
	    if i eq 0 then nret=cnt
	endfor
	return,nret
end
