;+
;NAME: 
;p12mlo1 - compute lo1 from requested RF frequency
;SYNTAX: istat=p12lo1(rfFreq,lo1,if1cfr=if1cfr)
;ARGS:
;rfFreq: double rf freq in Mhz
;KEYWORDS:
;IF1CFR: double   if1 cfr in Mhz. def= 1500.
;RETURNS:
;istat:  int      1 computed ok
;                -1  outside udc lo1 band
;DESCRIPTION:
;   The udc lo1 equation is:
; lo1=(22500 + (rfFreq - if1Cfr))/4.	
;   The udc lo1 range is 5750 to 8250.
;-
function p12mlo1,rfFreq,lo1,if1cfr=if1cfr
;
	minLo1=5750d
	maxLo1=8250d
	if n_elements(if1cfr) eq 0 then if1cfr=1500d
	lo1=(22500d + (rfFreq - if1Cfr))/4d
	if ((lo1 lt minLo1) or (lo1 gt maxlo1)) then return,-1
	return,1
end

