;+
;NAME:
;p12mmodeval - evaluate the model Correction at the requested az,el
;
;SYNTAX : p12mmodeval,az,el,modelData,azCorAsec,elCorAsec,$
;                     refCorD=refCorD
;
; ARGS    : 
;   az[]  :     azimuth positions degrees.
;   el[]  :     elevation angle positions degrees.
;   modelData: {modelData} loaded by p12mmodinp. 
; Returns:
;   azCorAsec:  [] return greate circle az correction in arc seconds.
;   elCorAsec:  [] return  el correction in arc seconds.
;                  This includes the refraction correction.
;                  Add this value to elReq (not elRefracted) to get elToUse.
;   refCorD:    [] elR -El in deg. This is already included in elErrAsec
;                  i've included it here just for reference.
;
; DESCRIPTION:
;   Evaluate the model at the specified az, el locations. 
; Use the model data in the structure modelData
; (this structure can be loaded via p12mmodinp).
;
; Return the model Corrections in great circle arc seconds evaluated at the
; az,el. The errors are defined such that:
; 1. let azComp,elComp be the computed az, el to move the telescope to.
; 2. compute azCor, elCor from the model.
; 3. azTouse = azComp + AzCor*asecToRad
;    ElTouse = ElComp + ElCor*asecToRad
; 4. this includes the refraction correction to el. So you Add the el value
;    to the elValue  without the refraction correction
;-
pro p12mmodeval,azInp,elInp,mI,azCorAsec,elCorAsec,refCorD=refCorD
;
;  some constants..
;
    ddtor=!dpi/180.d    
    minEl=5.8D;
    maxEl=88d;
;	 el 0,360 positive. then -90 to 90
    el=elInp mod 360d
	az=azInp;
	ii=where(el lt 0d,cnt)
	if cnt gt 0 then el[ii]+=360d
	ii= where (el gt 90d,cnt)
	if cnt gt 0 then begin
		el[ii]-=360d
		ii=where(el lt -90d,cnt)
		if cnt gt 0 then begin
			el[ii]+=180d
			az[ii]+=180d
		endif
	endif
	az=az mod 360d
	ii=where(az lt 0d,cnt)
	if cnt gt 0  then az[ii]+=360d

;	 az is now 0..360. make el within limits

    ii=where(el lt minel,cnt)
	if cnt gt 0 then el[ii]=minEl
    ii=where(el gt maxel,cnt)
	if cnt gt 0 then el[ii]=maxEl
    azErrAsecs=0.d
    elErrAsecs=0.d
	case mI.type of
	 	1: begin
    	  ; el limit to 88 --> tan(el) 1/cos(el) does not blow up
    	  ; refracted elevation
    	  elR=el + (.0019279D + $
             1.02D/(tan(ddtor*(el + (10.3D/(el+5.1D))))))/60d;
    	  cosAz=cos(ddtor*az);
    	  sinAz=sin(ddtor*az);
    	  cosEl=cos(ddtor*elR);
    	  sinEl=sin(ddtor*elR);
    	  cotEl=cosEl/sinEl;
		  refCorD=elR - El
	      azCorAsec=(mI.coefAsec[1-1] +$
                     mI.coefAsec[2-1]*cosEl  +$
                     mI.coefAsec[3-1]*sinEl  +$
                     mI.coefAsec[4-1]*sinEl*cosAz  +$
                     mI.coefAsec[5-1]*sinEl*sinAz)
          elCorAsec=(-mI.coefAsec[4-1]*sinAz + $
                    mI.coefAsec[5-1]*cosAz + $
                    mI.coefAsec[7-1]       +$
                    mI.coefAsec[8-1]*cosEl +$
                    mI.coefAsec[9-1]*cotEl)  + (refCorD)*3600d
		  end
     else: begin
           message,'model ' + mI.type + ' not yet supported'
           end
    endcase
	return
end
