;+ 
;NAME:
;psrfgetfile - input a  psrfits file
;
;SYNTAX: istat=psrfgetfile(filename,bAr,fnmI=fnmI,blankcor=blankcor,avg=avg,$
;                          tp=tp,desc=desc)
;
;ARGS:
;    filename: string    file to input (unless fnmI= keyword supplied
;
;RETURNS:
;     bAr[nrows]: structure holding the hdr and data input
;  tp[ndump,npol,nrows]: float  if tp provided (and averge set) then also
;                 return the total power for each time sample
;  desc         : struct  if supplied then return descriptor here. the file will already
;                         be closed
; istat: >0  number of rows we read in
;      : 0 hiteof
;      :-1 i/o error..bad hdr, etc..
;
;
;KEYWORDS:
;    blankcor : if set then correct for any blanking.. the forces the
;               returned dataset to be floats
;       avg   : if set then average the spectra in 1 row before returning.
;               This forces the returned datatype to be float.  
;               this will automatically do the blankcor (since it normalizes
;               the sum to the total number of ffts accumulated * the 
;               integration period std value.
;
;DESCRIPTION:
;
;   Read a psrfits file pointed to by desc.
;  If keyword row is present, position to row  before reading.
;-
;
function psrfgetfile, fname,bar,fnmI=fnmI,blankcor=blankcor ,avg=avg,$
				tp=tp,desc=desc
;
;
;;    on_error,2
    on_ioerror,ioerr
	useTp=(arg_present(tp) and (keyword_set(avg)))
;
;	open the file
;
	fileOpen=0 
	istat=psrfopen(fname,desc,fnmI=fnmI)
	if istat lt 0 then begin
		fnameL=(n_elements(fnmI) gt 0)?fnmI.fname:fname
		print,"psrfgetfile: error opening:" + fnameL
		return,-1
	endif
	fileOpen=1 
	nrows=desc.totrows
	npol=desc.hsubint.npol
	ndump=desc.hsubint.nsblk
	for irow=0,nrows-1 do begin
		if (useTp) then begin
			istat=psrfget(desc,b,blankcor=blankcor,avg=avg,tp=tp)
		endif else begin
			istat=psrfget(desc,b,blankcor=blankcor,avg=avg)
		endelse
		if irow eq 0 then begin
			bar=replicate(b,nrows)
		    if useTp then begin
				tpar=fltarr(ndump,npol,nrows)
			endif
		endif
		bar[irow]=b
		if useTp then begin
			if npol eq 1 then begin
				tpAr[*,irow]=tp
			endif else begin
				tpAr[*,*,irow]=tp
			endelse
		endif
	endfor
	psrfclose,desc
    return,nrows
ioErr: 
	print,"psrfgetfile: ioerr" 
	if fileOpen eq 1 then psrfclose,desc
	return,-1
end		
