;+
;NAME:
;psrfsspsrdiri - return  list of directories for sspsr data
;SYNTAX: ndir=psrfsspsrdiri(dirIAr)
;ARGS:
;   none
;                       file to open.
;RETURNS:
;   ndir:  int  number of directories returned
;  dirIAr[2,ndir] strarr  return an array of dirI[2] arrays that can be used in a 
;                 call to masfilelist
;DESCRIPTION:
; 	sspsr project is taking pulsar data at sband (2022). The output data has been
;spread over multiple file systems. This routine will return a list of filesystems
;that can be used in masfilstlist to search for files.
;
;EXAMPLE:
;  suppose we want to search for sspsr data on 20221122 
;  yymmdd=20221122l
;  proj='sspsr'
;	ndir=psrfsspsrdiri(dirIAr)
;
;print,ndir,dirIar
; 3 
; /proj/sspsr/pdevs /
; /proj/sspsr/pdevs t/
; /share/pdata /pdev
;
;   nfiles=0
;	for i=0,ndir-1 
;		dirI=dirIAr[*,i]
;       nfiles=masfilelist('',proj=proj,bm=0,band=1,grp=0,/psrfits,/appbm,yymmdd=yymmdd,$
;               diri=dirI)
;		if nfiles ne 0 then break
;   endfor 
;  if nfiles eq 0 then begin
;     print,'no  files found for ' + proj + ' on ',yymmddl
;  endif
;-
function psrfsspsrdiri,dirIAr 
	dirIAr=[['/proj/sspsr/pdevs','/'],$
	        ['/proj/sspsr/pdevs','t/'],$
	        ['/share/pdata','/pdev']]
	return,n_elements(dirIAr)/2l
end
