;+ 
;NAME:
;psrftpscan - compute total power by row for all files in a scan
;
;SYNTAX: n=psrfgettp(fnameAr,tp,tmavg,fnmI=fnmI,hdrAr=hdrAr,blankcor=blankcor,
;                      edge=edge,verb=verb)
;
;ARGS:
;    fnamear[n]: string	 arrray of files in scan to check
;KEYWORDS:
;	fnmI[n]:  {}    structure from masfilelist for file to use
;					In this case ignore fnameAr
;blankcor:          If set the correct for adc blanking
;edge[2] :float     fraction of spectra on each edge to ignore when computing
;                   tp. if only 1 dimension. then apply this fracct on both edges.
;                   def:0.
;verb    :           if set then print filenames as we process them
;RETURNS:
;  tp[n,npols,nbms]: float  if nbms=1 then just [n,npols.nfiles]
;  tmAvg: double     time step of average tp data
; hdrAr[nbms]        : struct primary and extension headers for first file of each bm
; n:   >=0 number of sample points per bm
;      < 0  error
;
;DESCRIPTION:
;   Read in a set of files from a scan and compute the total power. If edge=[] is suppied then 
;exclude this fraction of freq chan on each side of the bandpass.
;   The files should come from the same scan (the routine will check for this).
;the data is returned at: tp[nsampPerbm,npol,nbms)
;
;-
;
function psrftpscan,fnameAr,tpAr,tmAvg,hdrAr=hdrAr,fnmI=fnmI,verb=verb,blankcor=blankcor,$
				 edge=edge
;
;  get summary of each file
;
	useFnmI=n_elements(fnmI) gt 0
		if keyword_set(verb) then print,"getting file summaries"
	nsum=psrffilesum(fnameAr,sumI,fnmI=fnmI)
	ubms=sumI[uniq(sumI.bm,sort(sumI.bm))].bm
	nbms=n_elements(ubms)
	ii0=where(sumI.bm eq 0,nfilesBm)
;   get the total number of rows.. we avg each row
	navgT=total(sumI[ii0].nrows)
	npol=sumI[0].hpri.nrcvr
	nsblk=sumI[0].hsubint.nsblk  ; samples in 1 row
	tmAvg=nsblk * sumI[0].hsubint.tbin
	tpAr=fltarr(navgT,npol,nbms)
	start=1
	for ibm=0,nbms-1 do begin
		icur=0l
		ii=where(sumI.bm eq ibm,cnt)
		if (cnt ne nfilesbm) then begin
			print,"-->Warning: expected",nfilesbm," for bm:",ibm," but only found:",cnt
		endif
		for ifile=0,cnt-1 do begin
			j=ii[ifile]
			fname=(useFnmI)?fnmI[j].dir+fnmI[j].fname:fnameAr[j]
			lin=string(format='("bm:",i1," ifile:",i2," file:",a)',ibm,ifile,fname)
			if keyword_set(verb) then print,lin 
			n=psrftpfile(fname,tp,hdr=hdr,blankcor=blankcor,edge=edge)
		    nrows=n/nsblk
			if npol eq 1 then begin
				tpAr[icur:icur+nrows-1l,ibm]=total(reform(tp[0L:nsblk*nrows-1],nsblk,nrows),1)/(nsblk*1.) ; average over row
			endif else begin
				tpAr[icur:icur+nrows-1l,*,ibm]=total(reform(tp[0L:((nsblk*nrows)-1),*],nsblk,nrows,npol),1)/(nsblk*1.); average over row
			endelse	
			if start then begin
			   hdrAr=replicate(hdr,nbms)
			   start=0
			endif
			if ifile eq 0 then hdrAr[ibm]=hdr
			icur+=nrows
		 endfor
	endfor
	return,icur
end
