;+
;NAME:
;pupfavg - average puppi fits file row(s)
;SYNTAX: bavg=pupfavg(hsubint,b,median=median)
;ARGS:
;hsubint : {}   sub int header. from desc.hsubint
;b[n]    : {}   puppi fits file data n=1 to n
;KEYWORDS:
;median :       if set then compute median rather than average
;RETURNS:
;bavg   :  {}   averaged data.
;DESCRIPTION
;	Input a puppi fits file record(s). Average over the nsblk of each
;rec as well as over multiple rows (if input). Do not average the pols.
;	The bavg.data  will be dimensioned nchan,npol
;Warning: if using the median. be careful passing in an array of recs
; too largee (since it will do the median by chan over all the data.
;Example:
;   istat=pupfget(desc,b1)
;   istat=pupfget(desc,b2)
;   b=[b1,b2]
;	bavg=pupfavg(desc.hsubint,b)
; 
;Warning: the routine does not update the header locations
;         eg. tsubint 
;-
function pupfavg,hsubint,b,median=median 
;
	nrecs=n_elements(b)
	npol  =hsubint.npol
	a=size(b.data)
	if npol eq 1 then begin
		case a[0] of 
	             1: nsblk=1
		         2: nsblk=(nrecs gt 1)?1:a[1]
			  else: nsblk=a[1]
		endcase
	endif else begin
		case a[0] of 
	             2: nsblk=1
		         3: nsblk=(nrecs gt 1)?1:a[2]
			  else: nsblk=a[1]
		endcase
	endelse
	if (nsblk eq 1) and (nrecs eq 1) then begin
		bavg=b
		return,bavg
	endif
	useMed=keyword_set(median)
;
;   create struct with on single data entry
;
	 tagNmAr=tag_names(b[0])
     ntags  =n_elements(tagNmAr)
     for i=0,ntags-1 do begin
    	if i eq 0 then begin
        	bavg=create_struct(tagNmAr[i],b[0].(i))
        endif else begin
        	if tagNmAr[i] ne "DATA" then begin
            	bavg=create_struct(temporary(bavg),tagNmAr[i],b[0].(i))
            endif else begin
                nchan=n_elements(b[0].dat_freq)
                if npol eq 1 then begin
                    bavg=create_struct(temporary(bavg),tagNmAr[i],fltarr(nchan))
                endif else begin
                    bavg=create_struct(temporary(bavg),tagNmAr[i],fltarr(nchan,npol))
                endelse
            endelse
        endelse
    endfor
;
;       now average
;
     scl=1./(nsblk*nrecs)
;
;    now average
;
	dim=(npol eq 1)?2:3
	if nrecs gt 1 then begin
	  if usemed then begin
		  if npol eq 1 then begin
  	      	bavg.data=median(reform(b.data,nchan,nsblk*nrecs),dim=2) 
		  endif else begin
  	      	bavg.data=median(reform(b.data,nchan,npol,nsblk*nrecs),dim=3) 
		  endelse
	  endif else begin
		  if npol eq 1 then begin
  	      	 bavg.data=reform(total(reform(b.data,nchan,nsblk*nrecs),2)*scl,$
			           nchan)
		  endif else begin
  	      	 bavg.data=reform(total(reform(b.data,nchan,npol,nsblk*nrecs),3)*scl,$
			           nchan,npol)
		  endelse
	  endelse
	endif else begin
	  if usemed then begin
  	      bavg.data=median(b.data,dim=dim) 
	  endif else begin
  	      bavg.data=total(b.data,dim)*scl
	  endelse
	endelse
	return,bavg
end
