;+
;NAME:
;arm12intro - Using the 12m rcvmon12  routines:
;    
;    The 12m has a dewar monitoring package that lets us monitor the
;dewar temperatures, bias voltages and currents.
;    The data is continuously sampled (def once every 3 seconds) and written
;to an output file (in binary). The program to do this is
; /share/megs/phil/svn/p12m/wbrcvr/monctl/p12mrcvm.c . It will normally run on
;galfas2, talk to the labjack in the wbrcvr and write the data to disc.
;
;A new disc file is created each month using the filenaming
;conventions:
;    /share/phildat/rcvm12m/rcvm      .. the current month
;    /share/phildat/rcvm12m/rcvm.yymm .. previous months eg rcvmN.2212 for dec22
;
;Each of the monthly files contains about 55Mbytes of data (with 3 second sampling).
;The data is stored sequentially in time as it is sampled.
;
;    The routines in the rcvmon12 package let you access and plot this data. You
;need to be a bit careful what you ask for (because you might get it..). 
;
;    The main routines used by users are:
;    
;rm12inpday() - input one or more days of data.
;rm12plot()   - plot the temperature data that was input.
; 
;rm12mon()    - input and plot the data for a day, or continually monitor
;                the current values.
;
;The other routines are support routines used by these 3.
;
;The data structure used for each sample is:
;
;IDL> help,d,/st
;** Structure RCVMON12, 11 tags, length=64, data length=64:
; KEY        BYTE     Array[4]  ; "12m" start of rec id  
; YEAR       LONG     2022      ;  ast
; DAY        DOUBLE   341.00002 ; daynumber ast with fractional day
; PTORR      FLOAT    798.888   ; vacuum pressure in Torr
; TEMPCASE   FLOAT    32.9268   ; LabJack caseTemp degC
; TEMP1K     FLOAT    293.457   ; 16K stage degK
; TEMP2K     FLOAT    293.106   ; 70K state degK
; VGATE      FLOAT    Array[2]  ;  gate voltage polA,B  . V
; VDRAIN     FLOAT    Array[2]  ; drain voltage polA,B  . V
; IDRAIN     FLOAT    Array[2]  ; drain current polA,B  .milliAmps
; VDRAINLNA  FLOAT    Array[2]  ; drainVoltage acrosslna PolA,B
; 
;rm12inpday will input an array of these structures d[n]. You can then use rm12plot
;to plot the data, or you can use the normal idl plot routines for plotting.
;
;When plotting multiple pols, you ,may need to set the vertical scale first so that
; the plotting routines don't autoscale to the min,max of the first pol.
;
;EXAMPLES:
;;  start idl
;    idl
;    @phil
;    @rcvmon12init
;
;; input 01jan23 thru 06
; 
;    nrecs=rminpday(230101,d,lastday=230106) ;
;;  plot the 16 k stage using  ascii dates
;    ver,0,30
;    rm12plot,d,/adate
;;  plot the 70k stage
;    ver,0,100
;    rmplot,d,temp=2,/adate
;;
;    plot the 16k (black) and 70k (red) stage on same plot.   
;    ver,0,120
;    rm12plot,d,temp=1,/adate
;    rm12plot,d,temp=2,/adate,/over,col=2
;
;; plot the currents 
;    ver,30,40
;    rm12plot,d,/cur,/adate
;
;; plot the vacuum pressure. log scale
;    ver,5e-5,100
;    rm12plot,d,/pressure,/adate,/log
;-
