;+
;NAME:
;rm12inprecs - input 12meter rcvmonitor records 
;SYNTAX: nrecs=rm12inprecs(lun,nrecsReq,d,smo=smo)
;ARGS:
;   lun :       int file containing data to read
;   nrecsReq:  long requested number of records to read
;KEYWORDS:
;      smo: int smooth and decimate by this amount.  should be an odd number
;               >= 3. The data will be smoothed and decimated by this amount.
;RETURNS:
;   nrecs : long    number of records input.
;   d[nrecs]:{rcvmon12} data input from file
;DESCRIPTION:
;   This routine is normally called via rm12inpday or rm12moninp.
;
;   rm12inprecs will try to read the requested number of records from the 
;12meter receiver monitoring file that lun points to (you need to open the file
;before calling this routine). The number of records actually read is
;returned in nrecs. The routine will preallocate an array of nrecsReq
;before reading.
;
;EXAMPLE:
;   openr,lun,'/share/phildat/rcvm12m/rcvm',/get_lun
;   nrecs=rm12inprecs(lun,9999,d)
;-
function rm12inprecs,lun,nrecreq,inpdat,smo=smo
;
    on_ioerror,done

    dosmo=0
    if keyword_set(smo) then begin
        dosmo=1
        print,'smoothing by:',smo
        if smo gt 2 then dosmo=1
    endif

    inpdat=replicate({rcvmon12},nrecreq)
    inpdat.year=-1 
    readu,lun,inpdat
done:
    ind=where(inpdat.year eq -1,count)
    if count gt 0 then begin
		if count eq n_elements(inpdat) then return,0
		inpdat=temporary(inpdat[0:ind[0]-1])
	endif
;
; swap if little endian machine
;
    nrecs=n_elements(inpdat)
;
    if dosmo then begin
        nrecs=rm12smodat(inpdat,smo,dsmo)
        inpdat=temporary(dsmo)
    endif
    return,nrecs
end
