;+
;NAME:
;rm12smodat - smooth the data in 12m rcvmon struct
;SYNTAX: nrecs=rm12smodat(dinp,tosmo,dsmo)
;ARGS:
;   dinp[n] : {rcvmon12} data to smooth
;   tosmo   : long  number of points to smooth
;               >= 3. The data will be smoothed and decimated by this amount.
;RETURNS:
;   nrecs      : long    number of smoothed records returned
;   dsmo[nrecs]:{rcvmon12} smoothed data
;DESCRIPTION:
;   This routine is normally called via rm12inpday or rm12plot
;
;   Smooth the data fields in dinp by tosmo points using a boxcar smoothing.
;Each point is normally sampled every 3 seconds. Fields that are not numeric:
;.stat use the first element of the pnts to smooth.
;
;EXAMPLE:
;-
function rm12smodat,dinp,tosmo,dsmo
;
    if tosmo le 2 then begin
            message,'smoothing must be > 2 points'
    endif
    nrecs=n_elements(dinp)
	if nrecs lt tosmo  then begin
		print,"No smoothing, not enough records"
		return,-1
	endif
    aa=select(dinp.year,tosmo/2,tosmo)
	nrecsmo=n_elements(aa)
	aa=''
    dsmo=replicate(dinp[0],nrecsmo)
    icur=0L
     dsmo.key      =dinp[0].key
     dsmo.year     =select(smooth(dinp.year,tosmo,/edge),tosmo/2,tosmo)
     dsmo.day      =select(smooth(dinp.day,tosmo,/edge),tosmo/2,tosmo)
     dsmo.ptorr    =select(smooth(dinp.ptorr,tosmo,/edge),tosmo/2,tosmo)
     dsmo.tempcase =select(smooth(dinp.tempcase,tosmo,/edge),tosmo/2,tosmo)
     dsmo.temp1k   =select(smooth(dinp.temp1k,tosmo,/edge),tosmo/2,tosmo)
     dsmo.temp2k   =select(smooth(dinp.temp2k,tosmo,/edge),tosmo/2,tosmo)

     dsmo.temp2k   =select(smooth(dinp.temp2k,tosmo,/edge),tosmo/2,tosmo)
     for k=0,1  do begin
      	dsmo.vgate[k]=select(smooth(dinp.vgate[k],tosmo,/edge),tosmo/2,tosmo)
      	dsmo.vdrain[k]=select(smooth(dinp.vdrain[k],tosmo,/edge),tosmo/2,tosmo)
      	dsmo.idrain[k]=select(smooth(dinp.idrain[k],tosmo,/edge),tosmo/2,tosmo)
      	dsmo.vdrainlna[k]=select(smooth(dinp.vdrainlna[k],tosmo,/edge),tosmo/2,tosmo)
	endfor
;
;       put back in date order
;
    ind=sort(dsmo.day)
    dsmo=dsmo[ind]
    return,nrecsmo
end
