;+
;NAME:
;rm12smohr - smooth to one hour resolution
;SYNTAX: nrecs=rm12smohr(dinp,dsmo)
;ARGS:
;   dinp[n] : {rcvmon12} data to smooth to hour resolution 
;RETURNS:
;   nrecs      : long    number of smoothed records returned
;   dsmo[nrecs]:{rcvmon12} smoothed data
;DESCRIPTION:
;   Smooth the data fields in dinp to one hour resolution.
;Each point is normally sampled every 3 seconds.
;
;EXAMPLE:
;-
function rm12smohr,dinp,dsmo
;
   	nrecs=n_elements(dinp)
	lday=long(dinp.day)
	uldays=lday[uniq(lday,sort(lday))]	 ;unique idays
	ndays=n_elements(uldays)
	maxout=ndays*24L + 1
    dsmo=replicate(dinp[0],maxout)
	dsmo.key=dinp[0].key
;
; 	loop by day
;
	icur=0l
	for i=0,ndays-1 do begin
		lcurday=uldays[i]
		iiday=where(lday eq lcurday,count)
		if count eq 0 then goto,botloop
		hr=(dinp[iiday].day - lcurday) * 24.		; hour of day
		h=histogram(hr,binsize=1.,min=0.,max=23.999,reverse_ind=irev)
;       loop over 24 hours
    	for k=0L,23 do begin
			if irev[k] ne irev[k+1] then begin
				i1=irev[irev[k]]
				i2=irev[irev[k+1]-1L]
				npnts=i2-i1+1.
                dsmo[icur].year    =dinp[iiday[i1]].year
                dsmo[icur].day     =lcurday+(k+.5)/24.
     		    dsmo[icur].ptorr   =total(dinp[iiday[i1:i2]].ptorr)/npnts
     		    dsmo[icur].tempcase=total(dinp[iiday[i1:i2]].tempcase)/npnts
     		    dsmo[icur].temp1k  =total(dinp[iiday[i1:i2]].temp1k)/npnts
     		    dsmo[icur].temp2k  =total(dinp[iiday[i1:i2]].temp2k)/npnts
     			for kk=0L,1  do begin
     				dsmo[icur].vgate[kk]=total(dinp[iiday[i1:i2]].vgate[kk])/npnts
     				dsmo[icur].vdrain[kk]=total(dinp[iiday[i1:i2]].vdrain[kk])/npnts
     				dsmo[icur].idrain[kk]=total(dinp[iiday[i1:i2]].idrain[kk])/npnts
     				dsmo[icur].vdrainlna[kk]=total(dinp[iiday[i1:i2]].vdrainlna[kk])/npnts
   				endfor ; kk
   				icur=icur+1
      		endif  ; irev[k] ne irev[k+1]
		endfor	   ; k .. hour loop
botloop:
    endfor  ; 			   ; loop i =ndays-1
    nrecs=icur
    if nrecs lt maxout then dsmo=dsmo[0:nrecs-1]
;
;       put back in date order
;
    ind=sort(dsmo.day)
    dsmo=dsmo[ind]
    return,nrecs
end
