;+
;NAME:
;satlisttlefiles - return list of tle files
;SYNTAX: nfiles=satlisttlefiles(tlefiles,tledir=tledir,suf=suf)
;ARGS:
;
;KEYWORDS:
;tledir:  string  if supplied then the directory to  look for tle file
;suf   :  string  suffix for tle files. by default use txt,tle.
;yymmdd: long     if supplied, then look in archive for data for this date.
;
;RETURNS:
;nfiles: long    number of files we found
;tlefiles[nfiles]: array of files we founds
;
;DESCRIPTION:
;   get a list of tle files in the requested directory (default is the
;default tle directory).
;  If tledir is supplied then search this directory
;for any tle files.
;  if yymmdd= is supplied then search archive for data for this date.
;The current search looks for tle data updated on this date. It may return
;nothing if a tle file was not modified on this date (need to broaden search
;criteria).
;  it will have to run updatetle.sc on each file found
;  data is written to tmp directory.
; NOTE:
;   yymmdd and tledir are mutually exclusive...
;-
function satlisttlefiles,tlefiles,suf=suf,tledir=tledir,yymmdd=yymmdd
;
;   
; 
	tledirL=keyword_set(tledir)?tledir:''
    suI=satsetup() 
	usedate=keyword_set(yymmdd)
;
; 	if use date. look for .txt files.
;   if found, pass through fix_tle.sc
;   
	archiveTmp='/share/megs/phil/predict/atmp/'
	if usedate then begin
		yyyymmddl=yymmdd
		if (yyyymmddL/10000l lt 2000l) then yyyymmddl+=20000000L
		yr=yyyymmddL / 10000l
		lyyyymmddL=string(format='(i08)',yyyymmddl)
	   	; if not current year then search in subdir by year
		a=bin_date()
		srchPath=suI.tleArchive
		if a[0] ne yr then begin
			srchPath+=string(yr,format='(i04)',yr) + "/"
		endif
		pat=srchPath + "*txt*" + lyyyymmddL
   		tlefiles=file_search(pat)
        nfiles=n_elements(tlefiles)
		if not keyword_set(tlefiles[0]) then return,0
		; delete any files in archive tmp
		cmd='rm -f ' + archiveTmp + "*"
		spawn,cmd
		for i=0,nfiles-1 do begin &$
;			cmd='cat ' + tlefiles[i] + ' |' + suI.tleDir + "fix_tle.pl --foutbase=" + archiveTmp  &$
			cmd= suI.tleDir + "fix_tle.pl --foutbase=" + archiveTmp  + " " + tlefiles[i]  &$
            spawn,cmd &$
	    endfor
		tleDirL=archivetmp
	endif
   	tlepath=(keyword_set(tledirL))?tledirL:suI.tledir
	; make sure /  on end of path
	if strpos(tlepath,"/",/reverse_search) ne (strlen(tlepath)-1) then  $
		tlepath+="/"
  	tlefiles=file_search(tlepath+"*")
;
    nfiles=n_elements(tlefiles)
;   no files.. tlefiles=''
	if not keyword_set(tlefiles[0]) then return,0
    icnt=0
    sufAr=(keyword_set(suf))?suf:suI.tlesuf
    for ifile=0,nfiles-1 do begin
        for isuf=0,n_elements(suFAr)-1 do begin
            n=strlen(sufAr[isuf])
            if (strpos(tlefiles[ifile],sufAr[isuf],n-1,/reverse_offset) ne -1)$
                 then begin
                tlefiles[icnt]=tlefiles[ifile]
                icnt++
                break;
            endif
        endfor
    endfor
    if icnt ne 0 then begin
        if (icnt lt nfiles) then tlefiles=tlefiles[0:icnt-1]
    endif
	if usedate then begin
	    cmd="chmod 0666 " + archiveTmp + "/*.tle"
		spawn,cmd
	endif
    return,icnt
end
