;+
;NAME:
;anritinpbin - input an anritsu binary file
;SYNTAX: istat=anritinpbin(fname,ntrace,fI,npnts=npnts,trcord=trcord)
;ARGS:
;fname: string file to input
;ntrace: int   number of traces stored
;KEYWORDS:
;npnts : int   number of points/file def=551
;trcord:       if set then data is in trace order:
;              freq,trc1,trc2,...
;              def is frq[i],trc1[i],trc2[i].. i=01,npnts-1
;RETURNS:
; istat: int   0 - file does not exist
;             -1 - file exists, but size is too small
;       
; FI    :{}  holds info from files
;
;-
function  anritinpbin,fname,ntrace,fI,npnts=npnts,trcord=trcord
;
; to search for ntrace
; read in 10 floats.. 
; - start a 0.. freq 0.. move forward till you find a value >
;   - check to see if freq starts at 0..
;   - i2-i1  is the number of traces.
; - to  check on the number of pnts
;   npnts=nbytes/(4*ntrace)
; - this will not catch partial records
;
	trcord=keyword_set(trcord)
	if (n_elements(npnts) eq 0) then npnts=551
;    numbers order is:  freq, trace 1,2,3
	if not file_test(fname) then return,0
;   make sure not partially written
	bytesExpected=(ntrace + 1L)*npnts*4
	openr,lun,fname,/get_lun
	fs=fstat(lun)
	if fs.size lt bytesExpected then begin
		free_lun,lun
		lab=string(format='("Expected ",i5," bytes.filesize only: ",i5)',bytesExpected,fs.size )
		print,lab
		return,-1
	endif
	inpAr=(trcord eq 0)?fltarr(ntrace+1,npnts):fltarr(npnts,ntrace+1)
	readu,lun,inpar 
	free_lun,lun
	fI={ fname:' ',$ 
	   cfr   : 0.,$
       df    : 0.,$
	   mtime :0LL,$ ;secs 1970. last file modification
	   freq  : dblarr(npnts),$
	   spc   : dblarr(npnts,ntrace)}
;
;   get filelisting of this directory
;
	fI.fname=fname
	fI.freq=(trcord eq 0)?inpar[0,*] :inpar[*,0]
	fI.spc=(trcord eq 0)?transpose(inpar[1:*,*]): inpar[*,1:*]
	fI.df=(fI.freq[1]- fI.freq[0])
	fI.cfr=fI.freq[npnts/2]
	fI.mtime=fs.mtime
	return,1
end
