;+
;NAME:
;svinptargets -input target file
;SYNTAX: npts= svinptargets(file,tI,comment=comment)
;ARGS:
;	    lun: int  file to read from
;KEYWORDS:
;comment:  string   defines comment line if in col 1.
;                   if not supplied then defaults to #
;
;RETURNS:
;npts      : long         number of points returned
;                        < 0 --> error
;                        -1 file does not exist
;                        -2 
;tI[npts]  : {svpnt} return array of target structs
;
;DESCRIPTION:
;	input the targets from a target file. 
;The std file format is:
;name  x    y   z    refnum  tmstamp code
; It will also accept lines as
;name  
;  with nothing else. in this case it will set to the positions to 0,0,0 and the code to -1
;Where refnum tmstamp (secs1970) and code are optional
; eg:
; name          x            y           z        refN  tmsmp     code
;0109L2S       -25.98390    -5.82900   -18.13870   123 1582818845  1
; the TI structure is:
;IDL> help,ti,/st
;** Structure <10a5b58>, 5 tags, length=56, data length=52, refs=2:
;   NAME            STRING    ' '
;   XYZ             DOUBLE    Array[3]
;   REFNUM          LONG                 0
;   TMSTAMP         LONG                 0
;   CODE            LONG                 0    ; 1->part of dsn, else  not part of .dsn 
; @surveyinit first
;-
function svinptargets,file,tI,comment=comment

	if n_elements(comment) eq 0 then comment='#' 
	npnts=readasciifile(file,inp,comment=comment)
	if npnts le 0 then return,npnts
;	aa={ name: " ",$
;	     xyz: dblarr(3),$
;         refnum:0l,$  ; or measurement number. if none,=0
;         tmstamp:0l,$  ; secs1970 or 0l if none
;		 code   :0l $   ; code .. normally 1-> part of dsn, 0 not part of dsn
;	}
	tI=replicate({svpnt},npnts)
	icur=0
	for i=0,npnts-1 do begin
		a=strsplit(inp[i],count=count,/extract)
		if count eq 0 then continue
		ti[icur].name=a[0]
		if count ge 4 then begin
			ti[icur].xyz=double(a[1:3])
		    if count gt 4 then begin
		       ti[icur].refNum=long(a[4])
		       if count gt 5 then begin
			      ti[icur].tmstamp=long(a[5])
				  if count gt 6 then  begin
			         ti[icur].code=long(a[6])
				  endif
		   	   endif
		    endif
		endif
		icur++
    endfor
	if (icur ne npnts) then begin
		if icur eq 0 then return,0
		npnts=icur
		tI=tI[0:npnts-1]
	endif
	 return,npnts
end
