;+
;NAME:
;svskinplog - input sokia log file.
;SYNTAX: istat= svskinplog(file,npnts,pnts,gotxform,xform,ncirc,circle,debug=debug)
;ARGS:
;	 file  : string  log file to read
;RETURNS:
;  istat :  -1  error reading file
;           0 no data points
;           1 got datapoints
;           2 got datapoints and xform
;           3 got dataoints,xform, and circle
;npnts     :  int     number of datapoints for xform
;pnts[npts]: {svpntsk} return xform points  data here
;gotxform  :  int         0 didn't get xform, 1 got xform
;xform     : {surveyxform} final transform read from logfile
;ncirc   : int           number of circles we found
;circAr[ncirc]: {skcirclestr}   analyz circle info   
;KEYWORDS:  
;DEBUG     : if set then output debuggin info
;
;DESCRIPTION:
;	Read the sokia log file and input :
; - the measured points used for the xform
; - the xform
; - any analyze circle data and fits
;
; The program will strip out any lines with null,null
;-
function svskinplog,file,npnts,pnts,gotxform,xform,ncirc,circAr,lunout=lunout,debug=debug

	useDebug=keyword_set(debug)
	npnts=0
	gotxform=0
	ncirc=0
	if n_elements(lunout)  eq 0 then lunout=-1
	maxpnts=500
	pnts=replicate({svpntsk},maxpnts)
	xform={surveyxform}
	maxCir=50
	circAr=replicate({skcircleStr},maxCir)
	circAr.units='inches'
	pntsCir=replicate({svpntsk},5)
;
; 	input the file
; 
	n=readasciifile(file,inp)
	if n le 0 then begin
		print,"readasciifile return status:",n," for file ",file
		return,-1
	endif
;
; get rid of binary 0,0 
;
	a=byte(inp)
	ii=where(a[0,*] ne 0,cnt)
	if (cnt eq 0) then begin
		print,"No non zero lines found in file"
		return,-1
	endif
	inp=inp[ii]
	nlines=n_elements(inp)
	ipnt=0l
	done=0
	if useDebug then print,"Nlines found after 0 removal:",nlines
;   loop till we get the xform info
	iline=0
	while (not done) do begin 
		a=strsplit(inp[iline],/extract,count=count)
		if useDebug then print,iline," ntoks:",count," inpline:",inp[i]
		if count lt 2 then  goto,botloop1
	    case 1 of
		    a[0] eq 'Saved': gotXform=1
			count eq 7: begin
					    ii=where(pnts.name eq a[0],nn) ; see if new or replace
						j=(nn eq 0)?ipnt++:ii[0]
						pnts[j].name=a[0]
					    pnts[j].pos =double(a[1:3])
					   end
			a[0] eq 'Scale': xform.scale = double(a[1]) 
			(a[0] eq 'X') and (a[1] eq "Rotation"): xform.xrot = double(a[2])
			(a[0] eq 'Y') and (a[1] eq "Rotation"): xform.yrot = double(a[2])
			(a[0] eq 'Z') and (a[1] eq "Rotation"): xform.zrot = double(a[2])
			(a[0] eq 'X') and (count eq 2)        :xform.x = double(a[1])
			(a[0] eq 'Y') and (count eq 2)        :xform.y = double(a[1])
			(a[0] eq 'Z') and (count eq 2)        :xform.z = double(a[1])
			(a[0] ne 'RMS') and (count eq 4):begin
					ii=where(pnts.name eq a[0],cnt)
					if (cnt eq 0) then begin
					  print,"residual with no measuremnt:",inp[iline]
					  break
					endif
					pnts[ii[0]].err=double(a[1:3])
			      end
			(a[0] eq 'RMS') and (count eq 4):xform.rmsfit=double(a[3])
            else: if useDebug then print,"skip:"+inp[i]
		endcase
botloop1: iline++
		  done=gotXform || (iline ge nlines)
	endwhile
	if ipnt eq 0 then return,0
	npnts=ipnt
	pnts=pnts[0:ipnt-1]
;
	if (gotXform eq 0) then begin
		circAr=''
		return,1
	endif
	done=iline ge nlines
;  now look for analyze circle info

	ipnt=0l
	icir=0l
	gotPnts=0
	gotCirxform=0
	while (not done) do begin
  		a=strsplit(inp[iline],/extract,count=count)
		if useDebug then print,iline," ntoks:",count," inpline:",inp[i]
		if count lt 2 then  goto,botloop2
		case 1 of
			count eq 7 : begin
					if gotCirXform then begin
					   gotCirXform=0
					   ipnt=0
					   icir++
					endif
					if ipnt ge 5 then begin
						print,"line:",iline+1," more than 5 points skip last targs:",inp[iline]
					endif else begin
    					pntsCir[ipnt].name=a[0]
						pntsCir[ipnt].pos =double(a[1:3])
						ipnt++
					endelse
					end
			a[0] eq 'Analyze' : begin
					if ipnt lt 5 then begin
						print,"-->line:",iline+1," Analyze circle but only have ",ipnt," pnts.. skipping analyz"
						print,"-->      ",inp[iline-1]
						print,"-->      ",inp[iline]
						ipnt=0l
						gotPnts=0
					endif else begin
						circAr[icir].pnts=pntsCir
						circAr[icir].pnts.err=0d
						gotPnts=1
					endelse
					end 
			gotPnts and (a[1] eq 'X') : circAr[icir].tr[0]=double(a[2])
			gotPnts and (a[1] eq 'Y') : circAr[icir].tr[1]=double(a[2])
			gotPnts and (a[1] eq 'Z') : circAr[icir].tr[2]=double(a[2])
			gotPnts and (a[0] eq 'X') : circAr[icir].xrotD=double(a[2])
			gotPnts and (a[0] eq 'Y') : circAr[icir].yrotD=double(a[2])
			gotPnts and (a[0] eq 'Radius') : circAr[icir].radius=double(a[1])
			gotPnts and (a[0] eq 'RMS')    :begin
					   circAr[icir].rms=double(a[3])
					   gotCirXform=1
					 end
			gotPnts and (cnt eq 4) and (a[0] ne 'RMS'): begin
					ii=where(circAr[icir].pnts.name eq a[0],cnt)
					if (cnt eq 0) then begin
						print,"line:",iline+1," residual name not in measured points ignore error"
					endif else begin
						circAr[icir].pnts[ii[0]].err=double(a[1:3]) 
					endelse
					end
			else: if useDebug then print,"skip:"+inp[iline]
		endcase
botloop2:   iline++
		done=iline ge nlines
	endwhile
	if (gotCirXform) then icir++
	ncirc=icir
	if ncirc gt 0 then circAr=circAr[0:ncirc-1]
	return,3
end
