;+
;NAME:
;svskinplogdsnxform - input design data points and transform from a sokia theodolite log file.
;SYNTAX: npts= svskinplogdsnxformlun,pnts,xform,debug=debug)
;ARGS:
;	    lun: int  file to read from
;pnts[npts]: {surveypnts} return data here
;xform     : {surveyxform} final transform read from logfile
;KEYWORDS:  
;DEBUG     : if set then output debuggin info
;
;DESCRIPTION:
;	Read the sokia log file and input the measured theodolites points
;for the design targets. Also input the final transformation. The routine
;will stops after the Saved system design line (it doesn't read the measured targets
;for say the horns).
; The program will strip out any lines with null,null
;-
function svskinplogdsnxform,file,pnts,xform,lunout=lunout,debug=debug


	useDebug=keyword_set(debug)
	if n_elements(lunout)  eq 0 then lunout=-1
	maxpnts=500
	pnts=replicate({svpntsk},maxpnts)
	xform={surveyxform}
;
; 	input the file
; 
	n=readasciifile(file,inp)
	if n le 0 then begin
		print,"readasciifile return status:",n," for file ",file
		return,-1
	endif
;
; get rid of binary 0,0 
;
	a=byte(inp)
	ii=where(a[0,*] ne 0,cnt)
	if (cnt eq 0) then begin
		print,"No non zero lines found in file"
		return,-1
	endif
	inp=inp[ii]
	nlines=n_elements(inp)
	icur=0l
	done=0
	if useDebug then print,"Nlines found after 0 removal:",nlines
	for i=0,nlines-1 do begin
		a=strsplit(inp[i],/extract,count=count)
		if useDebug then print,i," ntoks:",count," inpline:",inp[i]
		if count lt 2 then  continue
	    case 1 of
		    a[0] eq 'Saved': done=1
			count eq 7: begin
					    ii=where(pnts.name eq a[0],nn) ; see if new or replace
						j=(nn eq 0)?icur++:ii[0]
						pnts[j].name=a[0]
					    pnts[j].pos =double(a[1:3])
					   end
			a[0] eq 'Scale': xform.scale = double(a[1])
			(a[0] eq 'X') and (a[1] eq "Rotation"): xform.xrot = double(a[2])
			(a[0] eq 'Y') and (a[1] eq "Rotation"): xform.yrot = double(a[2])
			(a[0] eq 'Z') and (a[1] eq "Rotation"): xform.zrot = double(a[2])
			(a[0] eq 'X') and (count eq 2)        :xform.x = double(a[1])
			(a[0] eq 'Y') and (count eq 2)        :xform.y = double(a[1])
			(a[0] eq 'Z') and (count eq 2)        :xform.z = double(a[1])
			(a[0] ne 'RMS') and (count eq 4):begin
					ii=where(pnts.name eq a[0],cnt)
					if (cnt eq 0) then begin
					  print,"residual with no measuremnt:",inp[i]
					  break
					endif
					pnts[ii[0]].err=double(a[1:3])
			      end
			(a[0] eq 'RMS') and (count eq 4):xform.rmsfit=double(a[3])
            else: if useDebug then print,"skip:"+inp[i]
		endcase
		if done then break
	endfor
	if icur eq 0 then return,0
	pnts=pnts[0:icur-1]
	return,icur
end
