;+
;NAME:
;svskinppntslog - input data points from a sokia theodolite log file.
;SYNTAX: npts= svskinppntslog(lun,pnts)
;ARGS:
;	    lun: int  file to read from
;pnts[npts]: {surveypnts} return data here
;
;DESCRIPTION:
;	input the survey data points from the data file. The program looks for
;the following keys at the start of a line:
; -,; ignore line
; SET  begin a set of data points.. following lines should have:
;       name   x y z  ...
; Transform .. end of set 
; Res  begin residuals. following lines should have :
;       name  dx dy dz
; It will stay in SET or Res mode till the next SET or Res is found.
;The routine will add an entry for every point found. Duplicate points
;will be entered twice. Use uniq on the name to check for  duplicates.
;-
function svskinppntslog,lun,pnts,maxpnts=maxpnts,lunout=lunout,debug=debug

    on_ioerror,readerr

	if n_elements(lunout)  eq 0 then lunout=-1
	if n_elements(maxpnts) eq 0 then maxpnts=500
	pnts=replicate({svpntsk},maxpnts)
	onpnt=0
	onres=0
	vals=dblarr(3)
	i=0
	line=''
	firstset=0
	lab=''
	cnt=0
	while 1 do begin
	  line=' '
	  ok=0
      readf,lun,line
	  ok=1
readerr:
	  if keyword_set(debug) then begin
	  	a=string(format='("->",a,/)',strmid(line,0,49))
 	 	 printf,lunout,a
	  endif
	  if (eof(lun)) then goto,done
	  if ok eq 0 then begin
		len=strlen(line)
		print,"readerr, linelen:",len
        printf,lunout,line
        print,!error_state.msg
		goto,done
	  endif
	  a=strsplit(line,/extract)
	  ntok=n_elements(a)
	  dataPnt=ntok eq 7
	  case 1 of
		  strcmp(line,';',1)    :  i=i
		  strcmp(line,'-',1)    :  i=i
		  strlen(line) eq 0     :  i=i
	      dataPnt: begin
				lab=strtrim(a[0])
				pnts[i].name=a[0]
				pnts[i].pos=double(a[1:3])
				i=i+1
				end
		  ntok eq 4: begin
				lab=a[0]
				ind=where(pnts.name eq lab,count) 
			    if count  gt 0 then begin
					pnts[ind].err=double(a[1:3])
			    endif else begin
				   a=string(format='("rmserr:",a)',strmid(line,0,29))
				    printf,lunout,a
				endelse
				end
		  else : begin
				a=string(format='("skip:",a)',strmid(line,0,29))
				printf,lunout,a
				end
	  endcase
	endwhile
done: 
    npts=i
    if npts ne maxpnts then pnts=pnts[0:npts-1]
	return,npts
end
