;+
;NAME:
;svskinptargets - input target file used by sokia
;SYNTAX: npts= svskinptargets(file,tI,comment=comment)
;ARGS:
;	    lun: int  file to read from
;KEYWORDS:
;comment:  string   defines comment line if in col 1.
;                   if not supplied then defaults to #
;
;RETURNS:
;npts      : long         number of points returned
;                        < 0 --> error
;                        -1 file does not exist
;                        -2 
;tI[npts]  : {targetpnts} return array of target structs
;
;DESCRIPTION:
;	input the targets from a sokia target file. 
;The std file format is:
;name  x    y   z   
; eg:
;0109L2S       -25.98390    -5.82900   -18.13870 
; the TI structure is:
;DL> help,ti,/st
;** Structure <ffe008>, 2 tags, length=40, data length=40, refs=1:
;   NAME            STRING    '0109L2S'
;   XYZ             DOUBLE    Array[3]
;-
function svskinptargets,file,tI,comment=comment

	if n_elements(comment) eq 0 then comment='#' 
	npnts=readasciifile(file,inp,comment=comment)
	if npnts le 0 then return,npnts
	aa={ name: " ",$
	     xyz: dblarr(3)}
	tI=replicate(aa,npnts)
	icur=0
	for i=0,npnts-1 do begin
		a=strsplit(inp[i],count=count,/extract)
		if count eq 0 then continue
		ti[icur].name=a[0]
		if count ge 4 then begin
			ti[icur].xyz=double(a[1:3])
		endif
		icur++
     endfor
	if (icur ne npnts) then begin
		if icur eq 0 then return,0
		npnts=icur
		tI=tI[0:npnts-1]
	endif
	 return,npnts
end
