;+
;NAME:
;tek_inpcsv- input tek scope csv file
;SYNTAX: istat=tek_inpcsv(file,d,hdrar=hdrar)
;ARGS:
; file: string    .csv file to input
;KEYWORDS:
;RETURNS:
;istat  : int   npts > 0 1 ok, -1 error, will  print error msg
;    d  : {}    structure with returned info
;hdrar[17]:strarr  if present then return  ascii header from file
;DESCRIPTION:
;	Input a tektronix scope .csv binary. The routine was written to handle
;files with all 4 channels (eg tek0003ALL.csv). If there are fewer channels, then
;you will still get arrasy of 4..but the channels that are missing will have 0's
;(this needs to be checked).
;
; 	The returned structure contains:
;IDL> help,d,/st
;** Structure <19333f8>, 10 tags, length=2000136, data length=2000132, refs=1:
;   CHANS           INT       Array[4]
;   NPNTS           LONG            100000
;   XUNIT           STRING    's'
;   XSTEP           FLOAT       2.00000e-10
;   XZERO           FLOAT       8.00000e-06
;   YUNITS          STRING    Array[4]
;   XDAT            FLOAT     Array[100000]
;   YDAT            FLOAT     Array[100000, 4]
;
; If hdrar= is supplied, the ascii file header will be returned;
; an example is:
; print,hdrar
;-
function tek_inpcsv,file,d,hdrar=hdrar
;
;	read past header, then back up
;
	maxHdr=25
	err=0
	lun=-1
	openr,lun,file,/get_lun,err=err
	fs=fstat(lun)

	if err ne 0 then begin
		print,"tek_inpcsv:file:" + file + " " + !error_state.msg
		return,-1
	endif
;
;	read the entire ascii file
;
	nlines=readasciifile(file,inp)
;
	chans=intarr(4)
	icur=0l
	npnts=0l
	xUnit=''
	xStep=0.
	xZero=0.
; 
	yUnits=strarr(4)
	hdrar=strarr(maxHdr)

;
; 	loop scanning the header
	scan=1   ; till hit TIME key
	while scan do begin
    	a=strsplit(inp[icur],",",/extract)
    	case 1 of
       a[0] eq 'Waveform Type'   :begin
                for i=0,3 do chans[i]=(a[i+1] eq 'Analog')?i+1:-1
                end
       a[0] eq 'Horizontal Units':xUnit=a[1]  ; 's'
       a[0] eq 'Horizontal Delay':xzero=float(a[1])
       a[0] eq 'Sample Interval' :xstep=float(a[1])
       a[0] eq 'Record Length'   :npnts=long(a[1])
       a[0] eq 'Vertical Units'  :yUnits=[a[1],a[2],a[3],a[4]]  ; 'V'
       a[0] eq 'TIME': scan=0
       else   : 
    	endcase
    	hdrAr[icur]=inp[icur]
    	icur++
		if icur ge maxHdr then begin
			print,"found more than ",maxhdr," hdr lines.. aborting. check hdrar"
			return,-2
		endif
	endwhile
	hdrar=hdrar[0:icur-1]
;
;	check that enough points inputs in inp array
;
	if ((icur+npnts) gt nlines) then begin
		; not enough lines
		lab=string(format='("Warn:hdr npnts:",i7," pntsRead:",i7," limit topnts Read")',$
				npnts,nlines - icur)
		npnts=nlines-icur
	endif
	d={$
        chans: chans,$ ; intarr 4
        npnts:npnts,$
        xunit:xunit,$
        xstep:xstep,$
        xzero:xzero,$ ; where the trigger is
        yunits:yunits,$
        xdat   :fltarr(npnts),$
        ydat   :fltarr(npnts,4)}
;                                         x      c1      c2      c3      c4
    a=stregex(inp[icur:icur+npnts-1l],"([^,]*),([^,]*),([^,]*),([^,]*),([^,]*)",/sub,/extr)
    d.xdat=reform(float(a[1,*]))
    d.ydat=transpose(float(a[2:5,*]))
	return,npnts
end
