;+
;NAME:
;tek_inpisf- input tek scope binary save file
;SYNTAX: istat=tek_inpisf(file,d,hdrar=hdrar)
;ARGS:
; file: string    .isf file to input
;KEYWORDS:
;RETURNS:
;istat  : int   1 ok, -1 error, will  print error msg
;    d  : {}    structure with returned info
;hdrar[23]:strarr  if present then return parsed ascii header from file
;DESCRIPTION:
;	Input a tektronix scope .isf binary. The routine makes a few assumptions on
;the input:
;  - 16 bit binary
;
; 	The returned structure contains:
;IDL> help,d,/st           
;** Structure <1523638>, 10 tags, length=800056, data length=800056, refs=1:
;   CHAN            LONG                 4   ; 1 thru 4. channel of scope
;   NPNTS           LONG            100000   ; number points in data array
;   XUNIT           STRING    's'            ; s - seconds
;   XSTEP           FLOAT       2.00000e-10  ; time for 1 sample
;   XZERO           FLOAT      -5.62000e-06  ; time offset for 1st time point
;   YUNIT           STRING    'V'            ; ydim V=volts
;   YSTEP           FLOAT       3.12500e-05  ; # of  yunits for 1 step in raw integer input
;   YOFFSET         FLOAT          -12800.0  ; display offset in raw input y integer
;   XDAT            FLOAT     Array[100000]  ; time in seconds for each sample
;   YDAT            FLOAT     Array[100000]  ; ydata converted to volts (or at least yunits).
;
; If hdrar= is supplied, the ascii file header will be returned, parsed on each ;
; an example is:
; print,hdrar
;IDL> for i=0,22 do print,hdrar[i]
;:WFMP:NR_P 100000
;:WFMP:BYT_N 2
;BIT_N 16
;ENC BIN
;BN_F RI
;BYT_O MSB
;WFI "Ch4, DC coupling, 200.0mV/div, 2.000us/div, 100000 points, Sample mode"
;NR_P 100000
;PT_F Y
;XUN "s"
;XIN 200.0000E-12
;XZE -5.6200E-6
;PT_O 0
;YUN "V"
;YMU 31.2500E-6
;YOF -12.8000E+3
;YZE 0.0E+0
;VSCALE 200.0000E-3
;;HSCALE 100.0000E-9
;VPOS -2.0000
;VOFFSET 0.0E+0
;HDELAY 0.0E+0
;:CURV #
;-

function tek_inpisf,file,d,hdrar=hdrar
;
;	read past header, then back up
;
	maxHdr=512
	err=0
	lun=-1
	openr,lun,file,/get_lun,err=err
	fs=fstat(lun)

	if err ne 0 then begin
		print,"tek_inpisf:file:" + file + " " + !error_state.msg
		return,-1
	endif
	on_ioerror,ioerr
	; just try to get the number of data points
	buf=bytarr(80)
	readu,lun,buf
	buf=string(buf)
	a=stregex(buf,'.*NR_P[^ ]* ([0-9]*)',/ext,/sub)
	npnts=long(a[1])
	hdrLen=fs.size - npnts*2L
	rew,lun
	buf=bytarr(hdrlen)
	readu,lun,buf
	hdr=string(buf)
;                       chn                 npnts               xunit               xstp             8    xzero                  yunit                ystp                  yoffset
	pat='.*WFI[^ ]* "Ch([0-9]).*NR_P[^ ]* ([0-9]*).*XUN[^ ]* "([^"]*)".*XIN[^ ]* ([-0-9.E+]*).*XZE[^ ]* ([-0-9E+.]*).*YUN[^ ]* "([^"]*)".*YMU[^ ]* ([-0-9.E+]*).*YOF[^ ]* ([-0-9.E+]*)'
	a=stregex(hdr,pat,/extr,/sub)
	chan =long(a[1]) 
	npnts=long(a[2]) 
	xunit=a[3]	 ; 's'
	xstp =float(a[4])
	xzero=float(a[5])
	yunit=a[6]		; 'V'
	ystp =float(a[7])
	yoff =float(a[8])
	hdrLen=fs.size - (npnts*2)

	;
    inpDat=intarr(npnts)
	readu,lun,inpDat
	d={$
		chan : chan,$ ; 1,2,3,4
		npnts:npnts,$
		xunit:xunit,$
		xstep:xstp,$
		xzero:xzero,$ ; where the trigger is
		yunit:yunit,$
		ystep:ystp,$
		yoffset:yoff,$ ; display
		xdat   :fltarr(npnts),$
		ydat   :fltarr(npnts)}

	d.ydat=(swap_endian(inpDat) - d.yoffset)*ystp
;	d.ydat=(swap_endian(inpDat) )*ystp
;	d.ydat=inpDat
	d.xdat=findgen(npnts)*xstp + xzero
	if (arg_present(hdrar)) then  begin
		hdrAr=strsplit(hdr,';',/extr)
	endif
	istat=1
done:
	if lun ne -1 then free_lun,lun
	return,istat
ioerr:
	print,"readerr:",!error_state.msg
	istat=-1
	goto,done
end
