;+
;NAME:
;turinpday - input a days worth of tur archive data.
;  SYNTAX:  n=turinpday(yymmdd,tur,fname=fname)
;    ARGS:
;  yymmdd:long  day to input
;KEYWORDS:
;fname :string  use this for the input file. Def: /share/phildat/tur/turyymmdd.dat
;RETURNS:
;      n:long   number of samples we found
;  tur[n]:{}     structure holding the turret data. 
;
;DESCRPIPTION:
;   Input a days worth of the turret archive data. This info is written
;once a second. the default data returned is:
;
;IDL> help,tur,/st
;** Structure TURLOG, 10 tags, length=216, data length=216:
;   STATWD          LONG                15
;   SECM            FLOAT           0.00000
;   POS             FLOAT           285.816
;   DEVSTAT         LONG              1025
;   LASTREQPOS      FLOAT           285.791
;   IOTRY           LONG          15662510
;   IOFAIL          LONG              1322
;   DAT             STRUCT    -> TURDATA Array[1]
;   DATTM           FLOAT     Array[22]
;    FLTS            STRUCT    -> FLTLOG Array[7]
;help,tur.dat,/st
;** Structure TURDATA, 22 tags, length=44, data length=44:
;   AI_PS24P        INT           3035
;   AI_PS24N        INT          -1568
;   AI_PSB24P       INT           3199
;   AI_PSENC5P      INT           2052
;   AI_VELFB        INT             -2
;   AI_MAMPCURMON   INT              0
;   AI_MAMPSPDMON   INT             -5
;   AI_SAMPCURMON   INT              0
;   AI_SAMPSPDMON   INT             -4
;   AI_ACCEL        INT              0
;   AI_RATEPOTPCU   INT            196
;   AO_VELCMD       INT           2001
;   DI_LS           INT          -1113
;   DI_UIO1         INT           1535
;   DI_UIO2         INT          -6157
;   DI_UIO3         INT           2627
;   DO_LSUIO1       INT              0
;   DO_UIO2_3       INT             40
;   ST_MDRV         INT              2                            
;   ST_SLDRV        INT              2                                                   
;   ST_SAFLIMLOCKAXIS INT        28946                                                   
;   ST_FAULT        INT           1537                       
;
;this is the same as the online data strcuture: see ~phil/vw/h/tieProgState.h
;-
function turinpday,yymmdd,tur,fname=fname
;
; input 1 days worth of tur data
;
;;  on_error,1
;
;   see how much of file is left
;
	if n_elements(fname) eq 0 then $
	lyymmdd=yymmdd mod 1000000l;
	fname=string(format='("/share/phildat/turret/tur",i06.6,".dat")',lyymmdd)
	openr,lun,fname,error=err,/get_lun
	if err ne 0 then begin
		print,"could not open file " + fname
		tur=''
		npts=0L
		return,npts
	endif
	turinp,lun,tur,86500
	npts=n_elements(tur)
	free_lun,lun
	return,npts
end
