;+
;NAME:
;turlab - return labels for various turret bitmaps
;SYNTAX: lab=turlab(type)
;ARGS  :
;       type    : string :
;           'devstat': device status
;           'dils'   : digital input little star
;           'di1'    : digital uio 1 
;           'di2'    : digital uio 2
;           'di3'    : digital uio 3
;           'dols_2' : digital out little star and uio2 out
;       'drv_fltstat': drive and fault status
;
;RETURNS:
;lab[n] : strarr    labels for each bit in the word
;
;DESCRIPTION:
;   This routine is normally called from turplotsum(). It provides
;the labels for all of the status bits.
;
;Warning:
; the order of the labels returned has been modified slightly. Some
;of the original status words had coded sets of bits rather than individual
;bits. This routine provides a decoded list. See turplotsum to see
;what you have to do with the binary numbers to use these labels.
;-
function turlab,type
;/*
; * labels for stat values. 16 bits, by on/off..
;*/
 	case type of
; tur log only saves slvState. doesn't have progStat
;        'prgstat': return,$
;                   ['running ', $
;                    'syncMst1', $
;                    '        ', $
;                    'ptSkipL ', $
;                    'ptFutTim', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    '        ', $
;                    'badMode ']
;
;; below is wrong.. 
; should be:
;typedef struct {
;    unsigned int    inUse       :1;
;    unsigned int    lastIoOk    :1;
;    unsigned int    modeReq     :3; 1 stop,2 pt,3 slew,4 autoscan
;    unsigned int    fill        :27;
;    }  TT_PRGSLV_STATWD;
;;LOCAL   TTT_LABELS   ttSlvStat[32]={
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
 
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;					{"ModeStop","        ",1},

;;					{"MSlew   ","ModeTrk ",1},
;;                    {"        ","ModeAScn",1},
;;                    {"LIoOk   ","-LIoOk  ",0},
;;                    {"InUse   ","-InUse  ",0}};
; // correct: 
;;                    {"InUse   ","-InUse  ",0}};
;;                    {"LIoOk   ","-LIoOk  ",0},
;;					  {"ModeStop","        ",1},
;;					  {"MSlew   ","ModeTrk ",1},
;;                    {"        ","ModeAScn",1},
;;/*************************************************************************/
;;LOCAL   TTT_LABELS  turDevStat[16]= {
;;                    {"SafteyO ","        ",0},
;;                    {"AxisFlt ","        ",0},
;;                    {"Drv1Flt ","        ",0},
;;                    {"Drv2Flt ","        ",0},

;;                    {"Warning ","        ",0},
;;                    {"TrckFlt ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"PwrOn   ","-PwrOn  ",0},
;;                    {"DrvEna  ","-DrvEna ",0},
;;                    {"RemCtrL ","{PcuEna}",0},
;;                    {"BrkOff  "," BrkOn  ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"Rebooted","        ",0},
;;                    {"        ","        ",0}};
;
; device stat where i've done some decoding..
;  moved rebooted, decoded  mode
    'devstat': return,$
                   ['SafteyO ', $
                    'AxisFlt ', $
                    'Drv1Flt ', $
                    'Drv2Flt ', $

                    'Warning ', $
                    'TrckFlt ', $
                    'Rebooted', $ ; moved
                    '        ', $

                    'PwrOn   ', $
                    'DrvEna  ', $
                    'RemCtrL ', $
                    'BrkOff  ', $

                    'ModeStop', $;mode stop,trk,slew,ascn
                    'ModeTrk ',$; dcd2
                    'ModeSlew',$; dcd2
                    'ModeAscn'] ; dcd2
;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDILs[16]={
;;                    {"        ","PhUvRly ",0},
;;                    {"        ","EmgStop ",0},
;;                    {"        ","Psr4Flt ",0},
;;                    {"-PcuCtrl","PcuCtrl ",0},
;;                    {"PcuDrvOn","        ",0},
;;                    {"        ","DoorOpen",0},
;;                    {"SafetyC ","-SafetyC",0},
;;                    {"Psr4MC  ","-Psr4MC ",0},
;;                    {"        ","        ",0},
;;                    {"Index   ","-Index  ",0},
;;                    {"        ","CRmEmgSt",0},
;;                    {"1ppsInt ","        ",0},
;;                    {"        ","CwLimit ",0},
;;                    {"        ","CcwLimit",0},
;;                    {"        ","MampFlt ",0},
;;                    {"        ","MampFltB",0}};
    'dils': return,$
                  [ '-PhUvRly', $
                    '-EmgStop', $
                    '-Psr4Flt', $
                    '-PcuCtrl ' ,$

                    'PcuDrvOn' ,$
                    '-DoorOpn' ,$
                    'SafetyC ' ,$
                    'Psr4MC  ' ,$
					  
                    '        ',$
                    '       ' ,$
                    '-CRmEmgSt',$
                    '1ppsInt ' ,$

                    '-CwLim  ' ,$
                    '-CcwLim ' ,$
                    '-MampOFlt',$
                    '-MampFdBk']

;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDIUio1[16]={
;;                    {"        ","MampOTmp",0},
;;                    {"        ","MdrvOff ",0},
;;                    {"        ","MmotOTmp",0},
;;                    {"        ","SampFlt ",0},
;;                    {"        ","SampFldB",0},
;;                    {"        ","SampOTmp",0},
;;                    {"        ","SdrvOff ",0},
;;                    {"        ","SmotOTmp",0},
;;                    {"        ","PcuEmgSt",0},
;;                    {"RstMon  ","        ",0},
;;                    {"        ","CwSdLim ",0},
;;                    {"        ","CcwSdLim",0},
;;                    {"        ","CrmEmgSR",0},
;;                    {"BrkOffMn","        ",0},
;;                    {"BrkOffCm","        ",0},
;;                    {"PcuRst  ","        ",0}};
;;
   'di1': return,$
                  [ '-MampOTmp', $
                    '-MdrvOff ', $
                    '-MmotOTmp', $
                    '-SampFlt ', $
                    '-SampFldB', $
                    '-SampOTmp', $
                    '-SdrvOff ', $
                    '-SmotOTmp', $
                    '-PcuEmgSt', $
                    'RstMon', $
                    '-CwSdLim',  $
                    '-CcwSDLim', $
                    '-CrmEmgSR',  $
                    'BrkOffMn',  $
                    'BrkOffCm', $
                    'PcuRst']

;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDIUio2[16]={
;;                    {"        ","CwFLim  ",0},
;;                    {"        ","CcwFLim ",0},
;;                    {"IlSbXmt ","-IlSbxmt",0},
;;                    {"Il430Po ","-Il430Po",0},
;;                    {"IlSbMov ","-IlSbMov",0},
;;                    {"Il430Dn ","-Il430Dn",0},
;;                    {"        ","MampFltC",0},
;;                    {"        ","SampFltC",0},
;;                    {"        ","CwDLim  ",0},
;;                    {"        ","CcwDLim ",0},
;;                    {"Pwr2Mon ","-Pwr2Mon",0},
;;                    {"BrkOffCM","        ",0},
;;                    {"AlarmRly","        ",0},
;;                    {"        ","-Psr4MCR",0},
;;                    {"        ","OvrLdRes",0},
;;                    {"Pwr1Mon ","-Pwr1Mon",0}};
   'di2': return,$
                 [  "-CwFLim",$
                    "-CcwFLim",$
                    " ",$
                    " ",$

                    " ",$
                    " ",$
                    "-MampFltC",$
                    "-SampFltC",$

                    "-CwDLim  ",$
                    "-CcwDLim ",$
                    "Pwr2Mon ",$
                    "BrkOffCM",$

                    "AlarmRly",$
                    "-Psr4MCR",$
                    "-OvrLdRes",$
                    "Pwr1Mon"] 

;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDIUio3[16]={
;;                    {"CabOvTmp","        ",0},
;;                    {"PsMcRC  ","-PsMcRC ",0},
;;                    {"RstRlyC ","        ",0},
;;                    {"SafRlyC ","-SafRlyC",0},
;;                    {"        ","IlSbndOC",0},
;;                    {"        ","IlWgOC  ",0},
;;                    {"        ","{IlKey} ",0},
;;                    {"BrkOffMc","        ",0},
;;                    {"AlarmC  ","        ",0},
;;                    {"FanRlyC ","        ",0},
;;                    {"StrbRlyC","        ",0},
;;                    {"FanRly  ","        ",0},
;;                    {"StrbRly ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0}};
   'di3': return,$
     			   ["CabOvTmp",$ 
                    "PsMcRC  ",$ 
                    "RstRlyC ",$ 
                    "SafRlyC ",$ 

                    "        ",$ 
                    "        ",$ 
                    "-IlKey  ",$ 
                    "BrkOffMc",$ 

                    "AlarmC  ",$ 
                    "FanRlyC ",$ 
                    "StrbRlyC",$ 
                    "FanRly  ",$ 

                    "StrbRly "]
;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDOLsUio1[16]={
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"Pwr1On  ","-Pwr1On ",0},
;;                    {"Alarm   ","        ",0},

;;                    {"BrkOffCm","        ",0},
;;                    {"MampEna ","-MampEna",0},
;;                    {"MampRst ","        ",0},
;;                    {"SampEna ","-SampEna",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0}};

;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDOUio2_3[16]={
;;                    {"SbndXOk ","-SbndXOk",0},
;;                    {"WgLowOk ","-WgLowOk",0},
;;                    {"DrvOnLt ","        ",0},
;;                    {"FltOnLt ","        ",0},

;;                    {"LimLt   ","        ",0},
;;                    {"-Pwr2On ","Pwr2On  ",0},
;;                    {"StrbLt  ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},

;;                    {"        ","        ",0},
;;                    {"        ","        ",0}};
; digout ls and digo uio2 are crammed together
    'dols_2': return,$
 				   ["        ",$
                    "        ",$        
                    "        ",$        
                    "        ",$        

                    "        ",$        
                    "        ",$        
                    "Pwr1On  ",$
                    "Alarm   ",$        

                    "BrkOffCm",$        
                    "MampEna ",$
                    "MampRst ",$        
                    "SampEna ",$

                    "DrvOnLt ",$ 
                    "FltOnLt ",$ 
                    "LimLt   ",$ 
                    "-Pwr2On ",$ 

                    "StrbLt  "] 

;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turDrvStat[16]={
;;				      {"DrvEnabl","DrvDisab",1},
;;                    {"DrvFlt  ","DrvPwred",1},
;;                    {"FltCntOp","        ",0},
;;                    {"OutptFlt","        ",0},
;;                    {"DrvOTmp ","        ",0},
;;                    {"MotOTmp ","        ",0},
;;                    {"FldBFlt ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0}};
;;                    {"        ","        ",0}};
; 18 bits cram master,slv drive stat together.. with decoding
'drv_stat': return, [$
                    'MDrvDisa',$ ;ignore 1st 2
                    'MDrvEna  ',$ ; ditto
                    'MDrvPwrd',$ ;ignore 1st 2
                    'MDrvFlt  ',$ ; ditto

                    'MFltCntO', $
                    'MOutputF', $
                    'MDrvOTmp', $
                    'MMotOTmp', $

                    'MFldBFlt',$
                    'SDrvDisa',$ ;ignore 1st 2
                    'SDrvEna  ',$ ; ditto
                    'SDrvPwrd',$ ;ignore 1st 2

                    'SDrvFlt  ',$ ; ditto
                    'SFltCntO', $
                    'SOutputF', $
                    'SDrvOTmp', $

                    'SMotOTmp', $
                    'SFldBFlt']



;;/*************************************************************************/
;;LOCAL   TTT_LABELS   turFltStat [16]={
;;                    {"SafetyO ","        ",0},
;;                    {"Mot12SpG","        ",0},
;;                    {"CmdSpdEr","        ",0},
;;                    {"OvrSpd  ","        ",0},
;;                    {"Drv1Fail","        ",0},
;;                    {"Drv2Fail","        ",0},
;;                    {"PwrSFail","        ",0},
;;                    {"IndFail ","        ",0},
;;                    {"BrkFail ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0},
;;                    {"        ","        ",0}};

	'faults': return, [$
                    'SafetyO ', $
                    'mot12SpG', $
                    'CmdSpdEr', $
                    'OvrSpd  ', $
                    'Drv1Fail', $
                    'Drv2Fail', $
                    'PwrSFail', $
                    'IndFail', $
                    'BrkFail ']

;;/*************************************************************************/
;;LOCAL   char        *ttStatSafety[16]={
;;                                        " ",
;;                                 "PwrOff  ",
;;                                 "Stopped ",
;;                                 "AlarmOn ",
;;                                 "Driving0",
;;                                 "BrakeOff",
;;                                 "Moving  ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " ",
;;                                        " "};
;;/*************************************************************************/
;;LOCAL   char         *turStatIntlk[16]={
;;                                       " ",
;;                                "IntlkOk ",
;;                                "IntlkSb ",
;;                                "Intlk430",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " "};
;;/*************************************************************************/
;;LOCAL   char         *turStatLim [16]={
;;                                       " ",
;;                                "LimOk   ",
;;                                "LimCdlm ",
;;                                "LimCslm ",
;;                                "LimCCdlm",
;;                                "LimCCslm",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " "};
;;/*************************************************************************/
;;LOCAL   char         *turStatAxis [16]={
;;                                       " ",
;;                                "SafOk   ",
;;                                "SafCflm ",
;;                                "SafFlt  ",
;;                                "SafInSrv",
;;                                "SafCCflm",
;;                                "SafEmgSt",
;;                                "SafEmgSC",
;;                                "SafEmgSP",
;;                                "SafPhUv ",
;;                                "{SafRst}",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " ",
;;                                       " "};
;;/*************************************************************************/
;;#if 0
;;LOCAL   char         *ttFlts [TT_MAX_FAULT_NUM+1]={
;;                            "fr0..",
;;                            "eprRd",
;;                            "eprWr",
;;                            "eprBD",
;;                            "indF.",
;;                            "indMF",
;;                            "brk..",
;;                            "fr7..",
;;                            "1ppsL",
;;                            "encUV",
;;                            "encIn",
;;                            "encEF",
;;                            "psr4F",
;;                            "pwrSp",
;;                            "PhUV.",
;;                            "runAw",
;;                            "ovrSp",
;;                            "velEr",
;;                            "bfFul",
;;                            "posRn",
;;                            "crc..",
;;                            "P24..",
;;                            "N24..",
;;                            "B24..",
;;                            "fr24.",
;;                            "fr25.",
;;                            "trkLa",
;;                            "bdTim",
;;                            "fr28m",
;;                            "fr29m",
;;                            "d/a.."};
;;
	else: return,$
 		['devstat','dils','di1','di2','dols_2',$
        'drv_stat','faults']
	endcase
	return,''
end

