;+
;NAME:
;usrpclpfixazza - add az,za to ascii header files
;SYNTAX: n=usrpclpfixazza(inpdir,outdir,firsthdr=firsthdr,lasthdr=lasthdr)
;ARGS:
;inpdir: string input directory holding the ascii .hdr files
;outdir: string output directory to write the new  ascii .hdr files
;               with the azza,
;KEYWORDS:
; firsthdr: string if supplied, then first header file to process
; lasthdr : string if supplied then last header file to process
;RETURNS:
;n     : long   number of .hdr files rewritten.
;DESCRIPTION:
;	The aeronomy usrp data taking system does not record the az,za positions
;in the data files. This routine will add the az,za info to the ascii header
;files (generated after the decoding step).
;	The routine will :
; - read all of the .hdr files found in inpdir, 
; - input the az,za data for that date
; - interpolate to the az,za to the time for this data file
; - output the ascii header file back out to outdir/ 
;
; Note that this should be run after the decoding has completed...
; It should probably be ok to have inpdir=outdir
;
; an example of using the program:
; - decode the data
; - in idl
;   @agcinit
;   inpdir='/share/tstor0/clp/t1193_20160106/'   
;   outdir='./newhdr/'
;   n=usrpclpfixazza(inpdir,outdir)
;
;  The new headers should be in outdir/
;-
;
function usrpclpfixazza,inpdir,outdir,firsthdr=firsthdr,lasthdr=lasthdr
;
;   find all the header files in the inpdir
;
	forward_function readasciifile,agcinpday
	maxlines=20
	flist=file_search(inpdir,"*.hdr")
	nfiles=n_elements(flist)
	if (keyword_set(firsthdr) or keyword_set(lasthdr)) then begin
;		get basenaeconvert to basenameq
		a=stregex(flist,".*/(.*).[0-9]+.hdr$",/sub,/extr)
		bname=reform(a[1,*])
		m1=(keyword_set(firsthdr))?firsthdr:''
		m2=(keyword_set(lasthdr))?lasthdr:reform(a[1,nfiles-1]) ; filenames start with numbers...
		ii=where((bname ge m1) and (bname le m2),nfiles)
		flist=flist[ii]
	endif
	curagcfile=-1L
	outdirL=outdir
	filesDone=0L
	if strmid(outdirL,0,1,/reverse) ne '/' then outDirL+='/'
	for ifile=0l,nfiles-1 do begin
		nlines=readasciifile(flist[ifile],inp,/fast,maxlines=maxlines)
		bname=basename(flist[ifile])
		if nlines eq 0 then begin
			print,"No lines file:",bname
			continue
		endif
		out=inp
		gottime=0
		gotpos=0
		for i=0,nlines-1 do begin
			if (strmid(out[i],0,11) eq 'DATE_SECMID') then begin
				a=strsplit(out[i],/extr)
				yymmdd=long(a[1]) mod 1000000l
				secMid=long(a[2])
				if (curagcfile ne yymmdd) then begin
					istat=agcinpday(yymmdd,b)
					if istat le 0 then begin
						print,"no agc data found for ",yymmdd
						return,-1
					endif
					; in case before midnite
					b[0].cb.time=b[1].cb.time-1.
					curagcfile=yymmdd
					azAr=reform(b.cb.pos[0])
					grAr=reform(b.cb.pos[1])
					chAr=reform(b.cb.pos[2])
					tmAgc =b.cb.time
				endif
				gottime=1
			endif
			if (gottime and (strmid(out[i],0,10) eq 'POS_AZGRCH')) then begin
				az  =interpol(azAr,tmAgc,secMid)
				zagr=interpol(grAr,tmAgc,secMid)
				zach=interpol(chAr,tmAgc,secMid)
				out[i]=string(format=$
				 '("POS_AZGRCH        ",f8.4,"   ",f7.4,"   ",f7.4)',$
					az,zagr,zach)
				gotpos=1
				break
			endif
		endfor
		if (not gotPos) then begin
			print,"not gotTime or pos, for file:",gottime,gotpos,bname
			print,"no update/copy"
		endif else begin
			openw,lunout,outdirL + bname,/get_lun
			for i=0,nlines-1 do begin
				printf,lunout,out[i]
			endfor
			free_lun,lunout
			filesDone++
		endelse
	endfor
	return,filesDone
end
