;+
;NAME:
;usrpclpimgmonscan - scan for processed usrp clp files
;SYNTAX: nfiles=usrpclpimgmonscan(dir,hdrAr,firsttime=firsttime 
;ARGS:
;dir     : string   to search for .hdr files. Include the 
;                   '/' at the end of the dir name
;KEYWORDS:
;firstTime:         if set then this is the first time the routine
;                   is called with this dir,fbase. If not set then
;                   hdrAr will have the info from the previous call.
;                   the routine will add new info to this array.
;                   with firsttime=1
;RETURNS:
;nfiles:  long   number of raw input files found
;hdrAr[nfiles]:{}  stuct holding info on all the image files found:
;
;DESCRIPTION:
;	Scan for usrp clp  processed hdrfiles(.dcd). 
;It returns the number of  input files found and the an array holding the headers. 
;EXAMPLES:
;	dir='/net/wombat/data/phil/usrpproc/150217/'
;   n=usrpclpimgmonscan(dir,hdrAr,first=1)
; help,hdrar[0],/st
; Structure <170f688>, 4 tags, length=196, data length=196, refs=1:
;;** Structure <62db38>, 18 tags, length=100, data length=100, refs=2:
;   FILENUM         LONG        1421784512
;   BLKINFILE       LONG                 1
;   NIPPSACCUM      LONG              1000
;   CUMIPPSTART     LONG               211
;   SMPTMUSEC       FLOAT         0.0400000
;   HGHTRESUSEC     FLOAT           1.00000
;   NHGHTS          LONG              4000
;   HGHTDELAYUSEC   FLOAT           533.320
;   FFTLEN          LONG             16384
;   TXSMPIPP        LONG             11000
;   HGHTSMPIPP      LONG            110975
;   CODELENUSEC     FLOAT           440.000
;   DATE            LONG          20150120
;   SECMID          LONG             58112
;   AZ              FLOAT           0.00000
;   ZAGREG          FLOAT           0.00000
;   ZACH            FLOAT           0.00000
;   lblkkinfile     string          "001"             if hires..
;   TMI             STRUCT    -> <Anonymous> Array[1]
;- 
function usrpclpimgmonscan,dir,hdrAr,firsttime=firsttime
;
; 	scan dir,fbase looking for .hdr files.
;   return in fiar one entry per filenum (multiple
;   imgfiles/fnum
;
	dirL=dir
	if (strmid(dir,0,/rever) ne "/") then dirL+='/'
	firstTimeL=keyword_set(firsttime)
	print,"Scanning for files..."
	far=file_search(dirL + "*.hdr")
	if (n_elements(far) eq 1) and (far[0] eq '') then return,0
	nfiles=n_elements(far)
	if keyword_set(firsttimeL) then begin
		i0=0
		Nnew=nfiles
	endif else begin
		nold=n_elements(hdrAr)
		maxNumOld=hdrAr[nold-1].filenum   ; actually the time
		; create last filename input hdrar
		flast=dirL + string(format='(d,".",d,".hdr")',hdrAr[nold-1].filenum,$
		      hdrAr[nold-1].blkinfile)
		ii=where(far gt flast,Nnew)
		if Nnew eq 0 then return,nold
		i0=ii[0]
	endelse
	;
	; now loop reading each new header file
	;
	start=1
	for i=i0,nfiles-1 do begin
		istat=usrpclprdhdr(far[i],hdr)
		if (istat lt 0) then return,istat
		if start then begin
			if (not firsttimeL) then begin
				hdrAr=[hdrAr,replicate(hdrAr[0],Nnew)]
			endif else begin
				hdrAr=replicate(hdr,Nnew)
			endelse
			start=0
		endif
		hdrAr[i]=hdr
	endfor
;
;
	return,nfiles
end
