;+
;NAME:
;usrpclprdhdr- read .hdr file from clp decoding
;SYNTAX:istat=usrpclprdhdr,file,hdr
;ARGS:
;file: string	header filename  xxxx.hdr
;KEYWORDS:
;RETURNS:
;istat:	0 ok -1 error
;hdr  : {}    header holding info
;DESCRIPTION:
;	Read the .hdr file created by the clp decoding (clpGpu).
;Return info in struct hdr
;Take info from the .hdr file (it should be in the same directory
;as the .dcd file.
;-
;
function usrpclprdhdr,hdrfile,hdr
;
; warning.. the order var in tmI in the struct needs to match the
;           order of the toks in the line in  the ascii file
tmI={          ippGMs:  0.	, $; input 1 ipp ms
               rmDCMs:  0.  , $; remove dc
               rfiMs:   0.	, $; rfi compute 1 ipp ms
              dcdMMs: 0.	, $; dcdMove, ms 1 ipp
               fftMs: 0.	, $; fft 1 ipp ms
               pwrMS: 0.	, $; compute pwr, accum 1 ipp ms
               gPwrS: 0.	, $; secs to read back pwr accum buf. secs
               wPwrS: 0.    , $; write pwrbuf to disc. secs
                totS: 0.}      ; total time

	 hdr={ fileNum:     0L,$	; 1970 time start
	        blkInFile:  0L,$
	       nippsAccum:  0L,$
	      cumIppStart:  0L,$
	        smpTmUsec:  0.,$
	      hghtResUsec:  0.,$
	           nhghts:  0l,$	; that were decoded and in .dcd fiel
         hghtDelayUsec: 0.,$	; for first height taken
;                                 does not include any tx offset at start
                fftlen: 0l,$	; fftlen used
              txSmpIpp: 0l,$	; txsmp taken in ipp for datataking
             hghtSmpIpp: 0l,$	; height samples taken datataking
            codeLenUsec: 0.,$	; codelen usecs
               date   :  0L,$	; yyyymmdd ast start of datablock
               secMid :  0L,$	;  ast start of datablock
				   az :  -1.,$   ;  az pos
			   zagreg :  -1.,$   ;  greg za
			   zach   :  -1.,$   ;  ch za
	        lblkInFile: '',$    ; in case hi res. will include leading zeros
				tmI   : tmI}
;
;   hdr needs same order as this.. same with file
;
;  12apr12 added pos_azgrch
	hdrI=[["FILE_NUM","I"],$
          ["BLK_IN_FILE","I"],$  
          ["NIPPS_ACCUM","I"],$
          ["CUM_IPP_START","I"],$
		  ["SMP_TM_USEC"  ,"F"],$
		  ["HGHT_RES_USEC","F"],$
		  ["NUM_HGHTS"    ,"I"],$
          ["HGHT_DELAY_USEC","F"],$
		  ["FFTLEN"         ,"I"],$
	      ["TX_SMP_IPP"     ,"I"],$
	      ["HGHT_SMP_IPP"   ,"I"],$
          ["CODE_LEN_USEC"  ,"F"],$
          ["DATE_SECMID"  ,"I I"],$
          ["POS_AZGRCH"   ,"F F F"]$
		]

;
; try a faster read
;
	n=15
	err=0
	lun=-1
	openr,lun,hdrfile,err=rr,/get_lun
	if err ne 0 then begin 
		print,'could not open hdrfile:',hdrfile
		return,-1
	endif
	if lun lt 0 then begin
		print,"hdrFile:",hdrfile," open error:",!error_state.msg
		return,-1
	endif
	inp=strarr(n)
	for i=0,n-1 do inp[i]=''
	readf,lun,inp
	free_lun,lun
	if strmid(inp[n-1],0,8)  ne 'AvgTMING' then begin
		print,'line 15 != AvgTMING in:',hdrfile
		return,-1
	endif
;
;	n=readasciifile(hdrfile,inp)
	nn=n_elements(hdrI[0,*])
	numSingle=nn-2			; number of single elements in header
	if (strmid(inp[nn-1],0,3) ne 'POS') then begin
		hdrI=hdrI[*,0:nn-2]
		nn=nn-1
	    numSingle=nn-2			; number of single elements in header
	endif
	if ((nn+1) gt (n)) then begin
		print,"hdrfile not enough entries:",hdrfile 
		return,-1
	endif
	for i=0,nn-1 do begin
		a=strsplit(inp[i],/extract)
		len=strlen(a[0])
	    if (hdrI[0,i] ne a[0]) then begin
			print,"Bad hdrEntry. expected,read:"+hdrI[0,i],+" / " + $
				a[0]
		    return,-1
		endif
		if (i lt  numSingle) then begin 
			hdr.(i)=(hdrI[1,i] eq "I")?long(a[1]):float(a[1])
		endif else begin
			case 1 of
			(a[0] eq "DATE_SECMID"):begin
						hdr.date=long(a[1])
						hdr.secMid=long(a[2])
					end
			(a[0] eq "POS_AZGRCH"):begin
						hdr.az=float(a[1])
						hdr.zagreg=float(a[2])
						hdr.zach =float(a[3])
					end
			else: begin
					print,"Bad hdrEntry. expected,read:"+hdrI[0,i],+" / " + a[0]
		    		return,-1
				end
			endcase
		endelse
	endfor
;
;  get the total times
;                 1           2         3          4         5         6          7           8          9
; AvgTMING IppG: 0.58 remDC: 1.74 rfi: 0.00 dcdM: 3.02 fft: 7.72 pwr: 3.83 GpwrS:0.190 WpwrS:12.95 totS:18.21
;inp='AvgTMING IppG: 0.58 remDC: 1.74 rfi: 0.00 dcdM: 3.02 fft: 7.72 pwr: 3.83 GpwrS:0.190 WpwrS:12.95 totS:18.21'
	a=stregex(inp[nn],$
;                1              2               3              4               5               6              7                8                   9
"[^ ]* [^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[^:]*:([0-9. ]*)[totS:]*([0-9.]*)",$
		/subex,/ext)
;	a=strsplit(inp[nn],/extract);
	if (strmid(a[0],0,8) ne "AvgTMING") then begin
			print,"Bad hdrEntry. expected,read:AvgTMING / "+ a[0]
		return,-1
	endif
	ii=[1,2,3,4,5,6,7,8,9]
	for i=0,n_elements(ii)-1 do hdr.tmI.(i)=float(a[ii[i]])
;   add string block in file
	a=stregex(hdrfile,".*\.([0-9]+).hdr",/sub,/ext)
	hdr.lblkInFile=a[1]
	return,0
end
