;+
;NAME:
;usrpfindrf - find rf in ipp
;SYNTAX: ind=usrpfindrf(si,d,nsmp=nsmp,tp=tp)
;ARGS:
;d[2,nsmp]:int    voltage samples (i,q) by n
;                or complex d[nsmp] 
;rflen  : long   num samples in rf pulse
;KEYWORDS:
;nsmp: long   if supplied then number samples in dcmp to use
;RETURNS;
;ind: long index in dcmp for start of rf pulse;
;tp[nsmp]:float  total power for nsmp
;DESCRIPTION:
;	find the index in dmp array where the rf starts.
;cmp power then convolve a window of rflenSmp and then
;find the peak.
;returns:
;  istat : -2 (found peak but too close to end of d)
;          -1 (found peak  but not clpipp)
;          >=0 index into d where rf starts
;- 
function usrpfindrf,si,d,nsmp=nsmp,tp=tp
;
	im=si.cmetaind
	rfLenSmp=long(si.expi.rfUsec * si.meta[im].sampleRate*1d-6 + .5) 
	a=size(d,/type)
	is_c = (a eq 6) or (a eq 9)
	iscl=(is_c)?1:2L
	if n_elements(nsmp) eq 0 then nsmp=n_elements(d)/iscl
	if (nsmp lt rflenSmp*2-1) then begin
		print,"nsmps be at least 2*rflenSmp-1"
		return,-1
	endif
	rf=fltarr(nsmp)
	rf[0:rflenSmp-1]=1.
	if (nsmp eq n_elements(d)) then begin
	
		tp=(is_c)? float(d)^2 + imaginary(d)^2 :$
		           float(d[0,*])^2 + float(d[1,*])^2
	endif else begin
		tp=(is_c)$  
		  ?float(d[0l:nsmp-1])^2 +  imaginary(d[0l:nsmp-1])^2$
		  :float(d[0,0l:nsmp-1])^2 + float(d[1,0l:nsmp-1])^2
	endelse
	; these dir give a pos number for a pos delay
 	a=max(fft(fft(tp,1)*conj(fft(rf,1)),-1),ind)
;   if ind is on second ipp, check to see if the max in the
;   first ipp is similar to this (and that it doesn't start at 0 (chopped off rflen)
	smpIpp=sI.smpIpp
	if (ind  ge smpIpp) then begin
 		a2=max(fft(fft(tp[0L:smpIpp-1],1)*conj(fft(rf[0L:smpIpp-1],1)),-1),ind2)
		if (ind2 gt 0) then begin
			ratio=abs(a)/abs(a2)
			; if within 10% take first peak
			if (ratio lt 1.1) then begin
			   ind=ind2
			endif
		endif
	endif
;	aa=   fft(fft(tp,1)*conj(fft(rf,1)),-1)
;	!p.multi=[0,1,2]
;	eps=100
;	hor,ind-eps,ind+eps
;	plot,aa
;	flag,ind
;	plot,tp
;	flag,ind
;
; 	now see if this starts a clp ipp
;
 	npnts=(nsmp - ind)  
;   actually probably only need smpInrfPulse + a few sampels
	epssmp=25*10 ; add 10 usecs
	if npnts lt rflensmp + epssmp then return,-2 
	isOk=usrpclpchkipp(d[ind:nsmp-1],minTxVal=si.expI.minTxPwr,uncoded=si.expI.uncoded)
	if isOk then return,ind
	return,-1 ;
end
