;+
;NAME:
;usrpgetdata - input data
;SYNTAX: nsmp=usrpgetdata(si,nsmpReq,d)
;ARGS:
;SI     :{}        from usrpinitset
;nsmpreq:long      number of samples requested
;RETURNS:
; nsmp	: long	   -99  .. no more files left
;                  < nsmpReq. read this many,
;                  next file has time jump
;                  (next file is current file) 
;                  
; d[nsmp]: complex  data input as floats
;
;DESCRIPTION:
;	Read the next requested number of samples
;from the si dataset. Return the number of samples
;read in nsmp, and the data in d[nsmp] as complex floats.
;	This will read across files unless there is a time jump between
; files. In this case it just returns the samples read and positions at
;the start of the new file.
;-
function usrpgetdata,si,nsmpReq,d
;
	im=si.cmetaInd
	bytesSmp=si.meta[im].bytesSmp
	nbytesReq=bytesSmp * nsmpReq
;	
;	see how many samples left in file/
;
	if (si.cfi.curPos lt si.dataOff) then begin
		point_lun,si.cfi.fd,si.dataOff
		si.cfi.curPos=si.dataOff
	endif
	smpLeft=(si.cfi.bytesTot - si.cfi.curPos)/bytesSmp
;
	smpRead=0L
	while (smpRead lt nsmpReq) do begin
		if smpLeft gt 0 then begin
			smpToRead=((nsmpReq - smpRead) < smpLeft)
			; don't write over previous buf
			if (smpRead gt 0) then begin
				buf1=intarr(2,smpToRead)
				readu,si.cfi.fd,buf1
				buf=reform([reform(buf,smpRead*2),reform(buf1,smpToRead*2)],2,smpRead+smpToRead)
			endif else begin
				buf=intarr(2,smpToRead)
				readu,si.cfi.fd,buf
			endelse
			smpRead+=smpToRead
			si.cfi.curPos+=smpToRead*bytesSmp
		endif
		if smpRead lt nsmpReq then begin
			; -1 .. no more files
            ;  0 .. file open ok
            ; > 0.. file open but time jump
			istat=usrpnextfile(si)
			if (istat lt 0) then goto,nomorefiles
			if (istat gt 0) then goto,tmjump
			smpLeft=si.cfi.bytesTot - si.cfi.curpos
		endif
	endwhile
tmjump:
	d=complex(reform(buf[0,*]),reform(buf[1,*]))
	return,smpRead
nomorefiles:
	return,-99
end
