;
; input file
;
; smpRead=usrpgetrawdata(lun,d,nsmp=nsmp,smpOff=smpOff,cmplx=cmplx,
;                        fname=fname,closeit=closeit)
;ARGS:
;lun    :  int   lun to read from. It should already be opened
;                (unless fname=  keyword is used.
;KEYWORDS:
; nsmp  :  long  number of samples to read. def=2^20
; smpOff:  long  smp offset to start reading at. count from 0.
;                if smpOff < 0 then continue at current position.
;cmplx  :        if set then return complex data. def: short
;fname  : string file to read. If supplied then open file, return
;                lun in lun. Leaves file open.
;				 fname='' will ignore fname
;closeit:        if true then close file on return.def is to leave it open.
;                
;RETURNS:
; smpRead: long  < 0   error.
;               -1    file open error.
;				-2    user provided lun. No file smpOff was requested, and
;                     the file was not aligned on a 4 byte boundary (smp boundary).
;               -3    could not position to requested sample in file
;                
function usrpgetrawdata,lun,d,nsmp=nsmp,smpOff=smpOff,cmplx=cmplx,fname=fname,closeit=closeit 

;
;	 i,q
	bytesSmp=4
;	start of data in file
	dataOff=2680L
	maxSmp=25000000l
;	end of data
	lastPos=dataOff + maxSmp*bytesSmp
	defSmp=2l^20
	retStat=0L
	
	if n_elements(nsmp) eq 0 then nsmp=defSmp
	nsmpL=nsmp
	if n_elements(smpOff) gt 0 then begin
		if smpOff ge maxSmp then begin
			retStat=-3
			goto,done
		endif
	endif


	if keyword_set(fname) then begin
		err=0
		openr,lun,fname,/get_lun,error=err
		if err ne 0 then begin
		  print,"openError:",!error_state.msg
		  retStat=-1
		  goto,done
		endif
	endif
;
;	get current pos of file
;
	point_lun,-lun,curpos
	needPos=0
	if curpos eq 0 then begin
		needPos=1
		posOff=dataOff
	endif
;
	if n_elements(smpOff) gt 0 then begin
		needPos=1
		posOff=dataOff + smpOff*bytesSmp
	endif
;
	if needPos then begin
		point_lun,lun,posOff
	    curPos=posOff
	endif
;
;	don't exceed max samples
;
	if ((curPos + nsmpL*bytesSmp) ge lastPos) then begin
		nsmpL=(lastPos - curPos)/bytesSmp
	endif
;
; alloc array
;
	d=intarr(2,nsmpL)
	readu,lun,d,transfer_count=nread
	smpRead=nread/2l
	if smpRead gt 0 then begin
		if keyword_set(cmplx) then begin
			d=complex(reform(d[0,*]),reform(d[1,*]))
		endif
	endif
	retStat=smpRead
	if keyword_set(closeit) then free_lun,lun
	
done:	return,retStat
end
