;+
;NAME:
;usrpinitset - initialize for a set of usrp files
;SYNTAX: istat=usrpinitset(dir,sI,expI=expI,$
;                      subDirSt=subDirSt,indFile=indFile,minTxPwr=minTxPwr}
;ARGS:
;dir: string    directory holding the 1 hour blocks of data
;KEYWORDS:
;expI    :{}    struct holding exp info that user can define
;               expI.rfUsec  - rf pulse in usecs (def=440)
;               expI.ippUsec - ipp usecs (def=10000)
;subDirSt :''  first subdir to start with (just the base name)
;              default is first in directory
;indFile  :0L  index in subdir for file to start
;              count from 0
;minTxPwr :0.  minimum allowable value for tx pulse. def: .8e6
;	           If you also supply expI{}, this will override the
;              value in expi.minTxPwr
;
;RETURNS:
;	istat: 0 ok
;          -1 error initializing set
;   sI   :{}    set info, used to access the data
;DESCRIPTION:
;	initialize the sI struct for access to the usrp
;data files. After this, you can call usrpgetdata(sI,xx)
;-
function usrpinitset,dir,sI,expI=expI,subDirSt=subDirSt,indfile=indFile,$
			minTxPwr=minTxPwr
;
;	find subdir in this dir
;
;   if si exists, close any open files
;
	if n_elements(si) gt 0 then begin
		if n_elements(si.cfi.fd) gt 0 then begin
			if si.cfi.fd gt 0 then begin
				free_lun,si.cfi.fd
				si.cfi.fd=-1
			endif
		endif
	endif
	txMinPwrDef=.8e6
	dirL=dir
	if strmid(dirL,0,1,/reverse) ne "/" then dirL+="/"
	if n_elements(indFile) eq 0 then indFile=0L
	sI={setInfo}
;   mod 09jun16 .. updated offset to brett's email
;	sI.dataOff=2676L
	sI.dataOff=2680L
	; end of full file.. not data 
;	sI.endSlop=4492L
	sI.endSlop=4488L
	if n_elements(expI) eq 1 then begin
		si.expI=expI
	endif else begin
		si.expI.ippUsec=10000d
		si.expI.rfUsec =440d
		si.expI.minTxPwr=txMinPwrDef
	endelse
	if n_elements(minTxPwr) eq 1 then si.expI.minTxPwr=minTxPwr
	sI.topDir=(strmid(dirL,0,1,/revers) ne "/")?$
			dirL + "/" : dirL
;
;	find all of the meta files in top dir
;  ..we only use the first... for sample rate so watch out..
	flist=file_search(dirL + "*.h5")
	if (flist[0] eq '') then begin
	 	print,"No meta files found in top dir:",dirL
		return,-1
	endif
	si.nmeta=n_elements(flist)
	for i=0,si.nmeta-1  do begin
		si.meta[i].fname=basename(flist[i])
		st=h5_parse(flist[i])
		si.meta[i].sampleRate=st.sample_rate._data;		sample rate hz.
		si.meta[i].bytesDtype =strcmp(st.dtype._data,"<i2")?2:1; byte or short
		si.meta[i].bytesSmp  =st.itemsize._data   ;   bytes for i,q sample
		si.meta[i].startTm   =st.t0._data         ;   sec 1970 utc first subdir
		si.meta[i].dirnm1    =usrpsectodirnm(si.meta[i].startTm); name of 1st dir
	endfor

;   now get list of sub directories.. each hold 1 hour of data

	subdirl=file_search(sI.topDir + '20[0-9][0-9]-*',/test_dir)
	nsubdir=n_elements(subdirl)
	if nsubdir eq 0 then begin
		print,"No data subdir in ",dirL
		return,-1
	endif
	nmax=n_elements(si.subdirAr)
	if nsubdir gt nmax then begin
	   print,'found ',nsubdir," subdir.. will only process first:",nmax
	   nsubdir=nmax
	endif
	subdirStB=(keyword_set(subDirSt) eq 0)? $
		basename(subdirl[0]): basename(subDirSt)
	indSt=-1
	for i=0,nsubdir-1 do begin
		 si.subdirAr[i]=basename(subdirL[i])
		 if subdirStB eq si.subDirAr[i] then indSt=i 
	endfor
	si.nsubdir=nsubdir
	if indSt eq -1 then begin
		print,"Requested subDir to start in not found:",subDirSt
		return,-1
	endif
	si.indCsd=indSt
;
;	find the closest metadata file
;
	imeta=-1
	for i=0,si.nmeta-1 do begin
		if si.meta[i].dirnm1 le subdirStB then imeta=i
	endfor
	if imeta eq -1 then begin
		print,"No metafile found for first subdir:",subdirStB
		return,-1
	endif
	si.cmetaInd=imeta
	si.smpIpp= long(si.meta[imeta].sampleRate * si.expI.ippusec*1d-6 + .5)
	si.bytesSmp=si.meta[imeta].bytesSmp
;
;	now get the current filename to start on in the subdir 
;
	filePat=si.topdir + si.subDirAr[si.indCsd] + "/*h5"
	flist=file_search(filePat)
	nfiles=n_elements(flist)
	if (indFile ge nfiles ) then begin
		print,"indFile:",indFile," does not exist in dir"
		return,-1
	endif
;
; open the files
;
	si.cfi.fnameAll =flist[indFile]
	si.cfi.basenm =basename(flist[indFile],dirnm=dirnm)
	si.cfi.dirPath =dirnm
	si.cfi.fInd= indFile
	si.cfi.time=long(strmid(si.cfi.basenm,3,10))
	openr,lun,si.cfi.fnameAll,/get_lun
	si.cfi.fd=lun
	fs=fstat(lun)
	si.cfi.bytesTot=(fs.size - si.endSlop)
	point_lun,lun,si.dataOff
	si.cfi.curPos=si.dataOff
;
	
	return,0
end
