;+
;NAME:
;usrpplottp - total power plot of usrp file
;SYNTAX: usrpplottp,si,ippfile=ippfile,nsmpipp=nsmpipp,delay=delay,limline=limline
;ARGS:
;si : {}   structure returned from usrpinitset()
;KEYWORDS:
;ippfile: long   number of ipps in file to plot. def:100 
;nsmpipp: long   number of samples in ipp. def:250000
;delay  : float  secs to delay between plots. def:.001
;limline: float  draw red horizontal on each plot here.
;RETURNS:
;	None. the si struct will be updated to the last 
;data read.
;DESCRIPTION:
;	Read raw usrp file compute power and plot it. The read is done
;nsmpipp at a time. ippfile ipps will be done in the file.
;It also places a horizonal line at the value of
;limline. You can use this to see if the txPower samples
;ever falls below this value (the tx threshold is used in searching
;for the tx pulse during clp decoding).
;	The routine will process ippfile ipps in the file .. and
;then it stops (doesn't move to the next file yet..);
;
;Example:
;  @usrpinit
;  dir='/export/usrp/20160106/ch'
;  ; data is stored by hour in each dir. to start at a later
;  ; directory use subdirst
;  subDirSt='2016-01-06T13-03-33'
;  istat=usrpinitset(dir,sI,subdirst=subdirst)
;
;-
pro usrpplottp,si,ippfile=ippfile,nsmpipp=nsmpipp,delay=delay,limline=limline
	    common colph,decomposedph,colph

	if n_elements(nsmpipp) eq 0 then nsmpipp=250000L
	if n_elements(delay) eq 0 then delay=.001
	if n_elements(limline) eq 0 then limline=.8e6
	if n_elements(ippFile) eq 0 then ippFile=100l
	ippThisFile=0l
	nsmp=nsmpipp
	
	while (nsmp) ge nsmpipp/2. do begin
    	nsmp=usrpgetdata(si,nsmpReq,d1)  &$ 
    	tp=abs(d1)^2 &$ 
   	    plot,tp ,tit=si.cfi.fnameall&$ 
         oplot,[0,2.5e5],[limline,limline],col=colph[2] &$ 
    	empty &$ 
    	wait,delay &$ 
		ippThisFile++
		if ippThisFile ge  ippFile then begin
			istat=usrpnextfile(si)
			if (istat lt 0) then begin
		   		print,"usprnextfile returned:",istat
		   		return
			endif
			ippThisFile=0L
		endif
	endwhile 
	return
end
