;
; demultiplex vdif file
; pass in header to check info. need to read it before and then
; hdr: {}   pass in header read previously for file
; lun: int  lun to read
;KEYWORD:
;nthreads: int   expected number of threads in file. if mismatch, return error.
;framestoread: int   number of frames to read .def: 128
;chkrate  : int   if true that verify that bandwidth the same for ll threads
;lut[4[   : float  if supplied then use this for the level values. def: -3.3349,-1,1,3.3349
;
;RETURNS
; nframes :   frames read. < 0 --> error
; bufI{}  :  hold info about returned buf
; obuf[smpFrame*nframes/nthr,nthr]: float   data input
;ihar=ihar[8,nframes
;-
function vdifvmux,hdr,lun,bufI,obuf,nthreads=nthreads,framestoread=framestoread,$
			chkrate=chkrate,ihar=ihar,lut=lut
;
; build the 2bit  lookup table
;  0  = -3.3349, 1=-1, 2 = 1.,3=3.3349   .. sigmas
	useHar=arg_present(ihar)
 	useRate=keyword_set(chkrate)
	Hi=3.3359;  .. walter brisken
	twoBitVals=[-Hi,-1.,1.,Hi]
	if (n_elements(lut) eq 4 ) then twoBitVals=lut 
	valAr=indgen(256)
	mask=3
	lut2bit=fltarr(4,256)
	for i=0,255 do begin &$
    	val=valAr[i] &$
    	for j=0,3 do begin &$
        	lut2bit[j,i]=twoBitVals[val and mask]  &$
        	val=ishft(val,-2) &$
    	endfor &$
	endfor

	hdrLenLong=8 ; 32 bit
	framePerBlk=128l;    ;frames to read  per read command
	if n_elements(framestoread) eq 0 then framestoread=framePerBlk
	if framePerBlk gt framestoread then framePerblk=framestoread
;
	nbits=hdr.bitspersmp + 1
	if nbits ne 2 then begin
		print,"Only works for 2bit data"
		return,-1
	endif	
	if hdr.cmplxdata ne 0 then begin
		print,"Only works for real data"
		return,-1
	endif	
	if hdr.nchanlog2 ne 0 then begin
		print,"Only works for single channel,multi thread files"
		return,-1
	endif	
;
	rate0=hdr.smprate
	frameLenBytes=hdr.datafrlen*8l ; number of bytes in frame
	frameLenLong=frameLenBytes/4l ; number of longs in frame
	smpFrame=(frameLenBytes-hdrLenLong*4)*(8l/nbits)
	inp=ulonarr(frameLenLong,framePerBlk)
	framesRead=0l
	start=1
	while (framesRead lt framesToRead) do begin
		readu,lun,inp,transfer_count=nwords
		nframesInp=nwords/frameLenLong
		if nframesInp ne framePerBlk then inp=inp[*,0:nframesRead-1] ; must have hit the end
;
;		do a quick decode of the header values we need
;
		thrAr=reform(ishft(inp[3,*],-16) and '3ff'xul)
;       frame within sec
		frNumAr=reform((inp[1,*] and 'ffffff'xul))
;       second from ref epoch
		secAr=reform(inp[0,*] and '3fffffff'xul)
		if useRate then rateAr=(inp[4,*] and '7fffff'xl)
;      first time check frames to get nthreads
		if start then begin
			uthr=thrAr[uniq(thrAr,sort(thrAr))]
			nthreadsFound=n_elements(uthr)
			if n_elements(nthreads) eq 0 then nthreads=nthreadsFound
		    if (nthreadsFound ne nthreads) then begin
				print,"nthreads input:",nthreads," but file has:",nthreadsFound
				return,-1
			endif
			bufI={ nthreads:nthreads,$
				   smpFrame:smpFrame,$
				smpThrAr:lonarr(nthreads),$; samples found for each thread
			    trblThrAr:lonarr(nthreads)}  ; 1 --> found problems in a frame
;                 smpByte bytesLong,nlongs
			obuf=fltarr(smpFrame*framestoread/nthreads,nthreads)
			start=0
		    if useHar then begin
				ihar=ulonarr(8,framestoread)
				ihdr=0l
			endif
		endif
;		
;		loop over each thread
;	
		for ithr=0,nthreads-1 do begin
			thr=uthr[ithr]; thread number to look for
			if useRate then begin
				ii=where((thrAr eq thr) and (rateAr eq rate0),nfr)
			endif else begin
				ii=where(thrAr eq thr,nfr)
			endelse
			if nfr eq 0 then continue
			ismp=bufI.smpThrAr[ithr]  ; last sample we loaded this thread 
			mask=255
			for ifr=0,nfr-1 do begin
				iuse=ii[ifr]
				if usehar then begin
					ihar[*,ihdr]=inp[0:7,iuse] 
				    ihdr++
			    endif
			
				for iwd=hdrLenLong,frameLenLong-1 do begin ; skip header
					val=inp[iwd,iuse]
					; bytes/word
					for j=0,3 do begin
						imm=val and mask
				    	obuf[ismp:ismp+3,ithr]=lut2bit[*,imm]
;                         
; 						print,iwd,j,val,imm,lut2bit[*,imm],format='(i4,1x,i2,1x,z08,1x,i3,1x,4f8.3)'
					    ismp+=4
					    val=ishft(val,-8)
					endfor ; done with 32bit word
			   endfor  ; done with frame
			endfor ; done this thread in blk
			bufI.smpThrAr[ithr]=ismp  ; remember where we left off
		endfor
		framesRead+=nframesInp
	endwhile
	if usehar then begin
		if ihdr lt framestoread then ihar=ihar[*,0l:ihdr-1]
	endif
	return,framesRead
end
