;+
;NAME:
;wbffmon - read and plot spectra 
;SYNTAX: wbffmon,fbase, npnts=npnts,ntrace=ntrace,dopwr=dopwr,rbw=rbw,$
;                       v1=v1,v2=v2,azsw=azsw,pwrar=pwrar,ffar=ffar
;ARGS:
;fbase: string     prefix of file pattern to match.def=8001
;                  eg: '/share/phildat/wbrcv/220622/azsw_'
;KEYWORDS:
;npnts   : long    number of points in spectra. def=
;ntrace  : long    number of traces returned.def=1
;dopwr   : long    compute power and display 
;rbw     : float   rbw set in ff in MHz
;v1[2]   : float   min,max vertical for freq plot, def: min,max
;v2[2]   : float   min,max vertical for power plot
;azsw    :  value  if set then data is azswing.
;                  grab az,el from filenames
;                  plot,vs az, each elevation set a separate number.
;RETURNS:
; ffar[nrecs]: {}  holds the input data.  spc still in dbm  
; pwrar[nrecs]: dblarr(nrecs)  return the integrated power fo each spectra
;                             (if dopwr is set)
;
;
;IDL> help,ffar,/st
;** Structure <1bd3138>, 6 tags, length=16048, data length=16048, refs=1:
;   FNAME           STRING    '/share/phildat/wbrcv/220621/azsw_00_06_000_270.dat'
;   CFR             FLOAT           7000.00
;   DF              FLOAT           10.0000
;   MTIME           LONG64                1655836951
;   FREQ            DOUBLE    Array[1001]
;   SPC             DOUBLE    Array[1001]
;
; check
pro wbffmon,fbase,ffAr=ffAr,pwrar=pwrar,npnts=npnts,ntrace=ntrace,$
			delay=delay,rbw=rbw,dopwr=dopwr,v1=v1,v2=v2,azsw=azsw
;
   common colph,decomposedph,colph
;
	nrecs=wbffinpscan(fbase,ffAr,npnts=npnts,ntrace=ntrace)
	if nrecs eq 0 then begin
		print,'No recs found for :',fbase
	endif
	nplots=keyword_set(dopwr)?2:1
	cs=(nplots eq 1)?1:1.4
	if n_elements(v1) eq 2 then ver,v1[0],v1[1]
	hor
	!p.multi=[0,1,nplots]
	xtit='Freq [MHz]'
	ytit='Dbm'
	tit='spectral density for azswings'
	stripsxy,ffar[0].freq,ffar.spc,0,0,/step,$	
			chars=cs,font=font,$	
			xtit=xtit,ytit=ytit,$
			tit=tit
	if  nplots eq 2 then begin	
		sym=0
		x=findgen(nrecs)
		if n_elements(rbw) eq 0 then rbw=1.
		df =ffar[0].df
		scldb=alog10(df/rbw)*10.
		pwrAr=dblarr(nrecs)
		freq=ffar[0].freq
		for i=0,nrecs-1 do begin
			pwrAr[i]=wbffcmppwr(freq,ffar[i].spc) + scldb
		endfor
	    if n_elements(v2) eq 2 then ver,v2[0],v2[1]
;
		if keyword_set(azsw) then begin
			a=stregex(ffar.fname,".*azsw_.._(..).*(...).dat",/sub,/extr)
			az=long(a[2,*])
			el=long(a[1,*])
			uel=el[uniq(el,sort(el))]
			nuEl=n_elements(uel)
			x=az
			sym=0
	        hor,0,360	
			ytit='dbm'
			xtit='az [deg]'
			cs=1.4
			tit='Total power (at fieldfox) vs az by el swing'
			plot,[0,1],[0,1],/nodata,$
				chars=cs,font=font,$
				xtit=xtit,ytit=ytit,$
				tit=tit
			for i=0,nuel-1 do begin
				icol=(i mod 10) + 1
				ii=where(el eq uel[i],cnt)
				x=az[ii]
				y=pwrAr[ii]
				jj=sort(x)
				oplot,x[jj],y[jj],col=colph[icol]
				ln=26
				xp=.04
			    csn=1.5
				xpinc=.1
				note,ln,string(format='(i02)',uel[i]),col=colph[icol],xp=xp+i*xpinc,$	
						chars=csn, font=font
			endfor
		endif else begin
			plot,x,pwrar
		endelse
	endif
	return
end
