;+
;NAME:
;wbffrmsmask - compute mask from rms
;SYNTAX: nscans=wbffrmsmas(spcArLin,nrecs,mask,rmsar=rmsar,nsig=nsig)
;ARGS:
;spcarLin[n]: {}   array of input spectra to use for computing rms, mask
;                  should be linear
;nrecs: int     number of records in a scan
;KEYWORDS:
; nsig   :  float the clipping level in sigmas for bad data. def=3.
;RETURNS:
;nscans    :  number of scans we processed
;            -1 problem. need multiple recs
;mask[npnts]: 0 - ok to use
;             >0  number of scans that had a bad rms in the channel
;rmsAr[npnts,nscans]: computed rmsar
;-
function wbffrmsmask,spcAr,nrecs,mask,rmsar=rmsar,nsig=nsig
;
	if n_elements(nsig) eq 0 then nsig=3.
	a=size(spcAr)
	if a[0] lt 2 then begin
		print,"must be 2d or > array to compute the rms"
		return,-1
	endif
	npnts=a[1]
	nspc=n_elements(spcar)/npnts
	nscans=nspc/nrecs
	if nscans eq 0 then begin
	   lab=string(format='("only ",i4," found. 1 scan needs:",i4)',nspc,nrecs)
		print,lab
		return,-1
	endif
	rmsAr=dblarr(npnts,nscans)
	i0=0
	mask=intarr(npnts)
	x=findgen(npnts)
	deg=1
	for i=0,nscans-1 do begin
		i1=i0+nrecs-1
		rmsAr[*,i]=rmsbychan(spcar[*,i0:i1])
		coef=robfit_poly(x,rmsAr[*,i],deg,bindx=bindx,nbad=nbad,nsig=nsig)
		if nbad gt 0 then mask[bindx]+=1
	endfor
	return,nscans
end
