;+
;NAME: 
;wstrawinpday - read in 1 days worth of data from ascii file
;
;SYNTAX: n=wstrawinpday(yymmdd,bar,inpdir=inpdir,tip=tip)
;ARGS:
;  yymmdd: int   yymmdd of date for file (ast)
; inpdir : string input dir to read file. def: '/share/orion/'
;  tip   :       if set then include tipping meter info in struct.
;                this includes the rainelements with a 2 eg
;                raintoday2
;RETURNS:
;      n:  int   number records input
; bar[n]: struct input data
;               
;DESCRIPTION:
;   Input a days worth of wst data from the daily raw:
;wst_yymmdd.txt. 
;	The data is loaded into the {wststr) array bar. 
;The file can have 1 or more minutes from the next ast day
;Since the file rename occurs 1 minute after midnite
;-
function wstrawinpday,yymmdd,bar,inpdir=inpdir,tip=tip
	
	if n_elements(inpdir) eq 0 then inpdir='/share/orion/'
	yymmddF=yymmdd
	if (yymmddF gt 999999) then yymmddF=yymmddF mod 1000000l
	yr2=long(yymmddf/10000l) ; to check for old,new data
	bar=''
	ntot=0L
	lun=-1
	a=bin_date()
	curyymmdd=(a[0] mod 100l) * 10000 + a[1]*100 + a[2]
;
; 	make filename
;
	if (curyymmdd eq yymmddF) then  begin
		fname=inpdir + 'oriondata.txt'
	endif else begin
		fname=inpdir + string(format='("wst_",i06,".txt")',yymmddF)
	endelse
	ierr=0
	openr,lun,fname,/get_lun,error=ierr
	if ierr ne 0 then begin
		print,"file:",fname," open error:",!ERROR_STATE.MSG
		goto,errout
	endif

;	count the records in the file
;
	cmd="wc " + fname   
	spawn,cmd,reply
	a=strsplit(reply,/extract)
	nrecs=long(a[0])
	if nrecs le 0 then begin
		print,"No lines found in file:",fname
		goto,done
	endif
	on_ioerror,ioerr2
	inpar=strarr(nrecs)
	readf,lun,inpar
ioerr2:
	ii=where(inpar ne '',cnt)
	if cnt ne nrecs then begin
		inpar=inpar[ii]
		nrecs=cnt
	endif
	bar=keyword_set(tip)?replicate({wststrtip},nrecs):replicate({wststr},nrecs)
	ntot=0L
	if  (yr2 lt 21) then begin ; old data
	  for i=0L,nrecs - 1L do begin
		bar[ntot++]=wstldrec(inpar[i])
	  endfor
	endif else begin
	  for i=0L,nrecs - 1L do begin
		bar[ntot++]=wstldrec21(inpar[i],tip=tip)
	  endfor
	endelse
	if (ntot) lt nrecs then begin
		bar=bar[0:ntot-1]
		nrecs=ntot
	endif
done:
	if lun ge 0 then free_lun,lun
	return,ntot
errout:
	ntot=-1
	goto,done
end
